@@ -239,7 +239,7 @@ class Box2DKernel(Kernel2D):
         Width of the filter kernel.
     mode : str, optional
         One of the following discretization modes:
-            * 'center' 
+            * 'center'
                 Discretize model by taking the value
                 at the center of the bin.
             * 'linear_interp' (default)
@@ -674,12 +674,12 @@ class AiryDisk2DKernel(Kernel2D):
 
     Parameters
     ----------
-    width : number
-        Width of the filter kernel.
+    radius : float
+        The radius of the Airy disk kernel (radius of the first zero).
     x_size : odd int, optional
-        Size in x direction of the kernel array. Default = 8 * width.
+        Size in x direction of the kernel array. Default = 8 * radius.
     y_size : odd int, optional
-        Size in y direction of the kernel array. Default = 8 * width.
+        Size in y direction of the kernel array. Default = 8 * radius.
     mode : str, optional
         One of the following discretization modes:
             * 'center' (default)
@@ -720,9 +720,9 @@ class AiryDisk2DKernel(Kernel2D):
     """
     _is_bool = False
 
-    def __init__(self, width, **kwargs):
-        self._model = models.AiryDisk2D(1, 0, 0, width)
-        self._default_size = _round_up_to_odd_integer(8 * width)
+    def __init__(self, radius, **kwargs):
+        self._model = models.AiryDisk2D(1, 0, 0, radius)
+        self._default_size = _round_up_to_odd_integer(8 * radius)
         super(AiryDisk2DKernel, self).__init__(**kwargs)
         self.normalize()
         self._truncation = None
@@ -730,13 +730,13 @@ class AiryDisk2DKernel(Kernel2D):
 
 class Model1DKernel(Kernel1D):
     """
-    Create kernel from astropy.models.Parametric1DModel.
+    Create kernel from 1D model.
 
     The model has to be centered on x = 0.
 
     Parameters
     ----------
-    model : Parametric1DModel
+    model : `~astropy.modeling.Parametric1DModel`
         Kernel response function model
     x_size : odd int, optional
         Size in x direction of the kernel array. Default = 8 * width.
@@ -760,11 +760,11 @@ class Model1DKernel(Kernel1D):
     Raises
     ------
     TypeError
-        If model is not an instance of astropy.models.Parametric1DModel
+        If model is not an instance of `~astropy.modeling.Parametric1DModel`
 
     See also
     --------
-    Model2DKernel : Create kernel from astropy.models.Parametric2DModel
+    Model2DKernel : Create kernel from `~astropy.modeling.Parametric2DModel`
     CustomKernel : Create kernel from list or array
 
     Examples
@@ -794,13 +794,13 @@ class Model1DKernel(Kernel1D):
 
 class Model2DKernel(Kernel2D):
     """
-    Create kernel from astropy.models.Parametric2DModel.
+    Create kernel from 2D model.
 
-    The model has to be centered on x = 0 and y= 0.
+    The model has to be centered on x = 0 and y = 0.
 
     Parameters
     ----------
-    model : Parametric2DModel
+    model : `~astropy.modeling.Parametric2DModel`
         Kernel response function model
     x_size : odd int, optional
         Size in x direction of the kernel array. Default = 8 * width.
@@ -826,11 +826,11 @@ class Model2DKernel(Kernel2D):
     Raises
     ------
     TypeError
-        If model is not an instance of astropy.models.Parametric2DModel
+        If model is not an instance of `~astropy.modeling.Parametric2DModel`
 
     See also
     --------
-    Model1DKernel : Create kernel from astropy.models.Parametric1DModel
+    Model1DKernel : Create kernel from `~astropy.modeling.Parametric1DModel`
     CustomKernel : Create kernel from list or array
 
     Examples
