@@ -263,7 +263,7 @@ class _AngleParser(object):
                     "Syntax error parsing angle {0!r}".format(angle))
 
         if unit is None and found_unit is None:
-                raise u.UnitsError("No unit specified")
+            raise u.UnitsError("No unit specified")
 
         return found_angle, found_unit
 
@@ -517,7 +517,8 @@ def sexagesimal_to_string(values, precision=None, pad=False, sep=(':',),
     values = (values[0], np.abs(values[1]), np.abs(values[2]))
 
     if pad:
-        if values[0] < 0:
+        # Check to see if values[0] is negative, using np.copysign to handle -0
+        if np.copysign(1.0, values[0]) == -1:
             pad = 3
         else:
             pad = 2
@@ -527,20 +528,25 @@ def sexagesimal_to_string(values, precision=None, pad=False, sep=(':',),
     if not isinstance(sep, tuple):
         sep = tuple(sep)
 
+    if fields < 1 or fields > 3:
+        raise ValueError(
+            "fields must be 1, 2, or 3")
+
     if not sep:  # empty string, False, or None, etc.
         sep = ('', '', '')
     elif len(sep) == 1:
-        sep = sep + (sep[0], '')
+        if fields == 3:
+            sep = sep + (sep[0], '')
+        elif fields == 2:
+            sep = sep + ('', '')
+        else:
+            sep = ('', '', '')
     elif len(sep) == 2:
         sep = sep + ('',)
     elif len(sep) != 3:
         raise ValueError(
             "Invalid separator specification for converting angle to string.")
 
-    if fields < 1 or fields > 3:
-        raise ValueError(
-            "fields must be 1, 2, or 3")
-
     # Simplify the expression based on the requested precision.  For
     # example, if the seconds will round up to 60, we should convert
     # it to 0 and carry upwards.  If the field is hidden (by the
