@@ -1,17 +1,20 @@
 # -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import print_function
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
 
 from numpy import testing as npt
 from ...tests.helper import pytest
 raises = pytest.raises
 
+from ...extern import six
+
 from ... import units as u
-from ..errors import *
+from ..errors import ConvertError, IllegalSecondError, IllegalMinuteError, IllegalHourError
 
 
 try:
-    import scipy
+    import scipy  # pylint: disable=W0611
 except ImportError:
     HAS_SCIPY = False
 else:
@@ -57,20 +60,21 @@ def test_create_angles():
     as much for self-documenting code as anything else.
 
     Angle objects simply represent a single angular coordinate. More specific
-    angular coordinates (e.g. RA, Dec) are subclasses of Angle.'''
+    angular coordinates (e.g. Longitude, Latitude) are subclasses of Angle.'''
 
     a1 = Angle(54.12412, unit=u.degree)
     a2 = Angle("54.12412", unit=u.degree)
     a3 = Angle("54:07:26.832", unit=u.degree)
     a4 = Angle("54.12412 deg")
     a5 = Angle("54.12412 degrees")
-    a6 = Angle(u"54.12412°") # because we like Unicode
+    a6 = Angle("54.12412°") # because we like Unicode
     a7 = Angle((54, 7, 26.832), unit=u.degree)
-    a8 = Angle(u"54°07'26.832\"")
+    a8 = Angle("54°07'26.832\"")
     # (deg,min,sec) *tuples* are acceptable, but lists/arrays are *not*
     # because of the need to eventually support arrays of coordinates
-    with raises(NotImplementedError):
-        Angle([54, 7, 26.832], unit=u.degree)
+    a9 = Angle([54, 7, 26.832], unit=u.degree)
+    npt.assert_allclose(a9.value, [54, 7, 26.832])
+    assert a9.unit is u.degree
 
     a10 = Angle(3.60827466667, unit=u.hour)
     a11 = Angle("3:36:29.7888000120", unit=u.hour)
@@ -78,7 +82,7 @@ def test_create_angles():
 
     Angle(0.944644098745, unit=u.radian)
 
-    with raises(UnitsError):
+    with raises(u.UnitsError):
         Angle(54.12412)
         #raises an exception because this is ambiguous
 
@@ -91,17 +95,17 @@ def test_create_angles():
 
     a16 = Angle("1 d")
     a17 = Angle("1 degree")
-    assert a16.degrees == 1
-    assert a17.degrees == 1
+    assert a16.degree == 1
+    assert a17.degree == 1
 
     #ensure the above angles that should match do
-    a1 == a2 == a3 == a4 == a5 == a6 == a7
-    npt.assert_almost_equal(a1.radians, a2.radians)
-    npt.assert_almost_equal(a2.degrees, a3.degrees)
-    npt.assert_almost_equal(a3.radians, a4.radians)
-    npt.assert_almost_equal(a4.radians, a5.radians)
-    npt.assert_almost_equal(a5.radians, a6.radians)
-    npt.assert_almost_equal(a6.radians, a7.radians)
+    assert a1 == a2 == a3 == a4 == a5 == a6 == a7
+    npt.assert_allclose(a1.radian, a2.radian)
+    npt.assert_allclose(a2.degree, a3.degree)
+    npt.assert_allclose(a3.radian, a4.radian)
+    npt.assert_allclose(a4.radian, a5.radian)
+    npt.assert_allclose(a5.radian, a6.radian)
+    npt.assert_allclose(a6.radian, a7.radian)
     #assert a10 == a11 == a12
 
     # check for illegal ranges / values
@@ -132,40 +136,32 @@ def test_angle_ops():
     """
     Tests operations on Angle objects
     """
-    from .. import Angle
-    import numpy.testing as npt
 
-    '''
-    Angles can be added and subtracted. Multiplication and division by
-    a scalar is also permitted. A negative operator is also valid.
-    All of these operate in a single dimension. Attempting to
-    multiply or divide two Angle objects will raise an exception.
-    '''
+    from .. import Angle
+
+    # Angles can be added and subtracted. Multiplication and division by a
+    # scalar is also permitted. A negative operator is also valid.  All of
+    # these operate in a single dimension. Attempting to multiply or divide two
+    # Angle objects will raise an exception.
+
     a1 = Angle(3.60827466667, unit=u.hour)
     a2 = Angle("54:07:26.832", unit=u.degree)
     a1 + a2  # creates new Angle object
     a1 - a2
     -a1
 
-    # division and multiplication have no unambiguous meaning here
-    with raises(NotImplementedError):
-        a1 / a2
-
-    with raises(NotImplementedError):
-        a1 * a2
-
-    npt.assert_almost_equal((a1 * 2).hours, 2 * 3.6082746666700003)
-    assert abs((a1 / 3.123456).hours - 3.60827466667 / 3.123456) < 1e-10
+    npt.assert_allclose((a1 * 2).hour, 2 * 3.6082746666700003)
+    assert abs((a1 / 3.123456).hour - 3.60827466667 / 3.123456) < 1e-10
 
     # commutativity
-    (2 * a1).hours == (a1 * 2).hours
+    assert (2 * a1).hour == (a1 * 2).hour
 
     a3 = Angle(a1)  # makes a *copy* of the object, but identical content as a1
-    npt.assert_almost_equal(a1.radians, a3.radians)
+    npt.assert_allclose(a1.radian, a3.radian)
     assert a1 is not a3
 
     a4 = abs(-a1)
-    assert a4.radians == a1.radians
+    assert a4.radian == a1.radian
 
     a5 = Angle(5.0, unit=u.hour)
     assert a5 > a1
@@ -173,76 +169,6 @@ def test_angle_ops():
     assert a1 < a5
     assert a1 <= a5
 
-def test_angle_bounds():
-    """
-    Tests setting and obeying of bounds for Angle objects, as well as
-    how operations interact with bounds
-    """
-    from .. import Angle, RangeError, BoundsError
-    import numpy.testing as npt
-
-    '''
-    By default the Angle object can accept any value, but will return
-    values in [-360,360] (retaining the sign that was specified).
-
-    One can also set artificial bounds for custom applications and range
-    checking. As Angle objects are intended to be immutable (the angle value
-    anyway), this provides a bound check upon creation. The units given in the
-    `bounds` keyword must match the units specified in the scalar.
-    '''
-
-    a1 = Angle(13343, unit=u.degree)
-    npt.assert_almost_equal(a1.degrees, 23)
-
-    a2 = Angle(-50, unit=u.degree)
-    assert a2.degrees == -50
-
-    a3 = Angle(-361, unit=u.degree)
-    npt.assert_almost_equal(a3.degrees, -1)
-
-    # custom bounds
-
-    with raises(BoundsError):
-        Angle(66, unit=u.degree, bounds=(-45, 45))
-
-    a4 = Angle(390, unit=u.degree, bounds=(-75, 75))
-    npt.assert_almost_equal(a4.degrees, 30)
-    # no BoundsError because while 390>75, 30 is within the bounds
-
-    a5 = Angle(390, unit=u.degree, bounds=(-720, 720))
-    a5.degrees == 390
-
-    a6 = Angle(1020, unit=u.degree, bounds=None)
-    a6.degrees == 1020
-
-    # bounds and operations
-
-    with raises(ValueError):
-        a4 + a5
-        # ValueError - the bounds don't match
-
-    a7 = a4 + a4
-    assert a7.bounds == (-75, 75)
-    # if the bounds match, there is no error and the bound is kept
-    npt.assert_almost_equal(a7.degrees, 60)
-
-    a8 = a4 - a4
-    assert a8.bounds == (-75, 75)
-    # To get the default bounds back, you need to create a new object with the
-    # equivalent angle
-    Angle(a4.degrees + a4.degrees, unit=u.degree)
-
-    a9 = Angle(a4.degrees + a5.degrees, unit=u.degree, bounds=[-180, 180])
-    npt.assert_almost_equal(a9.degrees, 60)
-    # if they don't match and you want to combine, just re-assign the bounds
-    # yourself
-
-    # bounds of None can also be operated on without complaint
-    a10 = a6 - a6
-    a10.degrees == 0
-
-    with raises(AttributeError):
-        a10.bounds = (0,34)
 
 def test_angle_convert():
     """
@@ -250,23 +176,24 @@ def test_angle_convert():
     """
 
     from .. import Angle
-    import numpy.testing as npt
 
     angle = Angle("54.12412", unit=u.degree)
 
-    npt.assert_almost_equal(angle.hours, 3.60827466667)
-    npt.assert_almost_equal(angle.radians, 0.944644098745)
-    npt.assert_almost_equal(angle.degrees, 54.12412)
+    npt.assert_allclose(angle.hour, 3.60827466667)
+    npt.assert_allclose(angle.radian, 0.944644098745)
+    npt.assert_allclose(angle.degree, 54.12412)
 
+    assert len(angle.hms) == 3
     assert isinstance(angle.hms, tuple)
     assert angle.hms[0] == 3
     assert angle.hms[1] == 36
-    npt.assert_almost_equal(angle.hms[2], 29.78879999999947)
+    npt.assert_allclose(angle.hms[2], 29.78879999999947)
 
+    assert len(angle.dms) == 3
     assert isinstance(angle.dms, tuple)
     assert angle.dms[0] == 54
     assert angle.dms[1] == 7
-    npt.assert_almost_equal(angle.dms[2], 26.831999999992036)
+    npt.assert_allclose(angle.dms[2], 26.831999999992036)
 
     assert isinstance(angle.dms[0], float)
     assert isinstance(angle.hms[0], float)
@@ -291,77 +218,77 @@ def test_angle_formatting():
     angle = Angle("54.12412", unit=u.degree)
 
     #__str__ is the default `format`
-    assert str(angle) == angle.format()
+    assert str(angle) == angle.to_string()
 
-    res = 'Angle as HMS: 3h36m29.78880s'
-    assert "Angle as HMS: {0}".format(angle.format(unit=u.hour)) == res
+    res = 'Angle as HMS: 3h36m29.7888s'
+    assert "Angle as HMS: {0}".format(angle.to_string(unit=u.hour)) == res
 
-    res = 'Angle as HMS: 3:36:29.78880'
-    assert "Angle as HMS: {0}".format(angle.format(unit=u.hour, sep=":")) == res
+    res = 'Angle as HMS: 3:36:29.7888'
+    assert "Angle as HMS: {0}".format(angle.to_string(unit=u.hour, sep=":")) == res
 
     res = 'Angle as HMS: 3:36:29.79'
-    assert "Angle as HMS: {0}".format(angle.format(unit=u.hour, sep=":",
+    assert "Angle as HMS: {0}".format(angle.to_string(unit=u.hour, sep=":",
                                       precision=2)) == res
 
     # Note that you can provide one, two, or three separators passed as a
     # tuple or list
 
     res = 'Angle as HMS: 3h36m29.7888s'
-    assert "Angle as HMS: {0}".format(angle.format(unit=u.hour,
+    assert "Angle as HMS: {0}".format(angle.to_string(unit=u.hour,
                                                    sep=("h", "m", "s"),
                                                    precision=4)) == res
 
     res = 'Angle as HMS: 3-36|29.7888'
-    assert "Angle as HMS: {0}".format(angle.format(unit=u.hour, sep=["-", "|"],
+    assert "Angle as HMS: {0}".format(angle.to_string(unit=u.hour, sep=["-", "|"],
                                                    precision=4)) == res
 
     res = 'Angle as HMS: 3-36-29.7888'
-    assert "Angle as HMS: {0}".format(angle.format(unit=u.hour, sep="-",
+    assert "Angle as HMS: {0}".format(angle.to_string(unit=u.hour, sep="-",
                                                     precision=4)) == res
 
     res = 'Angle as HMS: 03h36m29.7888s'
-    assert "Angle as HMS: {0}".format(angle.format(unit=u.hour, precision=4,
+    assert "Angle as HMS: {0}".format(angle.to_string(unit=u.hour, precision=4,
                                                   pad=True)) == res
 
     # Same as above, in degrees
 
     angle = Angle("3 36 29.78880", unit=u.degree)
 
-    res = 'Angle as DMS: 3d36m29.78880s'
-    assert "Angle as DMS: {0}".format(angle.format(unit=u.degree)) == res
+    res = 'Angle as DMS: 3d36m29.7888s'
+    assert "Angle as DMS: {0}".format(angle.to_string(unit=u.degree)) == res
 
-    res = 'Angle as DMS: 3:36:29.78880'
-    assert "Angle as DMS: {0}".format(angle.format(unit=u.degree, sep=":")) == res
+    res = 'Angle as DMS: 3:36:29.7888'
+    assert "Angle as DMS: {0}".format(angle.to_string(unit=u.degree, sep=":")) == res
 
     res = 'Angle as DMS: 3:36:29.79'
-    assert "Angle as DMS: {0}".format(angle.format(unit=u.degree, sep=":",
+    assert "Angle as DMS: {0}".format(angle.to_string(unit=u.degree, sep=":",
                                       precision=2)) == res
 
     # Note that you can provide one, two, or three separators passed as a
     # tuple or list
 
     res = 'Angle as DMS: 3d36m29.7888s'
-    assert "Angle as DMS: {0}".format(angle.format(unit=u.degree,
+    assert "Angle as DMS: {0}".format(angle.to_string(unit=u.degree,
                                                    sep=("d", "m", "s"),
                                                    precision=4)) == res
 
     res = 'Angle as DMS: 3-36|29.7888'
-    assert "Angle as DMS: {0}".format(angle.format(unit=u.degree, sep=["-", "|"],
+    assert "Angle as DMS: {0}".format(angle.to_string(unit=u.degree, sep=["-", "|"],
                                                    precision=4)) == res
 
     res = 'Angle as DMS: 3-36-29.7888'
-    assert "Angle as DMS: {0}".format(angle.format(unit=u.degree, sep="-",
+    assert "Angle as DMS: {0}".format(angle.to_string(unit=u.degree, sep="-",
                                                     precision=4)) == res
 
     res = 'Angle as DMS: 03d36m29.7888s'
-    assert "Angle as DMS: {0}".format(angle.format(unit=u.degree, precision=4,
+    assert "Angle as DMS: {0}".format(angle.to_string(unit=u.degree, precision=4,
                                                   pad=True)) == res
 
-    res = 'Angle as rad: 0.06298radian'
-    assert "Angle as rad: {0}".format(angle.format(unit=u.radian)) == res
+    res = 'Angle as rad: 0.0629763rad'
+    assert "Angle as rad: {0}".format(angle.to_string(unit=u.radian)) == res
 
-    res = 'Angle as rad decimal: 0.06298'
-    assert "Angle as rad decimal: {0}".format(angle.format(unit=u.radian, decimal=True)) == res
+    res = 'Angle as rad decimal: 0.0629763'
+    assert "Angle as rad decimal: {0}".format(angle.to_string(unit=u.radian, decimal=True)) == res
 
 
     # check negative angles
@@ -369,126 +296,104 @@ def test_angle_formatting():
     angle = Angle(-1.23456789, unit=u.degree)
     angle2 = Angle(-1.23456789, unit=u.hour)
 
-    assert angle.format() == '-1d14m04.44440s'
-    assert angle.format(pad=True) == '-01d14m04.44440s'
-    assert angle.format(unit=u.hour) == '-0h04m56.29629s'
-    assert angle2.format(unit=u.hour, pad=True) == '-01h14m04.44440s'
-    assert angle.format(unit=u.radian, decimal=True) == '-0.02155'
-
+    assert angle.to_string() == '-1d14m04.4444s'
+    assert angle.to_string(pad=True) == '-01d14m04.4444s'
+    assert angle.to_string(unit=u.hour) == '-0h04m56.2963s'
+    assert angle2.to_string(unit=u.hour, pad=True) == '-01h14m04.4444s'
+    assert angle.to_string(unit=u.radian, decimal=True) == '-0.0215473'
 
 def test_angle_format_roundtripping():
     """
     Ensures that the string represtation of an angle can be used to create a
     new valid Angle.
     """
-    from .. import Angle, RA, Dec
+    from .. import Angle, Longitude, Latitude
 
     a1 = Angle(0, unit=u.radian)
     a2 = Angle(10, unit=u.degree)
     a3 = Angle(0.543, unit=u.degree)
     a4 = Angle('1d2m3.4s')
 
-    assert Angle(str(a1)).degrees == a1.degrees
-    assert Angle(str(a2)).degrees == a2.degrees
-    assert Angle(str(a3)).degrees == a3.degrees
-    assert Angle(str(a4)).degrees == a4.degrees
+    assert Angle(str(a1)).degree == a1.degree
+    assert Angle(str(a2)).degree == a2.degree
+    assert Angle(str(a3)).degree == a3.degree
+    assert Angle(str(a4)).degree == a4.degree
 
-    #also check RA/Dec
-    ra = RA('1h2m3.4s')
-    dec = Dec('1d2m3.4s')
+    #also check Longitude/Latitude
+    ra = Longitude('1h2m3.4s')
+    dec = Latitude('1d2m3.4s')
 
-    assert Angle(str(ra)).degrees == ra.degrees
-    assert Angle(str(dec)).degrees == dec.degrees
+    npt.assert_allclose(Angle(str(ra)).degree, ra.degree)
+    npt.assert_allclose(Angle(str(dec)).degree, dec.degree)
 
 
 def test_radec():
     """
-    Tests creation/operations of RA and Dec objects
+    Tests creation/operations of Longitude and Latitude objects
     """
-    from .. import RA, Dec, Angle
+    from .. import Longitude, Latitude, Angle
     from ...time import Time
 
     '''
-    RA and Dec are objects that are subclassed from Angle. As with Angle, RA
-    and Dec can parse any unambiguous format (tuples, formatted strings, etc.).
+    Longitude and Latitude are objects that are subclassed from Angle. As with Angle, Longitude
+    and Latitude can parse any unambiguous format (tuples, formatted strings, etc.).
 
     The intention is not to create an Angle subclass for every possible
-    coordinate object (e.g. galactic l, galactic b). However, equatorial RA/dec
+    coordinate object (e.g. galactic l, galactic b). However, equatorial Longitude/Latitude
     are so prevalent in astronomy that it's worth creating ones for these
     units. They will be noted as "special" in the docs and use of the just the
     Angle class is to be used for other coordinate systems.
     '''
 
-    with raises(UnitsError):
-        ra = RA("4:08:15.162342")  # error - hours or degrees?
-    with raises(UnitsError):
-        ra = RA("-4:08:15.162342")
+    with raises(u.UnitsError):
+        ra = Longitude("4:08:15.162342")  # error - hours or degrees?
+    with raises(u.UnitsError):
+        ra = Longitude("-4:08:15.162342")
 
     # the "smart" initializer allows >24 to automatically do degrees, but the
     #Angle-based one does not
     #TODO: adjust in 0.3 for whatever behavior is decided on
 
-    #ra = RA("26:34:15.345634")  # unambiguous b/c hours don't go past 24
-    #npt.assert_almost_equal(ra.degrees, 26.570929342)
-    with raises(UnitsError):
-        ra = RA("26:34:15.345634")
+    #ra = Longitude("26:34:15.345634")  # unambiguous b/c hours don't go past 24
+    #npt.assert_allclose(ra.degree, 26.570929342)
+    with raises(u.UnitsError):
+        ra = Longitude("26:34:15.345634")
 
-    #ra = RA(68)
-    with raises(UnitsError):
-        ra = RA(68)
+    #ra = Longitude(68)
+    with raises(u.UnitsError):
+        ra = Longitude(68)
 
-    with raises(UnitsError):
-        ra = RA(12)
+    with raises(u.UnitsError):
+        ra = Longitude(12)
 
     with raises(ValueError):
-        ra = RA("garbage containing a d and no units")
+        ra = Longitude("garbage containing a d and no units")
 
-    ra = RA("12h43m23s")
-    npt.assert_almost_equal(ra.hours, 12.7230555556)
+    ra = Longitude("12h43m23s")
+    npt.assert_allclose(ra.hour, 12.7230555556)
 
-    ra = RA((56, 14, 52.52), unit=u.degree)      # can accept tuples
+    ra = Longitude((56, 14, 52.52), unit=u.degree)      # can accept tuples
     #TODO: again, fix based on >24 behavior
-    #ra = RA((56,14,52.52))
-    with raises(ValueError):
-        ra = RA((56, 14, 52.52))
-    with raises(ValueError):
-        ra = RA((12, 14, 52))  # ambiguous w/o units
-    ra = RA((12, 14, 52), unit=u.hour)
+    #ra = Longitude((56,14,52.52))
+    with raises(u.UnitsError):
+        ra = Longitude((56, 14, 52.52))
+    with raises(u.UnitsError):
+        ra = Longitude((12, 14, 52))  # ambiguous w/o units
+    ra = Longitude((12, 14, 52), unit=u.hour)
 
-    with raises(NotImplementedError):
-        ra = RA([56, 64, 52.2], unit=u.degree)  # ...but not arrays (yet)
+    ra = Longitude([56, 64, 52.2], unit=u.degree)  # ...but not arrays (yet)
 
     # Units can be specified
-    ra = RA("4:08:15.162342", unit=u.hour)
+    ra = Longitude("4:08:15.162342", unit=u.hour)
 
     #TODO: this was the "smart" initializer behavior - adjust in 0.3 appropriately
-    ## Where RA values are commonly found in hours or degrees, declination is
+    ## Where Longitude values are commonly found in hours or degrees, declination is
     ## nearly always specified in degrees, so this is the default.
-    #dec = Dec("-41:08:15.162342")
-    with raises(UnitsError):
-        dec = Dec("-41:08:15.162342")
-    dec = Dec("-41:08:15.162342", unit=u.degree)  # same as above
+    #dec = Latitude("-41:08:15.162342")
+    with raises(u.UnitsError):
+        dec = Latitude("-41:08:15.162342")
+    dec = Latitude("-41:08:15.162342", unit=u.degree)  # same as above
 
-    # The RA and Dec objects have bounds hard-coded at (0,360) and (-90,90)
-    # degrees, respectively.
-    assert ra.bounds == (0, 360)
-    with raises(AttributeError):
-        ra.bounds = (-45, 45)
-    assert dec.bounds == (-90, 90)
-    with raises(AttributeError):
-        dec.bounds = (-45, 45)
-
-    #RA objects can also compute hour angle and local siderial times
-    ra = RA("1:00:00", unit=u.hour)
-    ha1 = ra.hour_angle(Angle(1.5, u.hour))
-    assert isinstance(ha1, Angle)
-    npt.assert_almost_equal(ha1.hours, .5)
-    ha2 = ra.hour_angle(Time('2012-1-1 3:00:00', scale='utc'))
-    npt.assert_almost_equal(ha2.hours, 23.125)
-
-    lst = ra.lst(Angle(1.5, u.hour))
-    assert isinstance(lst, Angle)
-    npt.assert_almost_equal(lst.hours, 2.5)
 
 def test_create_coordinate():
     """
@@ -502,66 +407,70 @@ def test_create_coordinate():
     coordinates with conversions to standard coordinates.
     '''
 
-    from .. import Angle, RA, Dec, ICRSCoordinates, GalacticCoordinates
-    from .. import HorizontalCoordinates
-    import numpy.testing as npt
+    from .. import Angle, Longitude, Latitude, ICRS, Galactic
+    from .. import AltAz
 
-    ra = RA("4:08:15.162342", unit=u.hour)
-    dec = Dec("-41:08:15.162342", unit=u.degree)
+    ra = Longitude("4:08:15.162342", unit=u.hour)
+    dec = Latitude("-41:08:15.162342", unit=u.degree)
 
-    # ra and dec are RA and Dec objects, or Angle objects
-    c = ICRSCoordinates(ra, dec)
-    c = ICRSCoordinates(Angle(4.137545095, u.hour), Angle(-41.137545095, u.degree))
+    # ra and dec are Longitude and Latitude objects, or Angle objects
+    c = ICRS(ra, dec)
+    c = ICRS(Angle(4.137545095, u.hour), Angle(-41.137545095, u.degree))
 
-    c = ICRSCoordinates("54.12412 deg", "-41:08:15.162342 deg")
-    assert isinstance(c.dec, Dec) # dec is a Dec object
+    c = ICRS("54.12412 deg", "-41:08:15.162342 deg")
+    assert isinstance(c.dec, Latitude)  # dec is a Latitude object
 
-    npt.assert_almost_equal(dec.degrees, -41.137545095)
+    #make sure ICRS has a working repr
+    repr(c)
+
+    npt.assert_allclose(dec.degree, -41.137545095)
 
     # We should be really robust in what we accept.
-    with raises(ValueError):
-        c = ICRSCoordinates("12 34 56  -56 23 21") # ambiguous
+    with raises(u.UnitsError):
+        c = ICRS("12 34 56  -56 23 21") # ambiguous
 
     with raises(TypeError):
-        c = ICRSCoordinates() # not allowed
+        c = ICRS() # not allowed
 
-    c = ICRSCoordinates(ra="12 43 12", dec=dec, unit=(u.hour, u.hour))
+    c = ICRS(ra="12 43 12", dec=dec, unit=(u.hour, u.hour))
 
     with raises(TypeError):
-        c = ICRSCoordinates(ra="12 43 12", unit=(u.hour,))
+        c = ICRS(ra="12 43 12", unit=(u.hour,))
 
     with raises(TypeError):
-        c = ICRSCoordinates(ra="12h43m32", b="12:32:43")
+        c = ICRS(ra="12h43m32", b="12:32:43")
 
     with raises(TypeError):
-        c = ICRSCoordinates(ra="12h43m32")
+        c = ICRS(ra="12h43m32")
 
     with raises(TypeError):
-        c = ICRSCoordinates(dec="12 32 54")
+        c = ICRS(dec="12 32 54")
 
     # It would be convenient to accept both (e.g. ra, dec) coordinates as a
     # single string in the initializer. This can lead to ambiguities
     # particularly when both are different units. The solution is to accept a
     # sequence for the "unit" keyword  that one would expect to sent to Angle.
     # This must be a 2-sequence with the two elements' units.
-    ICRSCoordinates('4 23 43.43  +23 45 12.324', unit=(u.hour, u.degree))
+    ICRS('4 23 43.43  +23 45 12.324', unit=(u.hour, u.degree))
 
     # If one of them is None, try to guess for unambiguous cases
-    ICRSCoordinates('12h43m32 +23:45:12.324', unit=(None, u.degree))
+    ICRS('12h43m32 +23:45:12.324', unit=(None, u.degree))
 
     # unit=None is the same as unit=(None, None)
-    ICRSCoordinates('12h43m32 +23d45m12.324s', unit=None)
+    ICRS('12h43m32 +23d45m12.324s', unit=None)
 
 
     # Other types of coordinate systems have their own classes
     l = Angle(123.4, unit=u.degree)
     b = Angle(76.5, unit=u.degree)
-    c = GalacticCoordinates(l, b)  # only accepts Angle objects *not RA/Dec
-    with raises(TypeError):
-        GalacticCoordinates(ra, dec)
+    c = Galactic(l, b)  # accepts Angle objects and Longitude/Latitude
+    d = Galactic(ra, dec)
 
-    assert isinstance(c.l, Angle)  # *not* RA or Dec
-    assert isinstance(c.b, Angle)  # *not* RA or Dec
+    #make sure Galactic has a working repr
+    repr(c)
+
+    assert isinstance(c.l, Angle)  # *not* Longitude or Latitude
+    assert isinstance(c.b, Angle)  # *not* Longitude or Latitude
 
     #some coordinates require an equinox - this is given as an astropy.time.Time
     from ...time import Time
@@ -569,15 +478,22 @@ def test_create_coordinate():
     alt = Angle(20.5, unit=u.degree)
     az = Angle(45, unit=u.degree)
     timeobj = Time('J2000', scale='utc')
-    HorizontalCoordinates(alt, az, equinox=timeobj)
+    AltAz(alt, az, equinox=timeobj)
 
     #some also have an option for an observation time
-    ICRSCoordinates(12, 13, unit=(u.hour, u.degree), obstime=timeobj)
+    ICRS(12, 13, unit=(u.hour, u.degree), obstime=timeobj)
 
     #passing in a non-time object give a TypeError
     with raises(TypeError):
-        ICRSCoordinates(12, 13, unit=(u.hour, u.degree), obstime=2000.)
+        ICRS(12, 13, unit=(u.hour, u.degree), obstime=2000.)
 
+    #should also be able to initialize coordinates from other coord objects
+    ICRS(ICRS(ra, dec))
+    newi = ICRS(c) # including from other types like Galactic
+    # and it will auto-convert
+    assert isinstance(newi, ICRS)
+    assert newi.ra != c.l
+    assert newi.dec != c.b
 
 
 def test_convert_api():
@@ -585,41 +501,41 @@ def test_convert_api():
     Tests the basic coordinate conversion functionality.
     """
 
-    from .. import Angle, RA, Dec, ICRSCoordinates, GalacticCoordinates, HorizontalCoordinates
+    from .. import Angle, Longitude, Latitude, ICRS, Galactic, AltAz
     from ..transformations import coordinate_alias, transform_function, master_transform_graph
 
     '''
     Coordinate conversion occurs on-demand internally
     '''
 
-    ra = RA("4:08:15.162342", unit=u.hour)
-    dec = Dec("-41:08:15.162342", unit=u.degree)
-    c = ICRSCoordinates(ra=ra, dec=dec)
+    ra = Longitude("4:08:15.162342", unit=u.hour)
+    dec = Latitude("-41:08:15.162342", unit=u.degree)
+    c = ICRS(ra=ra, dec=dec)
 
-    npt.assert_almost_equal(c.galactic.l.degrees, -114.71902, 5)
+    npt.assert_allclose(c.galactic.l.degree, 245.28098, 5)
     assert isinstance(c.galactic.b, Angle)
-    npt.assert_almost_equal(c.galactic.b.degrees, -47.554501, 5)
+    npt.assert_allclose(c.galactic.b.degree, -47.554501, 5)
 
     # can also explicitly specify a coordinate class to convert to
-    gal = c.transform_to(GalacticCoordinates)
+    gal = c.transform_to(Galactic)
 
     # can still convert back to equatorial using the shorthand
-    assert gal.icrs.ra.format(unit=u.hour, sep=":",
-                              precision=2) == '4:08:15.16'
+    assert gal.icrs.ra.to_string(unit=u.hour, sep=":",
+                                 precision=2) == '4:08:15.16'
 
     with raises(ConvertError):
         # there's no way to convert to alt/az without a specified location
-        c.transform_to(HorizontalCoordinates)
+        c.transform_to(AltAz)
 
     # users can specify their own coordinates and conversions
     @coordinate_alias('my_coord')
-    class CustomCoordinates(ICRSCoordinates):
+    class CustomCoordinates(ICRS):
         pass
 
-    @transform_function(ICRSCoordinates, CustomCoordinates)
+    @transform_function(ICRS, CustomCoordinates)
     def icrs_to_custom(icrs_coo):
-        return CustomCoordinates(icrs_coo.ra.degrees,
-                                 icrs_coo.dec.degrees + 2.5,
+        return CustomCoordinates(icrs_coo.ra.degree,
+                                 icrs_coo.dec.degree + 2.5,
                                  unit=(u.degree, u.degree))
 
     try:
@@ -631,7 +547,7 @@ def test_convert_api():
         assert isinstance(mycoord2, CustomCoordinates)
     finally:
         #be sure to remove the registered transform
-        master_transform_graph._graph[ICRSCoordinates][CustomCoordinates].unregister()
+        master_transform_graph._graph[ICRS][CustomCoordinates].unregister()
 
 
 def test_proj_separations():
@@ -639,22 +555,22 @@ def test_proj_separations():
     Test angular separation functionality
     """
 
-    from .. import ICRSCoordinates, GalacticCoordinates, AngularSeparation, coordinate_alias
+    from .. import ICRS, Galactic, coordinate_alias, Angle
 
     '''
     Angular separations between two points on a sphere are supported via the
     `separation` method.
     '''
 
-    c1 = ICRSCoordinates(ra=0, dec=0, unit=(u.degree, u.degree))
-    c2 = ICRSCoordinates(ra=0, dec=1, unit=(u.degree, u.degree))
+    c1 = ICRS(ra=0, dec=0, unit=(u.degree, u.degree))
+    c2 = ICRS(ra=0, dec=1, unit=(u.degree, u.degree))
 
     sep = c2.separation(c1)
-    #returns an AngularSeparation object (a subclass of Angle)
-    assert isinstance(sep, AngularSeparation)
+    #returns an Angle object
+    assert isinstance(sep, Angle)
 
-    assert sep.degrees == 1
-    assert sep.arcmins == 60.
+    assert sep.degree == 1
+    npt.assert_allclose(sep.arcminute, 60.)
 
     # these operations have ambiguous interpretations for points on a sphere
     with raises(TypeError):
@@ -662,19 +578,19 @@ def test_proj_separations():
     with raises(TypeError):
         c1 - c2
 
-    ngp = GalacticCoordinates(l=0, b=90, unit=(u.degree, u.degree))
-    ncp = ICRSCoordinates(ra=0, dec=90, unit=(u.degree, u.degree))
+    ngp = Galactic(l=0, b=90, unit=(u.degree, u.degree))
+    ncp = ICRS(ra=0, dec=90, unit=(u.degree, u.degree))
 
     # if there is a defined conversion between the relevant coordinate systems,
     # it will be automatically performed to get the right angular separation
-    npt.assert_almost_equal(ncp.separation(ngp.icrs).degrees, ncp.separation(ngp).degrees)
+    npt.assert_allclose(ncp.separation(ngp.icrs).degree, ncp.separation(ngp).degree)
 
     # distance from the north galactic pole to celestial pole
-    npt.assert_almost_equal(ncp.separation(ngp.icrs).degrees, 62.8716627659)
+    npt.assert_allclose(ncp.separation(ngp.icrs).degree, 62.8716627659)
 
 
     @coordinate_alias('my_coord2')
-    class CustomCoordinate(ICRSCoordinates):
+    class CustomCoordinate(ICRS):
         pass  # does not specify a coordinate transform
 
     c4 = CustomCoordinate(0, 0, unit=(u.degree, u.degree))
@@ -689,7 +605,7 @@ def test_distances():
     Tests functionality for Coordinate class distances and cartesian
     transformations.
     """
-    from .. import Distance, ICRSCoordinates, GalacticCoordinates, CartesianPoints
+    from .. import Distance, ICRS, Galactic, CartesianPoints
     from ...cosmology import WMAP5, WMAP7
 
     '''
@@ -703,16 +619,16 @@ def test_distances():
     d3 = Distance(value=5, unit=u.kpc)
 
     # need to provide a unit
-    with raises(UnitsError):
+    with raises(u.UnitsError):
         Distance(12)
 
     # standard units are pre-defined
-    npt.assert_almost_equal(distance.lightyear, 39.138765325702551)
-    npt.assert_almost_equal(distance.km, 370281309776063.0)
+    npt.assert_allclose(distance.lyr, 39.138765325702551)
+    npt.assert_allclose(distance.km, 370281309776063.0)
 
     # Coordinate objects can be assigned a distance object, giving them a full
     # 3D position
-    c = GalacticCoordinates(l=158.558650, b=-43.350066, unit=(u.degree, u.degree))
+    c = Galactic(l=158.558650, b=-43.350066, unit=(u.degree, u.degree))
     c.distance = Distance(12, u.parsec)
 
     #can also set distances using tuple-format
@@ -729,19 +645,19 @@ def test_distances():
     # Coordinate objects can be initialized with a distance using special
     # syntax
     #TODO: use this commented line once quantity is in
-    #c1 = GalacticCoordinates(l=158.558650, b=-43.350066, unit=u.degree, distance=12 * u.kpc)
-    c1 = GalacticCoordinates(l=158.558650, b=-43.350066,
+    #c1 = Galactic(l=158.558650, b=-43.350066, unit=u.degree, distance=12 * u.kpc)
+    c1 = Galactic(l=158.558650, b=-43.350066,
         unit=(u.degree, u.degree), distance=Distance(12, u.kpc))
 
     # Coordinate objects can be instantiated with cartesian coordinates
     # Internally they will immediately be converted to two angles + a distance
-    c2 = GalacticCoordinates(x=2, y=4, z=8, unit=u.parsec)
+    c2 = Galactic(x=2, y=4, z=8, unit=u.parsec)
 
     sep12 = c1.separation_3d(c2)
     # returns a *3d* distance between the c1 and c2 coordinates
     # not that this does *not*
     assert isinstance(sep12, Distance)
-    npt.assert_almost_equal(sep12.pc, 12005.784163916317, 10)
+    npt.assert_allclose(sep12.pc, 12005.784163916317, 10)
 
     '''
     All spherical coordinate systems with distances can be converted to
@@ -750,35 +666,38 @@ def test_distances():
 
     (x, y, z) = (c2.x, c2.y, c2.z)
     #this only computes the CartesianPoints *once*, and then caches it
-    npt.assert_almost_equal(x, 2)
-    npt.assert_almost_equal(y, 4)
-    npt.assert_almost_equal(z, 8)
+    #note that the x/y/z are Quantity objects
+    assert isinstance(x, u.Quantity)
+    npt.assert_allclose(x.value, 2)
+    npt.assert_allclose(y.value, 4)
+    npt.assert_allclose(z.value, 8)
 
     cpt = c2.cartesian
     assert isinstance(cpt, CartesianPoints)
-    npt.assert_almost_equal(cpt.x, 2)
-    npt.assert_almost_equal(cpt.y, 4)
-    npt.assert_almost_equal(cpt.z, 8)
+    npt.assert_allclose(cpt.x.value, 2)
+    npt.assert_allclose(cpt.y.value, 4)
+    npt.assert_allclose(cpt.z.value, 8)
 
     # with no distance, the unit sphere is assumed when converting to cartesian
-    c3 = GalacticCoordinates(l=158.558650, b=-43.350066, unit=(u.degree, u.degree), distance=None)
+    c3 = Galactic(l=158.558650, b=-43.350066, unit=(u.degree, u.degree), distance=None)
     unitcart = c3.cartesian
-    npt.assert_almost_equal((unitcart.x**2 + unitcart.y**2 + unitcart.z**2)**0.5, 1.0)
+    npt.assert_allclose(((unitcart.x**2 + unitcart.y**2 +
+                          unitcart.z**2)**0.5).value, 1.0)
 
     # CartesianPoints objects can be added and subtracted, which are
     # vector/elementwise they can also be given as arguments to a coordinate
     # system
-    csum = ICRSCoordinates(c1.cartesian + c2.cartesian)
+    csum = ICRS(c1.cartesian + c2.cartesian)
 
-    npt.assert_almost_equal(csum.x, -8.12016610185)
-    npt.assert_almost_equal(csum.y, 3.19380597435)
-    npt.assert_almost_equal(csum.z, -8.2294483707)
-    npt.assert_almost_equal(csum.ra.degrees, 158.529401774)
-    npt.assert_almost_equal(csum.dec.degrees, -43.3235825777)
-    npt.assert_almost_equal(csum.distance.kpc, 11.9942200501)
+    npt.assert_allclose(csum.x.value, -8.12016610185)
+    npt.assert_allclose(csum.y.value, 3.19380597435)
+    npt.assert_allclose(csum.z.value, -8.2294483707)
+    npt.assert_allclose(csum.ra.degree, 158.529401774)
+    npt.assert_allclose(csum.dec.degree, -43.3235825777)
+    npt.assert_allclose(csum.distance.kpc, 11.9942200501)
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(str('not HAS_SCIPY'))
 def test_distances_scipy():
     """
     The distance-related tests that require scipy due to the cosmology
@@ -787,12 +706,15 @@ def test_distances_scipy():
     from .. import Distance
     from ...cosmology import WMAP5
 
-    #try all the different ways to initialize a Distance
+    #try different ways to initialize a Distance
     d4 = Distance(z=0.23)  # uses default cosmology - as of writing, WMAP7
-    d5 = Distance(z=0.23, cosmology=WMAP5)
+    npt.assert_allclose(d4.z, 0.23, rtol=1e-8)
 
-    assert abs(d4.z - 0.23) < 1e-8  # redshift, assuming "current" cosmology
-    assert abs(d5.compute_z(WMAP5) - 0.23) < 1e-8 # specifying a cosmology possible
+    d5 = Distance(z=0.23, cosmology=WMAP5)
+    npt.assert_allclose(d5.compute_z(WMAP5), 0.23, rtol=1e-8)
+
+    d6 = Distance(z=0.23, cosmology=WMAP5, unit=u.km)
+    npt.assert_allclose(d6.value, 3.5417046898762366e+22)
 
 
 def test_unicode():
@@ -801,6 +723,6 @@ def test_unicode():
     is not `utf-8` -- but given a recent fix, is expected to pass on
     all platforms.
     """
-    from .. import ICRSCoordinates
-    u = unicode("12h46m11.086s -00d30m11.99s")
-    c = ICRSCoordinates(u)
+    from .. import ICRS
+    u = six.text_type("12h46m11.086s -00d30m11.99s")
+    c = ICRS(u)
