@@ -7,10 +7,22 @@ implementation is actually in individual coordinates in the
 `builtin_systems` module, while this module provides the framework and
 related utilities.
 """
+
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
+
+from ..extern import six
+
+import heapq
+import inspect
+import subprocess
+
 from abc import ABCMeta, abstractmethod
+from collections import defaultdict
 
 import numpy as np
 
+
 __all__ = ['StaticMatrixTransform', 'FunctionTransform',
            'DynamicMatrixTransform', 'CompositeStaticMatrixTransform',
            'static_transform_matrix', 'transform_function',
@@ -24,8 +36,6 @@ class TransformGraph(object):
     """
 
     def __init__(self):
-        from collections import defaultdict
-
         self._graph = defaultdict(dict)
         self._clsaliases = {}
 
@@ -51,13 +61,12 @@ class TransformGraph(object):
             If `fromsys` or `tosys` are not classes or `transform` is
             not callable.
         """
-        from inspect import isclass
 
-        if not isclass(fromsys):
+        if not inspect.isclass(fromsys):
             raise TypeError('fromsys must be a class')
-        if not isclass(tosys):
+        if not inspect.isclass(tosys):
             raise TypeError('tosys must be a class')
-        if not callable(transform):
+        if not six.callable(transform):
             raise TypeError('transform must be callable')
 
         self._graph[fromsys][tosys] = transform
@@ -134,7 +143,6 @@ class TransformGraph(object):
             priorities are not set this is the number of trasnforms
             needed. Is `inf` if there is no possible path.
         """
-        import heapq
 
         inf = float('inf')
 
@@ -202,6 +210,9 @@ class TransformGraph(object):
             else:
                 result[n] = (path, d)
                 path.append(n)
+                if n not in edgeweights:
+                    # this is a system that can be transformed to, but not from.
+                    continue
                 for n2 in edgeweights[n]:
                     if n2 not in result:  # already visited
                         # find where n2 is in the heap
@@ -288,11 +299,10 @@ class TransformGraph(object):
         ValueError
             If `coordcls` already has a name assigned.
         """
-        if coordcls in self._clsaliases.values():
-            idx = self._clsaliases.values().index(coordcls)
-            oldnm = self._clsaliases.keys()[idx]
-            msg = 'Coordinate class {0} already has a name: {1}'
-            raise ValueError(msg.format(coordcls, oldnm))
+        for key, val in six.iteritems(self._clsaliases):
+            if val == coordcls:
+                msg = 'Coordinate class {0} already has a name: {1}'
+                raise ValueError(msg.format(coordcls, key))
         self._clsaliases[name] = coordcls
 
     def lookup_name(self, name):
@@ -322,7 +332,7 @@ class TransformGraph(object):
         nms : list
             The aliases for coordinate systems.
         """
-        return self._clsaliases.keys()
+        return list(six.iterkeys(self._clsaliases))
 
     def to_dot_graph(self, priorities=True, addnodes=[], savefn=None,
                      savelayout='plain', saveformat=None):
@@ -358,7 +368,6 @@ class TransformGraph(object):
 
         .. _graphviz: http://www.graphviz.org/
         """
-        from subprocess import Popen, PIPE
 
         nodes = []
         # find the node names
@@ -372,7 +381,7 @@ class TransformGraph(object):
             if node not in nodes:
                 nodes.append(node)
         nodenames = []
-        invclsaliases = dict([(v, k) for k, v in self._clsaliases.iteritems()])
+        invclsaliases = dict([(v, k) for k, v in six.iteritems(self._clsaliases)])
         for n in nodes:
             if n in invclsaliases:
                 nodenames.append('{0} [shape=oval label="{0}\\n`{1}`"]'.format(n.__name__, invclsaliases[n]))
@@ -406,7 +415,9 @@ class TransformGraph(object):
                 args = [savelayout]
                 if saveformat is not None:
                     args.append('-T' + saveformat)
-                proc = Popen(args, stdin=PIPE, stdout=PIPE, stderr=PIPE)
+                proc = subprocess.Popen(args, stdin=subprocess.PIPE,
+                                        stdout=subprocess.PIPE,
+                                        stderr=subprocess.PIPE)
                 stdout, stderr = proc.communicate(dotgraph)
                 if proc.returncode != 0:
                     raise IOError('problem running graphviz: \n' + stderr)
@@ -455,6 +466,7 @@ class TransformGraph(object):
 master_transform_graph = TransformGraph()
 
 
+@six.add_metaclass(ABCMeta)
 class CoordinateTransform(object):
     """
     An object that transforms a coordinate from one system to another.
@@ -463,11 +475,7 @@ class CoordinateTransform(object):
     `__init__`.
     """
 
-    __metaclass__ = ABCMeta
-
     def __init__(self, fromsys, tosys, register=True):
-        from inspect import isclass
-
         self.fromsys = fromsys
         self.tosys = tosys
 
@@ -475,7 +483,7 @@ class CoordinateTransform(object):
             # this will do the type-checking
             self.register()
         else:
-            if not isclass(fromsys) or not isclass(tosys):
+            if not inspect.isclass(fromsys) or not inspect.isclass(tosys):
                 raise TypeError('fromsys and tosys must be classes')
 
     def register(self):
@@ -543,7 +551,7 @@ class FunctionTransform(CoordinateTransform):
                  register=True):
         from inspect import getargspec
 
-        if not callable(func):
+        if not six.callable(func):
             raise TypeError('func must be callable')
 
         try:
@@ -584,7 +592,7 @@ class StaticMatrixTransform(CoordinateTransform):
         The coordinate system *class* to start from.
     tosys : class
         The coordinate system *class* to transform into.
-    matrix: array-like
+    matrix : array-like
         A 3 x 3 matrix for transforming 3-vectors. In most cases will
         be unitary (although this is not strictly required).
     priority : number
@@ -604,12 +612,17 @@ class StaticMatrixTransform(CoordinateTransform):
         self.priority = priority
         super(StaticMatrixTransform, self).__init__(fromsys, tosys)
 
-    # TODO: array: this needs some extra bits to do the broadcasting right
     def __call__(self, fromcoord):
-        v = [fromcoord.x, fromcoord.y, fromcoord.z]
-        x, y, z = np.dot(np.asarray(self.matrix), v)
-        unit = None if fromcoord.distance is None else fromcoord.distance._unit
-        result = self.tosys(x=x, y=y, z=z, unit=unit)
+        c = fromcoord.cartesian
+        v = c.reshape((3, c.size // 3))
+        v2 = np.dot(np.asarray(self.matrix), v)
+        subshape = c.shape[1:]
+        x = v2[0].reshape(subshape)
+        y = v2[1].reshape(subshape)
+        z = v2[2].reshape(subshape)
+
+        newunit = None if fromcoord.distance is None else fromcoord.distance.unit
+        result = self.tosys(x=x, y=y, z=z, unit=newunit)
 
         # copy over the observation time
         if hasattr(fromcoord, '_obstime') and hasattr(result, '_obstime'):
@@ -629,7 +642,7 @@ class CompositeStaticMatrixTransform(StaticMatrixTransform):
         The coordinate system *class* to start from.
     tosys : class
         The coordinate system *class* to transform into.
-    matrices: sequence of array-like
+    matrices : sequence of array-like
         A sequence of 3 x 3 cartesian transformation matricies.
     priority : number
         The priority if this transform when finding the shortest
@@ -645,9 +658,9 @@ class CompositeStaticMatrixTransform(StaticMatrixTransform):
         matrix = np.array(self.matricies[0])
         if len(self.matricies) > 1:
             for m in self.matricies[1:]:
-                matrix = np.dot(np.asarray(self.matrix), m)
+                matrix = np.dot(np.asarray(matrix), m)
 
-        super(CompositeStaticMatrixTransform, self).__init__(self, fromsys,
+        super(CompositeStaticMatrixTransform, self).__init__(fromsys,
             tosys, matrix, priority)
 
 
@@ -662,7 +675,7 @@ class DynamicMatrixTransform(CoordinateTransform):
         The coordinate system *class* to start from.
     tosys : class
         The coordinate system *class* to transform into.
-    matrix_func: callable
+    matrix_func : callable
         A callable that accepts a coordinate object and yields the 3 x 3
         matrix that converts it to the new coordinate system.
     priority : number
@@ -676,18 +689,23 @@ class DynamicMatrixTransform(CoordinateTransform):
 
     """
     def __init__(self, fromsys, tosys, matrix_func, priority=1, register=True):
-        if not callable(matrix_func):
+        if not six.callable(matrix_func):
             raise TypeError('matrix_func is not callable')
         self.matrix_func = matrix_func
         self.priority = priority
         super(DynamicMatrixTransform, self).__init__(fromsys, tosys, register)
 
-    # TODO: array: this needs some extra bits to do the broadcasting right
     def __call__(self, fromcoord):
-        v = [fromcoord.x, fromcoord.y, fromcoord.z]
-        x, y, z = np.dot(np.asarray(self.matrix_func(fromcoord)), v)
-        unit = None if fromcoord.distance is None else fromcoord.distance._unit
-        result = self.tosys(x=x, y=y, z=z, unit=unit)
+        c = fromcoord.cartesian
+        v = c.reshape((3, c.size // 3))
+        v2 = np.dot(np.asarray(self.matrix_func(fromcoord)), v)
+        subshape = c.shape[1:]
+        x = v2[0].reshape(subshape)
+        y = v2[1].reshape(subshape)
+        z = v2[2].reshape(subshape)
+
+        newunit = None if fromcoord.distance is None else fromcoord.distance.unit
+        result = self.tosys(x=x, y=y, z=z, unit=newunit)
 
         # copy over the observation time
         if hasattr(fromcoord, '_obstime') and hasattr(result, '_obstime'):
@@ -707,7 +725,7 @@ class CompositeTransform(CoordinateTransform):
         The coordinate system *class* to start from.
     tosys : class
         The coordinate system *class* to transform into.
-    transforms: sequence of `CoordinateTransform`s
+    transforms : sequence of `CoordinateTransform`s
         A sequence of transformations to apply in sequence.
     priority : number
         The priority if this transform when finding the shortest
