@@ -3,10 +3,6 @@
 Convenience functions for `astropy.cosmology`.
 """
 from .core import get_current as _get_current
-from math import pi as _pi
-
-_arcsec_in_radians = 1 / 3600. * _pi / 180
-_arcmin_in_radians = 1 / 60. * _pi / 180
 
 
 def kpc_comoving_per_arcmin(z, cosmo=None):
@@ -20,15 +16,13 @@ def kpc_comoving_per_arcmin(z, cosmo=None):
 
     Returns
     -------
-    d : ndarray, or float if input scalar
+    d : astropy.units.Quantity
       The distance in comoving kpc corresponding to an arcmin at each
       input redshift.
     """
-
-
     if cosmo is None:
         cosmo = _get_current()
-    return cosmo.comoving_transverse_distance(z) * 1.e3 * _arcmin_in_radians
+    return cosmo.kpc_comoving_per_arcmin(z)
 
 
 def kpc_proper_per_arcmin(z, cosmo=None):
@@ -42,13 +36,13 @@ def kpc_proper_per_arcmin(z, cosmo=None):
 
     Returns
     -------
-    d : ndarray, or float if input scalar
+    d : astropy.units.Quantity
       The distance in proper kpc corresponding to an arcmin at each
       input redshift.
     """
     if cosmo is None:
         cosmo = _get_current()
-    return cosmo.angular_diameter_distance(z) * 1.e3 * _arcmin_in_radians
+    return cosmo.kpc_proper_per_arcmin(z)
 
 
 def arcsec_per_kpc_comoving(z, cosmo=None):
@@ -62,14 +56,13 @@ def arcsec_per_kpc_comoving(z, cosmo=None):
 
     Returns
     -------
-    theta : ndarray, or float if input scalar
+    theta : astropy.units.Quantity
       The angular separation in arcsec corresponding to a comoving kpc
       at each input redshift.
     """
     if cosmo is None:
         cosmo = _get_current()
-    return 1 / (cosmo.comoving_transverse_distance(z) *
-                1.e3 * _arcsec_in_radians)
+    return cosmo.arcsec_per_kpc_comoving(z)
 
 
 def arcsec_per_kpc_proper(z, cosmo=None):
@@ -83,18 +76,21 @@ def arcsec_per_kpc_proper(z, cosmo=None):
 
     Returns
     -------
-    theta : ndarray, or float if input scalar
+    theta : astropy.units.Quantity
       The angular separation in arcsec corresponding to a proper kpc
       at each input redshift.
     """
     if cosmo is None:
         cosmo = _get_current()
-    return 1 / (cosmo.angular_diameter_distance(z) * 1.e3 * _arcsec_in_radians)
+    return cosmo.arcsec_per_kpc_proper(z)
 
 
 def distmod(z, cosmo=None):
     """ Distance modulus at redshift `z`.
 
+    The distance modulus is defined as the (apparent magnitude -
+    absolute magnitude) for an object at redshift `z`.
+
     Parameters
     ----------
     z : array_like
@@ -102,7 +98,7 @@ def distmod(z, cosmo=None):
 
     Returns
     -------
-    distmod : ndarray, or float if input scalar
+    distmod : astropy.units.Quantity
       Distance modulus at each input redshift.
     """
     if cosmo is None:
@@ -110,7 +106,7 @@ def distmod(z, cosmo=None):
     return cosmo.distmod(z)
 
 
-def H(z=0, cosmo=None):
+def H(z, cosmo=None):
     """ Hubble parameter (km/s/Mpc) at redshift `z`.
 
     Parameters
@@ -120,7 +116,7 @@ def H(z=0, cosmo=None):
 
     Returns
     -------
-    H : ndarray, or float if input scalar
+    H : astropy.units.Quantity
       Hubble parameter at each input redshift.
     """
     if cosmo is None:
@@ -128,9 +124,11 @@ def H(z=0, cosmo=None):
     return cosmo.H(z)
 
 
-def scale_factor(z=0, cosmo=None):
+def scale_factor(z, cosmo=None):
     """ Scale factor at redshift `z`.
 
+    The scale factor is defined as `a = 1 / (1 + z)`.
+
     Parameters
     ----------
     z : array_like
@@ -138,7 +136,7 @@ def scale_factor(z=0, cosmo=None):
 
     Returns
     -------
-    distmod : ndarray, or float if input scalar
+    scalefac : ndarray, or float if input scalar
       Scale factor at each input redshift.
     """
     if cosmo is None:
@@ -146,7 +144,7 @@ def scale_factor(z=0, cosmo=None):
     return cosmo.scale_factor(z)
 
 
-def critical_density(z=0, cosmo=None):
+def critical_density(z, cosmo=None):
     """ Critical density in grams per cubic cm at redshift `z`.
 
     Parameters
@@ -156,7 +154,7 @@ def critical_density(z=0, cosmo=None):
 
     Returns
     -------
-    critdens : ndarray, or float if input scalar
+    critdens : astropy.units.Quantity
       Critical density at each input redshift.
     """
     if cosmo is None:
@@ -164,9 +162,12 @@ def critical_density(z=0, cosmo=None):
     return cosmo.critical_density(z)
 
 
-def lookback_time(z=0, cosmo=None):
+def lookback_time(z, cosmo=None):
     """ Lookback time in Gyr to redshift `z`.
 
+    The lookback time is the difference between the age of the
+    Universe now and the age at redshift `z`.
+
     Parameters
     ----------
     z : array_like
@@ -174,7 +175,7 @@ def lookback_time(z=0, cosmo=None):
 
     Returns
     -------
-    t : ndarray, or float if input scalar
+    t : astropy.units.Quantity
       Lookback time at each input redshift.
     """
     if cosmo is None:
@@ -182,9 +183,12 @@ def lookback_time(z=0, cosmo=None):
     return cosmo.lookback_time(z)
 
 
-def comoving_distance(z=0, cosmo=None):
+def comoving_distance(z, cosmo=None):
     """ Comoving distance in Mpc at redshift `z`.
 
+    The comoving distance along the line-of-sight between two objects
+    remains constant with time for objects in the Hubble flow.
+
     Parameters
     ----------
     z : array_like
@@ -192,7 +196,7 @@ def comoving_distance(z=0, cosmo=None):
 
     Returns
     -------
-    codist : ndarray, or float if input scalar
+    codist : astropy.units.Quantity
       Comoving distance at each input redshift.
     """
     if cosmo is None:
@@ -200,9 +204,13 @@ def comoving_distance(z=0, cosmo=None):
     return cosmo.comoving_distance(z)
 
 
-def angular_diameter_distance(z=0, cosmo=None):
+def angular_diameter_distance(z, cosmo=None):
     """ Angular diameter distance in Mpc at a given redshift.
 
+    This gives the proper (sometimes called 'physical') transverse
+    distance corresponding to an angle of 1 radian for an object at
+    redshift `z`.
+
     Parameters
     ----------
     z : array_like
@@ -210,7 +218,7 @@ def angular_diameter_distance(z=0, cosmo=None):
 
     Returns
     -------
-    angdist : ndarray, or float if input scalar
+    angdist : astropy.units.Quantity
       Angular diameter distance at each input redshift.
     """
     if cosmo is None:
@@ -218,8 +226,11 @@ def angular_diameter_distance(z=0, cosmo=None):
     return cosmo.angular_diameter_distance(z)
 
 
-def luminosity_distance(z=0, cosmo=None):
-    """ Angular diameter distance in Mpc at a given redshift.
+def luminosity_distance(z, cosmo=None):
+    """ Luminosity distance in Mpc at redshift `z`.
+
+    This is the distance to use when converting between the bolometric
+    flux from an object at redshift `z` and its bolometric luminosity.
 
     Parameters
     ----------
@@ -228,8 +239,8 @@ def luminosity_distance(z=0, cosmo=None):
 
     Returns
     -------
-    lumdist : ndarray, or float if input scalar
-      Angular diameter distance at each input redshift.
+    lumdist : astropy.units.Quantity
+      Luminosity distance at each input redshift.
     """
     if cosmo is None:
         cosmo = _get_current()
