@@ -38,6 +38,10 @@ import re
 from . import core
 from . import fixedwidth
 
+
+__doctest_skip__ = ['*']
+
+
 class CdsHeader(core.BaseHeader):
     col_type_map = {'e': core.FloatType,
                     'f': core.FloatType,
@@ -48,7 +52,7 @@ class CdsHeader(core.BaseHeader):
         match = re.match(r'\d*(\S)', col.raw_type.lower())
         if not match:
             raise ValueError('Unrecognized CDS format "%s" for column "%s"' % (
-                    col.raw_type, col.name))
+                col.raw_type, col.name))
         return match.group(1)
 
     def __init__(self, readme=None):
@@ -77,7 +81,7 @@ class CdsHeader(core.BaseHeader):
         # me file ``self.readme``.
         if self.readme and self.data.table_name:
             in_header = False
-            f = open(self.readme,"r")
+            f = open(self.readme, "r")
             # Header info is not in data lines but in a separate file.
             lines = []
             comment_lines = 0
@@ -86,16 +90,16 @@ class CdsHeader(core.BaseHeader):
                 if in_header:
                     lines.append(line)
                     if line.startswith('------') or line.startswith('======='):
-                         comment_lines += 1
-                         if comment_lines == 3:
-                             break
+                        comment_lines += 1
+                        if comment_lines == 3:
+                            break
                 else:
                     match = re.match(r'Byte-by-byte Description of file: (?P<name>.+)$',
-                            line, re.IGNORECASE)
+                                     line, re.IGNORECASE)
                     if match:
                         # Split 'name' in case in contains multiple files
                         names = [s for s in re.split('[, ]+', match.group('name'))
-                                                                        if s]
+                                 if s]
                         # Iterate on names to find if one matches the tablename
                         # including wildcards.
                         for pattern in names:
@@ -105,12 +109,17 @@ class CdsHeader(core.BaseHeader):
                                 break
 
             else:
-                raise core.InconsistentTableError("Cant' find table {0} in {1}".format(
-                        self.data.table_name, self.readme))
+                raise core.InconsistentTableError("Can't find table {0} in {1}".format(
+                    self.data.table_name, self.readme))
             f.close()
 
+        found_line = False
+
         for i_col_def, line in enumerate(lines):
             if re.match(r'Byte-by-byte Description', line, re.IGNORECASE):
+                found_line = True
+            elif found_line: # First line after list of file descriptions
+                i_col_def -= 1 # Set i_col_def to last description line
                 break
 
         re_col_def = re.compile(r"""\s*
@@ -123,34 +132,39 @@ class CdsHeader(core.BaseHeader):
                                 re.VERBOSE)
 
         cols = []
-        for i, line in enumerate(itertools.islice(lines, i_col_def+4, None)):
+        for line in itertools.islice(lines, i_col_def+4, None):
             if line.startswith('------') or line.startswith('======='):
                 break
             match = re_col_def.match(line)
             if match:
-                col = core.Column(name=match.group('name'), index=i)
-                col.start = int(re.sub(r'[-\s]', '', match.group('start') or match.group('end'))) - 1
+                col = core.Column(name=match.group('name'))
+                col.start = int(re.sub(r'[-\s]', '',
+                                       match.group('start') or match.group('end'))) - 1
                 col.end = int(match.group('end'))
-                col.units = match.group('units')
-                if col.units == '---':
-                    col.units = None  # "---" is the marker for no units in CDS table
+                col.unit = match.group('units')
+                if col.unit == '---':
+                    col.unit = None  # "---" is the marker for no unit in CDS table
                 col.description = match.group('descr').strip()
                 col.raw_type = match.group('format')
                 col.type = self.get_col_type(col)
 
-                match = re.match(r'\? (?P<equal> =)? (?P<nullval> \S*)', col.description, re.VERBOSE)
+                match = re.match(
+                    r'\? (?P<equal> =)? (?P<nullval> \S*)', col.description, re.VERBOSE)
                 if match:
                     if issubclass(col.type, core.FloatType):
                         fillval = 'nan'
                     else:
-                        fillval = '-999'
-                    if match.group('nullval') == '':
-                        col.null = ''
-                    elif match.group('nullval') == '-':
+                        fillval = '0'
+                    
+                    if match.group('nullval') == '-':
                         col.null = '---'
+                        # CDS tables can use -, --, ---, or ---- to mark missing values
+                        # see https://github.com/astropy/astropy/issues/1335
+                        for i in [1, 2, 3, 4]:
+                            self.data.fill_values.append(('-'*i, fillval, col.name))
                     else:
                         col.null = match.group('nullval')
-                    self.data.fill_values.append((col.null, fillval, col.name))
+                        self.data.fill_values.append((col.null, fillval, col.name))
 
                 cols.append(col)
             else:  # could be a continuation of the previous col's description
@@ -160,19 +174,8 @@ class CdsHeader(core.BaseHeader):
                     raise ValueError('Line "%s" not parsable as CDS header' % line)
 
         self.names = [x.name for x in cols]
-        names = set(self.names)
-        if self.include_names is not None:
-            names.intersection_update(self.include_names)
-        if self.exclude_names is not None:
-            names.difference_update(self.exclude_names)
 
-        self.cols = [x for x in cols if x.name in names]
-        self.n_data_cols = len(self.cols)
-
-        # Re-index the cols because the FixedWidthSplitter does NOT return the ignored
-        # cols (as is the case for typical delimiter-based splitters)
-        for i, col in enumerate(self.cols):
-            col.index = i
+        self.cols = cols
 
 
 class CdsData(core.BaseData):
@@ -192,7 +195,7 @@ class CdsData(core.BaseData):
                       if x.startswith('------') or x.startswith('=======')]
         if not i_sections:
             raise core.InconsistentTableError('No CDS section delimiter found')
-        return lines[i_sections[-1]+1 : ]
+        return lines[i_sections[-1]+1:]
 
 
 class Cds(core.BaseReader):
@@ -279,13 +282,15 @@ class Cds(core.BaseReader):
 
     Caveats:
 
-    * Format, Units, and Explanations are available in the ``Reader.cols`` attribute.
-    * All of the other metadata defined by this format is ignored.
-
-    Code contribution to enhance the parsing to include metadata in a Reader.meta
-    attribute would be welcome.
-
+    * The Units and Explanations are available in the column ``unit`` and
+      ``description`` attributes, respectively.
+    * The other metadata defined by this format is not available in the output table.
     """
+    _format_name = 'cds'
+    _io_registry_format_aliases = ['cds']
+    _io_registry_can_write = False
+    _description = 'CDS format table'
+
     def __init__(self, readme=None):
         core.BaseReader.__init__(self)
         self.header = CdsHeader(readme)
