@@ -10,7 +10,7 @@ ui.py:
 
 ## Copyright (c) 2010, Smithsonian Astrophysical Observatory
 ## All rights reserved.
-## 
+##
 ## Redistribution and use in source and binary forms, with or without
 ## modification, are permitted provided that the following conditions are met:
 ##     * Redistributions of source code must retain the above copyright
@@ -21,7 +21,7 @@ ui.py:
 ##     * Neither the name of the Smithsonian Astrophysical Observatory nor the
 ##       names of its contributors may be used to endorse or promote products
 ##       derived from this software without specific prior written permission.
-## 
+##
 ## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ## ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 ## WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
@@ -30,7 +30,7 @@ ui.py:
 ## (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 ## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ## ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-## (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS  
+## (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 ## SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 import re
@@ -43,13 +43,14 @@ from . import cds
 from . import daophot
 from . import sextractor
 from . import ipac
-from .core import next, izip
 from . import latex
 
 from ...table import Table
 
 # Default setting for guess parameter in read()
 _GUESS = True
+
+
 def set_guess(guess):
     """Set the default value of the ``guess`` parameter for read()
 
@@ -58,12 +59,13 @@ def set_guess(guess):
     global _GUESS
     _GUESS = guess
 
+
 def get_reader(Reader=None, Inputter=None, Outputter=None, **kwargs):
     """Initialize a table reader allowing for common customizations.  Most of the
     default behavior for various parameters is determined by the Reader class.
 
-    :param Reader: Reader class (default= :class:`Basic`)
-    :param Inputter: Inputter class 
+    :param Reader: Reader class (DEPRECATED) (default= :class:`Basic`)
+    :param Inputter: Inputter class
     :param Outputter: Outputter class
     :param delimiter: column delimiter string
     :param comment: regular expression defining a comment line in table
@@ -88,6 +90,20 @@ def get_reader(Reader=None, Inputter=None, Outputter=None, **kwargs):
     reader = core._get_reader(Reader, Inputter=Inputter, Outputter=Outputter, **kwargs)
     return reader
 
+
+def _get_format_class(format, ReaderWriter, label):
+    if format is not None and ReaderWriter is not None:
+        raise ValueError('Cannot supply both format and {0} keywords'.format(label))
+
+    if format is not None:
+        if format in core.FORMAT_CLASSES:
+            ReaderWriter = core.FORMAT_CLASSES[format]
+        else:
+            raise ValueError('ASCII format {0!r} not in allowed list {1}'
+                             .format(format, sorted(core.FORMAT_CLASSES)))
+    return ReaderWriter
+
+
 def read(table, guess=None, **kwargs):
     """Read the input ``table`` and return the table.  Most of
     the default behavior for various parameters is determined by the Reader
@@ -95,9 +111,9 @@ def read(table, guess=None, **kwargs):
 
     :param table: input table (file name, list of strings, or single newline-separated string)
     :param guess: try to guess the table format (default=True)
-    :param Reader: Reader class (default=``ascii.Basic``)
+    :param format: input table format
     :param Inputter: Inputter class
-    :param Outputter: Outputter class
+    :param Outputter: Outputter class (default=TableOutputter)
     :param delimiter: column delimiter string
     :param comment: regular expression defining a comment line in table
     :param quotechar: one-character string to quote fields containing special characters
@@ -110,18 +126,28 @@ def read(table, guess=None, **kwargs):
     :param names: list of names corresponding to each data column
     :param include_names: list of names to include in output (default=None selects all names)
     :param exclude_names: list of names to exlude from output (applied after ``include_names``)
-    :param fill_values: specification of fill values for bad or missing table values
+    :param fill_values: specification of fill values for bad or missing table values (default=('', '0'))
     :param fill_include_names: list of names to include in fill_values (default=None selects all names)
     :param fill_exclude_names: list of names to exlude from fill_values (applied after ``fill_include_names``)
-
+    :param Reader: Reader class (DEPRECATED) (default=``ascii.Basic``)
     """
 
-    # Provide a simple way to choose between the two common outputters.  If an
-    # Outputter is supplied in kwargs that will take precedence.
+    if 'fill_values' not in kwargs:
+        kwargs['fill_values'] = [('', '0')]
+
+    # If an Outputter is supplied in kwargs that will take precedence.
     new_kwargs = {}
     new_kwargs['Outputter'] = core.TableOutputter
     new_kwargs.update(kwargs)
 
+    # Get the Reader class based on possible format and Reader kwarg inputs.
+    Reader = _get_format_class(kwargs.get('format'), kwargs.get('Reader'), 'Reader')
+    if Reader is not None:
+        new_kwargs['Reader'] = Reader
+    # Remove format keyword if there, this is only allowed in read() not get_reader()
+    if 'format' in new_kwargs:
+        del new_kwargs['format']
+
     if guess is None:
         guess = _GUESS
     if guess:
@@ -129,18 +155,10 @@ def read(table, guess=None, **kwargs):
     else:
         reader = get_reader(**new_kwargs)
         dat = reader.read(table)
+
     return dat
 
 
-def _is_number(x):
-    try:
-        x = float(x)
-        return True
-    except ValueError:
-        pass
-    return False
-
-
 def _guess(table, read_kwargs):
     """Try to read the table using various sets of keyword args. First try the
     original args supplied in the read() call. Then try the standard guess
@@ -165,22 +183,23 @@ def _guess(table, read_kwargs):
 
         if not guess_kwargs_ok:
             # User-supplied kwarg is inconsistent with the guess-supplied kwarg, e.g.
-            # user supplies delimiter="|" but the guess wants to try delimiter=" ", 
+            # user supplies delimiter="|" but the guess wants to try delimiter=" ",
             # so skip the guess entirely.
             continue
 
         try:
+            # If guessing will try all Readers then use strict req'ts on column names
+            if 'Reader' not in read_kwargs:
+                guess_kwargs['strict_names'] = True
+
             reader = get_reader(**guess_kwargs)
             dat = reader.read(table)
-            # When guessing impose additional requirements on column names and number of cols
-            bads = [" ", ",", "|", "\t", "'", '"']
-            if (len(reader.cols) <= 1 or
-                any(_is_number(col.name) or 
-                     len(col.name) == 0 or 
-                     col.name[0] in bads or 
-                     col.name[-1] in bads for col in reader.cols)):
+
+            # When guessing require at least two columns
+            if len(dat.colnames) <= 1:
                 raise ValueError
             return dat
+
         except (core.InconsistentTableError, ValueError, TypeError):
             failed_kwargs.append(guess_kwargs)
             pass
@@ -191,18 +210,21 @@ def _guess(table, read_kwargs):
             return reader.read(table)
         except (core.InconsistentTableError, ValueError):
             failed_kwargs.append(read_kwargs)
-            lines = ['\nERROR: Unable to guess table for with the guesses listed below:']
+            lines = ['\nERROR: Unable to guess table format with the guesses listed below:']
             for kwargs in failed_kwargs:
-                sorted_keys = sorted([x for x in sorted(kwargs) if x not in ('Reader', 'Outputter')])
+                sorted_keys = sorted([x for x in sorted(kwargs)
+                                      if x not in ('Reader', 'Outputter')])
                 reader_repr = repr(kwargs.get('Reader', basic.Basic))
                 keys_vals = ['Reader:' + re.search(r"\.(\w+)'>", reader_repr).group(1)]
                 kwargs_sorted = ((key, kwargs[key]) for key in sorted_keys)
                 keys_vals.extend(['%s: %s' % (key, repr(val)) for key, val in kwargs_sorted])
                 lines.append(' '.join(keys_vals))
-            lines.append('ERROR: Unable to guess table for with the guesses listed above.')
-            lines.append('Check the table and try with guess=False and appropriate arguments to read()')
+            lines.append('ERROR: Unable to guess table format with the guesses listed above.')
+            lines.append('Check the table and try with guess=False '
+                         'and appropriate arguments to read()')
             raise core.InconsistentTableError('\n'.join(lines))
-    
+
+
 def _get_guess_kwargs_list():
     guess_kwargs_list = [dict(Reader=basic.Rdb),
                          dict(Reader=basic.Tab),
@@ -223,11 +245,12 @@ def _get_guess_kwargs_list():
 extra_writer_pars = ('delimiter', 'comment', 'quotechar', 'formats',
                      'names', 'include_names', 'exclude_names', 'strip_whitespace')
 
+
 def get_writer(Writer=None, **kwargs):
     """Initialize a table writer allowing for common customizations.  Most of the
     default behavior for various parameters is determined by the Writer class.
 
-    :param Writer: Writer class (default=``ascii.Basic``)
+    :param Writer: Writer class (DEPRECATED) (default=``ascii.Basic``)
     :param delimiter: column delimiter string
     :param write_comment: string defining a comment line in table
     :param quotechar: one-character string to quote fields containing special characters
@@ -244,13 +267,14 @@ def get_writer(Writer=None, **kwargs):
     writer = core._get_writer(Writer, **kwargs)
     return writer
 
-def write(table, output=sys.stdout,  Writer=None, **kwargs):
+
+def write(table, output=None,  format=None, Writer=None, **kwargs):
     """Write the input ``table`` to ``filename``.  Most of the default behavior
     for various parameters is determined by the Writer class.
 
     :param table: input table (Reader object, NumPy struct array, list of lists, etc)
     :param output: output [filename, file-like object] (default = sys.stdout)
-    :param Writer: Writer class (default=``ascii.Basic``)
+    :param format: output format (default=``basic``)
     :param delimiter: column delimiter string
     :param write_comment: string defining a comment line in table
     :param quotechar: one-character string to quote fields containing special characters
@@ -259,25 +283,18 @@ def write(table, output=sys.stdout,  Writer=None, **kwargs):
     :param names: list of names corresponding to each data column
     :param include_names: list of names to include in output (default=None selects all names)
     :param exclude_names: list of names to exlude from output (applied after ``include_names``)
+    :param Writer: Writer class (DEPRECATED) (default=``ascii.Basic``)
     """
+    if output is None:
+        output = sys.stdout
 
     table = Table(table, names=kwargs.get('names'))
 
-    names = set(table.colnames)
-    if 'include_names' in kwargs:
-        names.intersection_update(kwargs['include_names'])
-    if 'exclude_names' in kwargs:
-        names.difference_update(kwargs['exclude_names'])
-    if names != set(table.colnames):
-        remove_names = set(table.colnames) - set(names)
-        table.remove_columns(remove_names)
-
-    table.cols = table.columns.values()
-
+    Writer = _get_format_class(format, Writer, 'Writer')
     writer = get_writer(Writer=Writer, **kwargs)
     lines = writer.write(table)
 
-    # Write the lines to output 
+    # Write the lines to output
     outstr = os.linesep.join(lines)
     if not hasattr(output, 'write'):
         output = open(output, 'w')
@@ -287,4 +304,3 @@ def write(table, output=sys.stdout,  Writer=None, **kwargs):
     else:
         output.write(outstr)
         output.write(os.linesep)
-
