@@ -345,7 +345,7 @@ class _FormatQ(_FormatP):
 
     _format_code = 'Q'
     _format_re = re.compile(_FormatP._format_re_template % _format_code)
-    _descriptor_format = '2l4'
+    _descriptor_format = '2i8'
 
 
 class Column(object):
@@ -776,6 +776,9 @@ class ColDefs(object):
 
         return object.__new__(klass)
 
+    def __getnewargs__(self):
+        return (self._arrays,)
+
     def __init__(self, input, tbtype='BinTableHDU'):
         """
         Parameters
@@ -899,8 +902,8 @@ class ColDefs(object):
         return self.__class__(self, self._tbtype)
 
     def __deepcopy__(self, memo):
-        return self.__class__([copy.deepcopy(c, memo) for c in self.columns],
-                              tbtype=self._tbtype)
+        return self.__class__([copy.deepcopy(c, memo) for c in self.columns
+                               if not c._phantom], tbtype=self._tbtype)
 
     def _copy_column(self, column):
         """Utility function used currently only by _init_from_coldefs
