@@ -18,6 +18,8 @@ from ..util import (_is_int, _tmp_name, fileobj_closed, ignore_sigint,
                     _get_array_mmap)
 from ..verify import _Verify, _ErrList, VerifyError, VerifyWarning
 
+from ....extern.six import string_types
+
 from ....utils import indent
 from ....utils.exceptions import AstropyUserWarning
 
@@ -640,7 +642,7 @@ class HDUList(list, _Verify):
         # make note of whether the input file object is already open, in which
         # case we should not close it after writing (that should be the job
         # of the caller)
-        closed = fileobj_closed(fileobj)
+        closed = isinstance(fileobj, string_types) or fileobj_closed(fileobj)
 
         # writeto is only for writing a new file from scratch, so the most
         # sensible mode to require is 'ostream'.  This can accept an open
