@@ -10,20 +10,20 @@ import re
 import sys
 import warnings
 
+from collections import defaultdict
+
 from .card import Card, CardList, _pad, BLANK_CARD, KEYWORD_LENGTH
 from .file import _File
 from .util import (encode_ascii, decode_ascii, fileobj_mode, fileobj_closed,
                    fileobj_is_binary)
 
+from ...extern import six
 from ...extern.six import PY3, string_types, itervalues, iteritems, next
-from ...extern.six.moves import zip, range
+from ...extern.six.moves import zip, range, zip_longest
 from ...utils import deprecated, isiterable
 from ...utils.exceptions import AstropyUserWarning, AstropyDeprecationWarning
 
 
-PY3K = sys.version_info[:2] >= (3, 0)
-
-
 BLOCK_SIZE = 2880  # the FITS block size
 
 # This regular expression can match a *valid* END card which just consists of
@@ -1788,10 +1788,11 @@ class Header(object):
 
         increment = 1 if increment else -1
 
-        for indices in self._keyword_indices.itervalues():
-            for jdx, keyword_index in enumerate(indices):
-                if keyword_index >= idx:
-                    indices[jdx] += increment
+        for index_sets in (self._keyword_indices, self._rvkc_indices):
+            for indices in itervalues(index_sets):
+                for jdx, keyword_index in enumerate(indices):
+                    if keyword_index >= idx:
+                        indices[jdx] += increment
 
     def _countblanks(self):
         """Returns the number of blank cards at the end of the Header."""
@@ -1944,7 +1945,7 @@ class Header(object):
 
     # Some fixes for compatibility with the Python 3 dict interface, where
     # iteritems -> items, etc.
-    if PY3K:  # pragma: py3
+    if PY3:  # pragma: py3
         keys = iterkeys
         values = itervalues
         items = iteritems
@@ -2110,13 +2111,22 @@ class _CardAccessor(object):
         return iter(self._header._cards)
 
     def __eq__(self, other):
-        if isiterable(other):
-            for a, b in itertools.izip(self, other):
-                if a != b:
-                    return False
+        # If the `other` item is a scalar we will still treat it as equal if
+        # this _CardAccessor only contains one item
+        if not isiterable(other) or isinstance(other, string_types):
+            if len(self) == 1:
+                other = [other]
             else:
-                return True
-        return False
+                return False
+
+        for a, b in zip_longest(self, other):
+            if a != b:
+                return False
+        else:
+            return True
+
+    def __ne__(self, other):
+        return not (self == other)
 
     def __getitem__(self, item):
         if isinstance(item, slice) or self._header._haswildcard(item):
