@@ -30,7 +30,9 @@ def get_extensions():
             cfg['extra_compile_args'].extend([
                 '-Wno-unused-variable', '-Wno-parentheses',
                 '-Wno-uninitialized', '-Wno-format', '-Wno-strict-prototypes',
-                '-Wno-unused', '-Wno-comments', '-Wno-switch'])
+                '-Wno-unused', '-Wno-comments', '-Wno-switch',
+                '-Wno-declaration-after-statement'
+            ])
 
         cfitsio_path = os.path.join('cextern', 'cfitsio')
         cfitsio_files = glob(os.path.join(cfitsio_path, '*.c'))
@@ -50,8 +52,3 @@ def get_package_data():
 
 def get_external_libraries():
     return ['cfitsio']
-
-
-def get_legacy_alias():
-    return setup_helpers.add_legacy_alias(
-        'pyfits', 'astropy.io.fits', '3.2.dev', {'__svn_revision__': '1927'})
