@@ -15,19 +15,15 @@
 /* This module contains three functions that are callable from python.  The  */
 /* first is compress_hdu.  This function takes an                            */
 /* astropy.io.fits.CompImageHDU object containing the uncompressed image     */
-/* data and returns the compressed data for all tiles into the .compData     */
-/* attribute of that HDU.                                                    */
+/* data and returns the compressed data for all tiles into the               */
+/* .compressed_data attribute of that HDU.                                   */
 /*                                                                           */
 /* The second function is decompress_hdu.  It takes an                       */
 /* astropy.io.fits.CompImageHDU object that already has compressed data in   */
-/* its .compData attribute. It returns the decompressed image data into the  */
-/* HDU's .data attribute.                                                    */
+/* its .compressed_data attribute.  It returns the decompressed image data   */
+/* into the HDU's .data attribute.                                           */
 /*                                                                           */
-/* Finally, the utility function calc_max_elm is used internally by the      */
-/* CompImageHDU class to estimate how much memory to allocate for the        */
-/* compressed data when compressing an image.                                */
-/*                                                                           */
-/* Copyright (C) 2012 Association of Universities for Research in Astronomy  */
+/* Copyright (C) 2013 Association of Universities for Research in Astronomy  */
 /* (AURA)                                                                    */
 /*                                                                           */
 /* Redistribution and use in source and binary forms, with or without        */
@@ -659,14 +655,45 @@ void configure_compression(fitsfile* fileptr, PyObject* header) {
                 (0 == strcmp(tmp, "NONE"))) {
             Fptr->quantize_level = NO_QUANTIZE;
         } else if (0 == strcmp(tmp, "SUBTRACTIVE_DITHER_1")) {
-            Fptr->quantize_dither = SUBTRACTIVE_DITHER_1;
+#ifdef CFITSIO_SUPPORTS_SUBTRACTIVE_DITHER_2
+            // Added in CFITSIO 3.35, this also changed the name of the
+            // quantize_dither struct member to quantize_method
+            Fptr->quantize_method = SUBTRACTIVE_DITHER_1;
+        } else if (0 == strcmp(tmp, "SUBTRACTIVE_DITHER_2")) {
+            Fptr->quantize_method = SUBTRACTIVE_DITHER_2;
         } else {
-            Fptr->quantize_dither = 0;
+            Fptr->quantize_method = NO_DITHER;
         }
     } else {
-        Fptr->quantize_dither = 0;
+        Fptr->quantize_method = NO_DITHER;
     }
 
+    if (Fptr->quantize_method != NO_DITHER) {
+        if (0 != get_header_int(header, "ZDITHER0", &(Fptr->dither_seed), 0)) {
+            // ZDITHER0 keyword not found
+            Fptr->dither_seed = 0;
+            Fptr->request_dither_seed = 0;
+        }
+    }
+#else
+            Fptr->quantize_dither = SUBTRACTIVE_DITHER_1;
+        } else {
+            Fptr->quantize_dither = NO_DITHER;
+        }
+    } else {
+        Fptr->quantize_dither = NO_DITHER;
+    }
+
+    if (Fptr->quantize_dither != NO_DITHER) {
+        if (0 != get_header_int(header, "ZDITHER0", &(Fptr->dither_offset),
+                                0)) {
+            // ZDITHER0 keyword no found
+            Fptr->dither_offset = 0;
+            Fptr->request_dither_offset = 0;
+        }
+    }
+#endif
+
     Fptr->compressimg = 1;
     Fptr->maxelem = imcomp_calc_max_elem(Fptr->compress_type,
                                          Fptr->maxtilelen,
@@ -680,7 +707,7 @@ void configure_compression(fitsfile* fileptr, PyObject* header) {
 void init_output_buffer(PyObject* hdu, void** buf, size_t* bufsize) {
     // Determines a good size for the output data buffer and allocates
     // memory for it, returning the address and size of the allocated
-    // membory in to **buf and *bufsize respectively.
+    // memory into **buf and *bufsize respectively.
 
     PyObject* header = NULL;
     char keyword[9];
@@ -740,7 +767,6 @@ void init_output_buffer(PyObject* hdu, void** buf, size_t* bufsize) {
         *bufsize += ((size_t) (IOBUFLEN - (*bufsize % IOBUFLEN)));
     }
 
-    // TODO: Add error handling here
     *buf = calloc(*bufsize, sizeof(char));
 fail:
     Py_XDECREF(header);
@@ -757,7 +783,7 @@ void get_hdu_data_base(PyObject* hdu, void** buf, size_t* bufsize) {
     PyArrayObject* base;
     PyArrayObject* tmp;
 
-    data = (PyArrayObject*) PyObject_GetAttrString(hdu, "compData");
+    data = (PyArrayObject*) PyObject_GetAttrString(hdu, "compressed_data");
     if (data == NULL) {
         goto fail;
     }
@@ -767,7 +793,7 @@ void get_hdu_data_base(PyObject* hdu, void** buf, size_t* bufsize) {
     // allocated for the table and its heap
     if (!PyObject_TypeCheck(data, &PyArray_Type)) {
         PyErr_SetString(PyExc_TypeError,
-                        "CompImageHDU.compData must be a numpy.ndarray");
+                        "CompImageHDU.compressed_data must be a numpy.ndarray");
         goto fail;
     }
 
@@ -891,16 +917,20 @@ PyObject* compression_compress_hdu(PyObject* self, PyObject* args)
     // We just need to get the compressed bytes and Astropy will handle the
     // writing of them.
     init_output_buffer(hdu, &outbuf, &outbufsize);
+    if (outbuf == NULL) {
+        return NULL;
+    }
+
     open_from_hdu(&fileptr, &outbuf, &outbufsize, hdu, &columns);
     if (PyErr_Occurred()) {
-        return NULL;
+        goto fail;
     }
 
     Fptr = fileptr->Fptr;
 
     bitpix_to_datatypes(Fptr->zbitpix, &datatype, &npdatatype);
     if (PyErr_Occurred()) {
-        return NULL;
+        goto fail;
     }
 
     indata = (PyArrayObject*) PyObject_GetAttrString(hdu, "data");
@@ -940,7 +970,15 @@ PyObject* compression_compress_hdu(PyObject* self, PyObject* args)
     // Leaves refcount of tmp untouched, so its refcount should remain as 1
     retval = Py_BuildValue("KN", heapsize, tmp);
 
+    goto cleanup;
+
 fail:
+    if (outbuf != NULL) {
+        // At this point outbuf should never not be NULL, but in principle
+        // buggy code somewhere in CFITSIO or Numpy could set it to NULL
+        free(outbuf);
+    }
+cleanup:
     if (columns != NULL) {
         PyMem_Free(columns);
         Fptr->tableptr = NULL;
@@ -990,7 +1028,8 @@ PyObject* compression_decompress_hdu(PyObject* self, PyObject* args)
         return NULL;
     }
 
-    // Grab a pointer to the input data from the HDU's compData attribute
+    // Grab a pointer to the input data from the HDU's compressed_data
+    // attribute
     get_hdu_data_base(hdu, &inbuf, &inbufsize);
     if (PyErr_Occurred()) {
         return NULL;
