@@ -3,7 +3,6 @@
 import glob
 import io
 import os
-import warnings
 import sys
 
 import numpy as np
@@ -11,7 +10,8 @@ import numpy as np
 from .util import ignore_warnings
 from ..verify import VerifyError
 from ....io import fits
-from ....tests.helper import pytest, raises
+from ....tests.helper import pytest, raises, catch_warnings
+from ....utils.exceptions import AstropyUserWarning
 
 from . import FitsTestCase
 
@@ -100,7 +100,7 @@ class TestHDUListFunctions(FitsTestCase):
         hdul = fits.HDUList()
         hdul1 = fits.open(self.data('tb.fits'))
         hdul.append(hdul1[1])
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 4, (), 'uint8', ''),
+        info = [(0, 'PRIMARY', 'PrimaryHDU', 4, (), '', ''),
                 (1, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
 
         assert hdul.info(output=False) == info
@@ -116,7 +116,7 @@ class TestHDUListFunctions(FitsTestCase):
         hdu = fits.GroupsHDU()
         hdul.append(hdu)
 
-        info = [(0, 'PRIMARY', 'GroupsHDU', 8, (), 'uint8',
+        info = [(0, 'PRIMARY', 'GroupsHDU', 8, (), '',
                  '1 Groups  0 Parameters')]
 
         assert hdul.info(output=False) == info
@@ -147,7 +147,7 @@ class TestHDUListFunctions(FitsTestCase):
         hdul = fits.open(self.data('tb.fits'))
         hdul.append(hdul[1])
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 11, (), 'int16', ''),
+        info = [(0, 'PRIMARY', 'PrimaryHDU', 11, (), '', ''),
                 (1, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', ''),
                 (2, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
 
@@ -203,7 +203,7 @@ class TestHDUListFunctions(FitsTestCase):
         hdul1 = fits.open(self.data('tb.fits'))
         hdul.insert(0, hdul1[1])
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 4, (), 'uint8', ''),
+        info = [(0, 'PRIMARY', 'PrimaryHDU', 4, (), '', ''),
                 (1, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
 
         assert hdul.info(output=False) == info
@@ -219,7 +219,7 @@ class TestHDUListFunctions(FitsTestCase):
         hdu = fits.GroupsHDU()
         hdul.insert(0, hdu)
 
-        info = [(0, 'PRIMARY', 'GroupsHDU', 8, (), 'uint8',
+        info = [(0, 'PRIMARY', 'GroupsHDU', 8, (), '',
                  '1 Groups  0 Parameters')]
 
         assert hdul.info(output=False) == info
@@ -250,7 +250,7 @@ class TestHDUListFunctions(FitsTestCase):
         hdul = fits.open(self.data('tb.fits'))
         hdul.insert(1, hdul[1])
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 11, (), 'int16', ''),
+        info = [(0, 'PRIMARY', 'PrimaryHDU', 11, (), '', ''),
                 (1, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', ''),
                 (2, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
 
@@ -271,7 +271,7 @@ class TestHDUListFunctions(FitsTestCase):
         with pytest.raises(ValueError):
             hdul.insert(1, hdu)
 
-        info = [(0, 'PRIMARY', 'GroupsHDU', 8, (), 'uint8',
+        info = [(0, 'PRIMARY', 'GroupsHDU', 8, (), '',
                  '1 Groups  0 Parameters'),
                 (1, '', 'ImageHDU', 6, (100,), 'int32', '')]
 
@@ -300,9 +300,9 @@ class TestHDUListFunctions(FitsTestCase):
         hdul = fits.open(self.data('tb.fits'))
         hdul.insert(0, hdul[1])
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 4, (), 'uint8', ''),
+        info = [(0, 'PRIMARY', 'PrimaryHDU', 4, (), '', ''),
                 (1, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', ''),
-                (2, '', 'ImageHDU', 12, (), 'uint8', ''),
+                (2, '', 'ImageHDU', 12, (), '', ''),
                 (3, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
 
         assert hdul.info(output=False) == info
@@ -322,7 +322,7 @@ class TestHDUListFunctions(FitsTestCase):
         hdul.insert(0, hdu)
 
         info = [(0, 'PRIMARY', 'PrimaryHDU', 5, (100,), 'int32', ''),
-                (1, '', 'ImageHDU', 12, (), 'uint8', ''),
+                (1, '', 'ImageHDU', 12, (), '', ''),
                 (2, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
 
         assert hdul.info(output=False) == info
@@ -417,10 +417,10 @@ class TestHDUListFunctions(FitsTestCase):
         oldmtime = os.stat(self.data('test0.fits')).st_mtime
         hdul = fits.open(self.data('test0.fits'))
         hdul[0].header['FOO'] = 'BAR'
-        with warnings.catch_warnings(record=True) as w:
+        with catch_warnings(AstropyUserWarning) as w:
             hdul.flush()
-            assert len(w) == 1
-            assert 'mode is not supported' in str(w[0].message)
+        assert len(w) == 1
+        assert 'mode is not supported' in str(w[0].message)
         assert oldmtime == os.stat(self.data('test0.fits')).st_mtime
 
     def test_fix_extend_keyword(self):
@@ -496,14 +496,14 @@ class TestHDUListFunctions(FitsTestCase):
             f.seek(padding_start)
             f.write('\0'.encode('ascii') * padding_len)
 
-        with warnings.catch_warnings(record=True) as w:
+        with catch_warnings(AstropyUserWarning) as w:
             with fits.open(self.temp('temp.fits')) as hdul:
-                assert ('contains null bytes instead of spaces' in
-                        str(w[0].message))
-                assert len(w) == 1
-                assert len(hdul) == 1
-                assert str(hdul[0].header) == str(hdu.header)
                 assert (hdul[0].data == a).all()
+        assert ('contains null bytes instead of spaces' in
+                str(w[0].message))
+        assert len(w) == 1
+        assert len(hdul) == 1
+        assert str(hdul[0].header) == str(hdu.header)
 
     def test_update_with_truncated_header(self):
         """
@@ -617,17 +617,32 @@ class TestHDUListFunctions(FitsTestCase):
                 assert orig_info == hdul2.info(output=False)
                 for idx in range(len(hdul)):
                     assert hdul[idx].header == hdul2[idx].header
-                    if hdul[idx].data is None or hdul2[idx].data is None:
-                        assert hdul[idx].data == hdul2[idx].data
-                    elif (hdul[idx].data.dtype.fields and
-                          hdul2[idx].data.dtype.fields):
+                    data = hdul[idx].data
+                    data2 = hdul2[idx].data
+
+                    if data is None or data2 is None:
+                        assert data == data2
+                    elif data.dtype.fields and data2.dtype.fields:
                         # Compare tables
-                        for n in hdul[idx].data.names:
-                            c1 = hdul[idx].data[n]
-                            c2 = hdul2[idx].data[n]
+                        for n in data.names:
+                            c1 = data[n]
+                            c2 = data2[n]
                             assert (c1 == c2).all()
+                    elif np.any(np.isnan(data)) or np.any(np.isnan(data2)):
+                        mask = np.isnan(data)
+                        mask2 = np.isnan(data2)
+                        assert np.sum(mask) == np.sum(mask2)
+                        assert np.all(data[~mask] == data2[~mask2])
+                    elif (any(dim == 0 for dim in hdul[idx].data.shape) or
+                          any(dim == 0 for dim in hdul2[idx].data.shape)):
+                        # For some reason some combinations of Python and Numpy
+                        # on Windows result in MemoryErrors when trying to work
+                        # on memmap arrays with more than one dimension but
+                        # some dimensions of size zero, so include a special
+                        # case for that
+                        return hdul[idx].data.shape == hdul2[idx].data.shape
                     else:
-                        assert (hdul[idx].data == hdul2[idx].data).all()
+                        assert (data == data2).all()
 
         for filename in glob.glob(os.path.join(self.data_dir, '*.fits')):
             if sys.platform == 'win32' and filename == 'zerowidth.fits':
