@@ -32,20 +32,22 @@ def empty_writer(table, *args, **kwargs):
     pass
 
 
-def empty_identifier(args, kwargs):
+def empty_identifier(*args, **kwargs):
     return True
 
 
 def test_get_reader_invalid():
     with pytest.raises(Exception) as exc:
         io_registry.get_reader('test', TestData)
-    assert exc.value.args[0] == "No reader defined for format 'test' and class 'TestData'"
+    assert exc.value.args[0].startswith(
+        "No reader defined for format 'test' and class 'TestData'")
 
 
 def test_get_writer_invalid():
     with pytest.raises(Exception) as exc:
         io_registry.get_writer('test', TestData)
-    assert exc.value.args[0] == "No writer defined for format 'test' and class 'TestData'"
+    assert exc.value.args[0].startswith(
+        "No writer defined for format 'test' and class 'TestData'")
 
 
 def test_register_reader():
@@ -106,13 +108,13 @@ def test_register_identifier_force():
 def test_read_noformat():
     with pytest.raises(Exception) as exc:
         TestData.read()
-    assert exc.value.args[0] == "Format could not be identified"
+    assert exc.value.args[0].startswith("Format could not be identified.")
 
 
 def test_write_noformat():
     with pytest.raises(Exception) as exc:
         TestData().write()
-    assert exc.value.args[0] == "Format could not be identified"
+    assert exc.value.args[0].startswith("Format could not be identified.")
 
 
 def test_read_noformat_arbitrary():
@@ -120,7 +122,19 @@ def test_read_noformat_arbitrary():
     _identifiers.update(_IDENTIFIERS_ORIGINAL)
     with pytest.raises(Exception) as exc:
         TestData.read(object())
-    assert exc.value.args[0] == "Format could not be identified"
+    assert exc.value.args[0].startswith("Format could not be identified.")
+
+
+def test_read_noformat_arbitrary_file(tmpdir):
+    """Tests that all identifier functions can accept arbitrary files"""
+    _readers.update(_READERS_ORIGINAL)
+    testfile = str(tmpdir.join('foo.example'))
+    with open(testfile, 'w') as f:
+        f.write("Hello world")
+
+    with pytest.raises(Exception) as exc:
+        Table.read(testfile)
+    assert exc.value.args[0].startswith("Format could not be identified.")
 
 
 def test_write_noformat_arbitrary():
@@ -128,20 +142,30 @@ def test_write_noformat_arbitrary():
     _identifiers.update(_IDENTIFIERS_ORIGINAL)
     with pytest.raises(Exception) as exc:
         TestData().write(object())
-    assert exc.value.args[0] == "Format could not be identified"
+    assert exc.value.args[0].startswith("Format could not be identified.")
+
+
+def test_write_noformat_arbitrary_file(tmpdir):
+    """Tests that all identifier functions can accept arbitrary files"""
+    _writers.update(_WRITERS_ORIGINAL)
+    testfile = str(tmpdir.join('foo.example'))
+
+    with pytest.raises(Exception) as exc:
+        Table().write(testfile)
+    assert exc.value.args[0].startswith("Format could not be identified.")
 
 
 def test_read_toomanyformats():
-    io_registry.register_identifier('test1', TestData, lambda o, x, y: True)
-    io_registry.register_identifier('test2', TestData, lambda o, x, y: True)
+    io_registry.register_identifier('test1', TestData, lambda o, *x, **y: True)
+    io_registry.register_identifier('test2', TestData, lambda o, *x, **y: True)
     with pytest.raises(Exception) as exc:
         TestData.read()
     assert exc.value.args[0] == "Format is ambiguous - options are: test1, test2"
 
 
 def test_write_toomanyformats():
-    io_registry.register_identifier('test1', TestData, lambda o, x, y: True)
-    io_registry.register_identifier('test2', TestData, lambda o, x, y: True)
+    io_registry.register_identifier('test1', TestData, lambda o, *x, **y: True)
+    io_registry.register_identifier('test2', TestData, lambda o, *x, **y: True)
     with pytest.raises(Exception) as exc:
         TestData().write()
     assert exc.value.args[0] == "Format is ambiguous - options are: test1, test2"
@@ -150,19 +174,25 @@ def test_write_toomanyformats():
 def test_read_format_noreader():
     with pytest.raises(Exception) as exc:
         TestData.read(format='test')
-    assert exc.value.args[0] == "No reader defined for format 'test' and class 'TestData'"
+    assert exc.value.args[0].startswith(
+        "No reader defined for format 'test' and class 'TestData'")
 
 
 def test_write_format_nowriter():
     with pytest.raises(Exception) as exc:
         TestData().write(format='test')
-    assert exc.value.args[0] == "No writer defined for format 'test' and class 'TestData'"
+    assert exc.value.args[0].startswith(
+        "No writer defined for format 'test' and class 'TestData'")
 
 
 def test_read_identifier():
 
-    io_registry.register_identifier('test1', TestData, lambda o, x, y: x[0].startswith('a'))
-    io_registry.register_identifier('test2', TestData, lambda o, x, y: x[0].startswith('b'))
+    io_registry.register_identifier(
+        'test1', TestData,
+        lambda o, path, fileobj, *x, **y: path.startswith('a'))
+    io_registry.register_identifier(
+        'test2', TestData,
+        lambda o, path, fileobj, *x, **y: path.startswith('b'))
 
     # Now check that we got past the identifier and are trying to get
     # the reader. The io_registry.get_reader will fail but the error message will
@@ -170,17 +200,19 @@ def test_read_identifier():
 
     with pytest.raises(Exception) as exc:
         TestData.read('abc')
-    assert exc.value.args[0] == "No reader defined for format 'test1' and class 'TestData'"
+    assert exc.value.args[0].startswith(
+        "No reader defined for format 'test1' and class 'TestData'")
 
     with pytest.raises(Exception) as exc:
         TestData.read('bac')
-    assert exc.value.args[0] == "No reader defined for format 'test2' and class 'TestData'"
+    assert exc.value.args[0].startswith(
+        "No reader defined for format 'test2' and class 'TestData'")
 
 
 def test_write_identifier():
 
-    io_registry.register_identifier('test1', TestData, lambda o, x, y: x[0].startswith('a'))
-    io_registry.register_identifier('test2', TestData, lambda o, x, y: x[0].startswith('b'))
+    io_registry.register_identifier('test1', TestData, lambda o, *x, **y: x[0].startswith('a'))
+    io_registry.register_identifier('test2', TestData, lambda o, *x, **y: x[0].startswith('b'))
 
     # Now check that we got past the identifier and are trying to get
     # the reader. The io_registry.get_writer will fail but the error message will
@@ -188,17 +220,19 @@ def test_write_identifier():
 
     with pytest.raises(Exception) as exc:
         TestData().write('abc')
-    assert exc.value.args[0] == "No writer defined for format 'test1' and class 'TestData'"
+    assert exc.value.args[0].startswith(
+        "No writer defined for format 'test1' and class 'TestData'")
 
     with pytest.raises(Exception) as exc:
         TestData().write('bac')
-    assert exc.value.args[0] == "No writer defined for format 'test2' and class 'TestData'"
+    assert exc.value.args[0].startswith(
+        "No writer defined for format 'test2' and class 'TestData'")
 
 
 def test_identifier_origin():
 
-    io_registry.register_identifier('test1', TestData, lambda o, x, y: o == 'read')
-    io_registry.register_identifier('test2', TestData, lambda o, x, y: o == 'write')
+    io_registry.register_identifier('test1', TestData, lambda o, *x, **y: o == 'read')
+    io_registry.register_identifier('test2', TestData, lambda o, *x, **y: o == 'write')
     io_registry.register_reader('test1', TestData, empty_reader)
     io_registry.register_writer('test2', TestData, empty_writer)
 
@@ -208,11 +242,13 @@ def test_identifier_origin():
 
     with pytest.raises(Exception) as exc:
         TestData.read(format='test2')
-    assert exc.value.args[0] == "No reader defined for format 'test2' and class 'TestData'"
+    assert exc.value.args[0].startswith(
+        "No reader defined for format 'test2' and class 'TestData'")
 
     with pytest.raises(Exception) as exc:
         TestData().write(format='test1')
-    assert exc.value.args[0] == "No writer defined for format 'test1' and class 'TestData'"
+    assert exc.value.args[0].startswith(
+        "No writer defined for format 'test1' and class 'TestData'")
 
 
 def test_read_valid_return():
@@ -238,6 +274,17 @@ def test_read_basic_table():
         assert t['B'][i] == data['B'][i]
 
 
+def test_register_readers_with_same_name_on_different_classes():
+    # No errors should be generated if the same name is registered for
+    # different objects...but this failed under python3
+    io_registry.register_reader('test', TestData, lambda: TestData())
+    io_registry.register_reader('test', Table, lambda: Table())
+    t = TestData.read(format='test')
+    assert isinstance(t, TestData)
+    tbl = Table.read(format='test')
+    assert isinstance(tbl, Table)
+
+
 def teardown_function(function):
     _readers.update(_READERS_ORIGINAL)
     _writers.update(_WRITERS_ORIGINAL)
