@@ -1,6 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 # -*- coding: utf-8 -*-
-u"""
+"""
 .. _warnings:
 
 Warnings
@@ -31,15 +31,19 @@ Exceptions
 {exceptions}
 """
 
-from __future__ import division, absolute_import
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
+
+from ...extern import six
 
 # STDLIB
 import io
 import re
+
+from textwrap import dedent
 from warnings import warn
 
-# LOCAL
-from .util import IS_PY3K
+from ...utils.exceptions import AstropyWarning
 
 
 __all__ = [
@@ -52,7 +56,9 @@ __all__ = [
 MAX_WARNINGS = 10
 
 
-def _format_message(message, name, config={}, pos=None):
+def _format_message(message, name, config=None, pos=None):
+    if config is None:
+        config = {}
     if pos is None:
         pos = ('?', '?')
     filename = config.get('filename', '?')
@@ -61,7 +67,7 @@ def _format_message(message, name, config={}, pos=None):
 
 def _suppressed_warning(warning, config, stacklevel=2):
     warning_class = type(warning)
-    config.setdefault('_warning_counts', {}).setdefault(warning_class, 0)
+    config.setdefault('_warning_counts', dict()).setdefault(warning_class, 0)
     config['_warning_counts'][warning_class] += 1
     message_count = config['_warning_counts'][warning_class]
     if message_count <= MAX_WARNINGS:
@@ -71,11 +77,13 @@ def _suppressed_warning(warning, config, stacklevel=2):
         warn(warning, stacklevel=stacklevel+1)
 
 
-def warn_or_raise(warning_class, exception_class=None, args=(), config={},
+def warn_or_raise(warning_class, exception_class=None, args=(), config=None,
                   pos=None, stacklevel=1):
     """
     Warn or raise an exception, depending on the pedantic setting.
     """
+    if config is None:
+        config = {}
     if config.get('pedantic'):
         if exception_class is None:
             exception_class = warning_class
@@ -84,20 +92,24 @@ def warn_or_raise(warning_class, exception_class=None, args=(), config={},
         vo_warn(warning_class, args, config, pos, stacklevel=stacklevel+1)
 
 
-def vo_raise(exception_class, args=(), config={}, pos=None):
+def vo_raise(exception_class, args=(), config=None, pos=None):
     """
     Raise an exception, with proper position information if available.
     """
+    if config is None:
+        config = {}
     raise exception_class(args, config, pos)
 
 
-def vo_reraise(exc, config={}, pos=None, additional=''):
+def vo_reraise(exc, config=None, pos=None, additional=''):
     """
     Raise an exception, with proper position information if available.
 
     Restores the original traceback of the exception, and should only
     be called within an "except:" block of code.
     """
+    if config is None:
+        config = {}
     message = _format_message(str(exc), exc.__class__.__name__, config, pos)
     if message.split()[0] == str(exc).split()[0]:
         message = str(exc)
@@ -107,10 +119,12 @@ def vo_reraise(exc, config={}, pos=None, additional=''):
     raise exc
 
 
-def vo_warn(warning_class, args=(), config={}, pos=None, stacklevel=1):
+def vo_warn(warning_class, args=(), config=None, pos=None, stacklevel=1):
     """
     Warn, with proper position information if available.
     """
+    if config is None:
+        config = {}
     warning = warning_class(args, config, pos)
     _suppressed_warning(warning, config, stacklevel=stacklevel+1)
 
@@ -146,8 +160,14 @@ def parse_vowarning(line):
             result['is_other'] = True
             result['number'] = None
             result['doc_url'] = None
-        result['nline'] = int(match.group('nline'))
-        result['nchar'] = int(match.group('nchar'))
+        try:
+            result['nline'] = int(match.group('nline'))
+        except ValueError:
+            result['nline'] = 0
+        try:
+            result['nchar'] = int(match.group('nchar'))
+        except ValueError:
+            result['nchar'] = 0
         result['message'] = match.group('rest')
         result['is_something'] = True
     else:
@@ -156,14 +176,14 @@ def parse_vowarning(line):
         result['is_exception'] = False
         result['is_other'] = False
         result['is_something'] = False
-        if not isinstance(line, unicode):
+        if not isinstance(line, six.text_type):
             line = line.decode('utf-8')
         result['message'] = line
 
     return result
 
 
-class VOWarning(Warning):
+class VOWarning(AstropyWarning):
     """
     The base class of all VO warnings and exceptions.
 
@@ -402,7 +422,7 @@ class W08(VOTableSpecWarning):
     make more sense.
     """
 
-    if IS_PY3K:
+    if six.PY3:
         message = "'%s' must be a str or bytes object"
     else:
         message = "'%s' must be a str or unicode object"
@@ -593,11 +613,11 @@ class W20(VOTableSpecWarning):
 class W21(UnimplementedWarning):
     """
     Unknown issues may arise using ``vo.table`` with VOTable files
-    from a version other than 1.1 or 1.2.
+    from a version other than 1.1, 1.2 or 1.3.
     """
 
     message = (
-        'vo.table is designed for VOTable version 1.1 and 1.2, but ' +
+        'vo.table is designed for VOTable version 1.1, 1.2 and 1.3, but ' +
         'this file is %s')
     default_args = ('x',)
 
@@ -943,10 +963,16 @@ class W45(VOWarning, ValueError):
 
         query, hints, doc, location
 
+    And in VOTable 1.3, additionally::
+
+        type
+
     **References**: `1.1
     <http://www.ivoa.net/Documents/VOTable/20040811/REC-VOTable-1.1-20040811.html#ToC54>`__,
     `1.2
     <http://www.ivoa.net/Documents/VOTable/20091130/REC-VOTable-1.2.html#ToC58>`__
+    `1.3
+    <http://www.ivoa.net/documents/VOTable/20130315/PR-VOTable-1.3-20130315.html#sec:link>`__
     """
 
     message = "content-role attribute '%s' invalid"
@@ -983,7 +1009,8 @@ class W48(VOTableSpecWarning):
 
 class W49(VOTableSpecWarning):
     """
-    Empty cell illegal for integer fields.
+    Prior to VOTable 1.3, the empty cell was illegal for integer
+    fields.
 
     If a \"null\" value was specified for the cell, it will be used
     for the value, otherwise, 0 will be used.
@@ -997,6 +1024,9 @@ class W50(VOTableSpecWarning):
     Invalid unit string as defined in the `Standards for Astronomical
     Catalogues, Version 2.0
     <http://cdsarc.u-strasbg.fr/doc/catstd-3.2.htx>`_.
+
+    Consider passing an explicit `unit_format` parameter if the units
+    in this file conform to another specification.
     """
 
     message = "Invalid unit string '%s'"
@@ -1230,7 +1260,7 @@ class E12(VOWarning, ValueError):
 
 
 class E13(VOWarning, ValueError):
-    u"""
+    """
     From the VOTable 1.2 spec:
 
         A table cell can contain an array of a given primitive type,
@@ -1372,7 +1402,7 @@ class E21(VOWarning, ValueError):
 
 def _get_warning_and_exception_classes(prefix):
     classes = []
-    for key, val in globals().iteritems():
+    for key, val in six.iteritems(globals()):
         if re.match(prefix + "[0-9]{2}", key):
             classes.append((key, val))
     classes.sort()
@@ -1380,37 +1410,35 @@ def _get_warning_and_exception_classes(prefix):
 
 
 def _build_doc_string():
-    from textwrap import dedent
-
     def generate_set(prefix):
         classes = _get_warning_and_exception_classes(prefix)
 
         out = io.StringIO()
 
         for name, cls in classes:
-            out.write(u".. _%s:\n\n" % name)
+            out.write(".. _%s:\n\n" % name)
             msg = "%s: %s" % (cls.__name__, cls.get_short_name())
-            if not isinstance(msg, unicode):
+            if not isinstance(msg, six.text_type):
                 msg = msg.decode('utf-8')
             out.write(msg)
-            out.write(u'\n')
-            out.write(u'~' * len(msg))
-            out.write(u'\n\n')
+            out.write('\n')
+            out.write('~' * len(msg))
+            out.write('\n\n')
             doc = cls.__doc__
-            if not isinstance(doc, unicode):
+            if not isinstance(doc, six.text_type):
                 doc = doc.decode('utf-8')
             out.write(dedent(doc))
-            out.write(u'\n\n')
+            out.write('\n\n')
 
         return out.getvalue()
 
-    warnings = generate_set(u'W')
-    exceptions = generate_set(u'E')
+    warnings = generate_set('W')
+    exceptions = generate_set('E')
 
-    return {u'warnings': warnings,
-            u'exceptions': exceptions}
+    return {'warnings': warnings,
+            'exceptions': exceptions}
 
 __doc__ = __doc__.format(**_build_doc_string())
 
-__all__.extend([x[0] for x in _get_warning_and_exception_classes(u'W')])
-__all__.extend([x[0] for x in _get_warning_and_exception_classes(u'E')])
+__all__.extend([x[0] for x in _get_warning_and_exception_classes('W')])
+__all__.extend([x[0] for x in _get_warning_and_exception_classes('E')])
