@@ -29,7 +29,7 @@ next_power_of_2(Py_ssize_t n)
     n |= n >> 16;
     n++;
 
-    return n;
+    return n == 0 ? 2 : n;
 }
 
 /******************************************************************************
