@@ -1,4 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+
+from __future__ import absolute_import, division, print_function, unicode_literals
+
 # THIRD-PARTY
 import numpy as np
 from numpy.testing import assert_array_equal
@@ -25,7 +28,7 @@ def test_oversize_char(recwarn):
     c = converters.get_converter(field, config=config)
     w = recwarn.pop(exceptions.W47)
 
-    c.parse(u"XXX")
+    c.parse("XXX")
     w = recwarn.pop(exceptions.W46)
 
 
@@ -45,7 +48,7 @@ def test_oversize_unicode(recwarn):
         config=config)
     c = converters.get_converter(field, config=config)
 
-    c.parse(u"XXX")
+    c.parse("XXX")
     w = recwarn.pop(exceptions.W46)
 
 
@@ -55,7 +58,7 @@ def test_unicode_mask():
         None, name='c', datatype='unicodeChar',
         config=config)
     c = converters.get_converter(field, config=config)
-    assert c.output(u"Foo", True) == u''
+    assert c.output("Foo", True) == ''
 
 
 @raises(exceptions.E02)
@@ -108,7 +111,7 @@ def test_complex_array_vararray2():
     assert len(x[0]) == 0
 
 
-def test_complex_array_vararray():
+def test_complex_array_vararray3():
     config = {'pedantic': True}
     field = tree.Field(
         None, name='c', datatype='doubleComplex', arraysize='2x3*',
@@ -203,3 +206,24 @@ def test_precision():
         config=config)
     c = converters.get_converter(field, config=config)
     assert c.output(266.248, False) == '266.2480'
+
+
+@raises(exceptions.W51)
+def test_integer_overflow():
+    config = {'pedantic': True}
+
+    field = tree.Field(
+        None, name='c', datatype='int', config=config)
+    c = converters.get_converter(field, config=config)
+    c.parse('-2208988800', config=config)
+
+
+def test_float_default_precision():
+    config = {'pedantic': True}
+
+    field = tree.Field(
+        None, name='c', datatype='float', arraysize="4",
+        config=config)
+    c = converters.get_converter(field, config=config)
+    assert (c.output([1, 2, 3, 8.999999], [False, False, False, False]) ==
+            '1 2 3 8.9999990000000007')
