@@ -728,21 +728,21 @@ class LabeledInput(dict):
 
     Examples
     --------
-    >>> x,y = np.mgrid[:5, :5]
+    >>> y, x = np.mgrid[:5, :5]
     >>> l = np.arange(10)
     >>> labeled_input = LabeledInput([x, y, l], ['x', 'y', 'pixel'])
     >>> labeled_input.x
-    array([[0, 0, 0, 0, 0],
-           [1, 1, 1, 1, 1],
-           [2, 2, 2, 2, 2],
-           [3, 3, 3, 3, 3],
-           [4, 4, 4, 4, 4]])
+    array([[0, 1, 2, 3, 4],
+           [0, 1, 2, 3, 4],
+           [0, 1, 2, 3, 4],
+           [0, 1, 2, 3, 4],
+           [0, 1, 2, 3, 4]])
     >>> labeled_input['x']
-    array([[0, 0, 0, 0, 0],
-           [1, 1, 1, 1, 1],
-           [2, 2, 2, 2, 2],
-           [3, 3, 3, 3, 3],
-           [4, 4, 4, 4, 4]])
+    array([[0, 1, 2, 3, 4],
+           [0, 1, 2, 3, 4],
+           [0, 1, 2, 3, 4],
+           [0, 1, 2, 3, 4],
+           [0, 1, 2, 3, 4]])
     """
 
     def __init__(self, data, labels):
@@ -827,22 +827,16 @@ class _CompositeModel(Model):
         self.fittable = False
 
     def __repr__(self):
-        fmt = """
-            Model:  {0}
-            """.format(self.__class__.__name__)
-        fmt_args = tuple(repr(tr) for tr in self._transforms)
-        fmt1 = (" %s  " * len(self._transforms)) % fmt_args
-        fmt = fmt + fmt1
-        return fmt
+        return '<{0}([\n{1}\n])>'.format(
+            self.__class__.__name__,
+            indent(',\n'.join(repr(tr) for tr in self._transforms),
+                   width=4))
 
     def __str__(self):
-        fmt = """
-            Model:  {0}
-            """.format(self.__class__.__name__)
-        fmt_args = tuple(str(tr) for tr in self._transforms)
-        fmt1 = (" %s  " * len(self._transforms)) % fmt_args
-        fmt = fmt + fmt1
-        return fmt
+        parts = ['Model: {0}'.format(self.__class__.__name__)]
+        for tr in self._transforms:
+            parts.append(indent(str(tr), width=4))
+        return '\n'.join(parts)
 
     def add_model(self, transf, inmap, outmap):
         self[transf] = [inmap, outmap]
@@ -854,6 +848,18 @@ class _CompositeModel(Model):
         # implemented by subclasses
         raise NotImplementedError("Subclasses should implement this")
 
+    @property
+    def param_sets(self):
+        raise NotImplementedError(
+            "Composite models do not currently support multiple "
+            "parameter sets.")
+
+    @property
+    def parameters(self):
+        raise NotImplementedError(
+            "Composite models do not currently support the .parameters "
+            "array.")
+
 
 class SerialCompositeModel(_CompositeModel):
     """
@@ -883,7 +889,7 @@ class SerialCompositeModel(_CompositeModel):
 
         >>> import numpy as np
         >>> from astropy.modeling import models, LabeledInput, SerialCompositeModel
-        >>> x, y = np.mgrid[:5, :5]
+        >>> y, x = np.mgrid[:5, :5]
         >>> rotation = models.MatrixRotation2D(angle=23.5)
         >>> offset_x = models.Shift(-4.23)
         >>> offset_y = models.Shift(2)
@@ -925,9 +931,13 @@ class SerialCompositeModel(_CompositeModel):
 
     def inverse(self):
         try:
-            transforms = [tr.inverse() for tr in self._transforms[::-1]]
+            transforms = []
+            for transform in self._transforms[::-1]:
+                transforms.append(transform.inverse())
         except NotImplementedError:
-            raise
+            raise NotImplementedError(
+                "An analytical inverse has not been implemented for "
+                "{0} models.".format(transform.__class__.__name__))
         if self._inmap is not None:
             inmap = self._inmap[::-1]
             outmap = self._outmap[::-1]
