@@ -39,7 +39,7 @@ class TestSerialComposite(object):
     Test composite models evaluation in series
     """
     def setup_class(self):
-        self.x, self.y = np.mgrid[:5, :5]
+        self.y, self.x = np.mgrid[:5, :5]
         self.p1 = models.Polynomial1D(3)
         self.p11 = models.Polynomial1D(3)
         self.p2 = models.Polynomial2D(3)
@@ -237,7 +237,7 @@ class TestParametricModels(object):
         self.y = 6.7
         self.x1 = np.arange(1, 10, .1)
         self.y1 = np.arange(1, 10, .1)
-        self.x2, self.y2 = np.mgrid[:10, :8]
+        self.y2, self.x2 = np.mgrid[:10, :8]
 
     @pytest.mark.parametrize(('model_class'), models_1D.keys())
     def test_input1D(self, model_class):
@@ -270,14 +270,16 @@ class TestParametricModels(object):
         x_lim = models_1D[model_class]['x_lim']
         parameters = models_1D[model_class]['parameters']
         model = create_model(model_class, parameters)
+
         if isinstance(parameters, dict):
-            parameters.pop('degree')
-            parameters = parameters.values()
+            parameters = [parameters[name] for name in model.param_names]
+
         if "log_fit" in models_1D[model_class]:
             if models_1D[model_class]['log_fit']:
                 x = np.logspace(x_lim[0], x_lim[1], self.N)
         else:
             x = np.linspace(x_lim[0], x_lim[1], self.N)
+
         np.random.seed(0)
         # add 10% noise to the amplitude
         relative_noise_amplitude = 0.01
@@ -329,9 +331,9 @@ class TestParametricModels(object):
 
         parameters = models_2D[model_class]['parameters']
         model = create_model(model_class, parameters)
+
         if isinstance(parameters, dict):
-            parameters.pop('degree')
-            parameters = parameters.values()
+            parameters = [parameters[name] for name in model.param_names]
 
         if "log_fit" in models_2D[model_class]:
             if models_2D[model_class]['log_fit']:
