@@ -9,6 +9,7 @@ from __future__ import absolute_import, print_function
 import collections
 import errno
 import imp
+import inspect
 import os
 import re
 import shlex
@@ -16,8 +17,10 @@ import shutil
 import subprocess
 import sys
 import textwrap
+import warnings
 
-from distutils import log
+from distutils import log, ccompiler, sysconfig
+from distutils.cmd import DistutilsOptionError
 from distutils.dist import Distribution
 from distutils.errors import DistutilsError, DistutilsFileError
 from distutils.core import Extension
@@ -25,13 +28,19 @@ from distutils.core import Command
 from distutils.command.sdist import sdist as DistutilsSdist
 from setuptools.command.build_ext import build_ext as SetuptoolsBuildExt
 from setuptools.command.build_py import build_py as SetuptoolsBuildPy
+from setuptools.command.install import install as SetuptoolsInstall
+from setuptools.command.install_lib import install_lib as SetuptoolsInstallLib
 
 from setuptools.command.register import register as SetuptoolsRegister
+from setuptools import find_packages
 
 from .tests.helper import astropy_test
 from .utils import silence
 from .utils.compat.misc import invalidate_caches
 from .utils.misc import walk_skip_hidden
+from .utils.exceptions import AstropyDeprecationWarning
+
+from .extern import six
 
 
 try:
@@ -54,6 +63,10 @@ except SyntaxError:  # occurs if markupsafe is recent version, which doesn't sup
 PY3 = sys.version_info[0] >= 3
 
 
+# This adds a new keyword to the setup() function
+Distribution.skip_2to3 = []
+
+
 _adjusted_compiler = False
 def adjust_compiler(package):
     """
@@ -74,9 +87,6 @@ def adjust_compiler(package):
     to.
     """
 
-    from distutils import ccompiler, sysconfig
-    import re
-
     compiler_mapping = [
         (b'i686-apple-darwin[0-9]*-llvm-gcc-4.2', 'clang')
         ]
@@ -152,7 +162,7 @@ def adjust_compiler(package):
                     """
                     The C compiler used to compile Python {compiler:s}, and
                     which is normally used to compile C extensions, is not
-                    available. You can explicitly specifiy which compiler to
+                    available. You can explicitly specify which compiler to
                     use by setting the CC environment variable, for example:
 
                         CC=gcc python setup.py <command>
@@ -174,10 +184,13 @@ def adjust_compiler(package):
 def get_compiler_version(compiler):
 
     process = subprocess.Popen(
-    shlex.split(compiler) + ['--version'], stdout=subprocess.PIPE)
+        shlex.split(compiler) + ['--version'], stdout=subprocess.PIPE)
 
     output = process.communicate()[0].strip()
-    version = output.split()[0]
+    try:
+        version = output.split()[0]
+    except IndexError:
+        return 'unknown'
 
     return version
 
@@ -307,8 +320,7 @@ def get_compiler_option():
 
     compiler = get_distutils_build_option('compiler')
     if compiler is None:
-        import distutils.ccompiler
-        return distutils.ccompiler.get_default_compiler()
+        return ccompiler.get_default_compiler()
 
     return compiler
 
@@ -354,19 +366,25 @@ def register_commands(package, version, release):
     _registered_commands = {
         'test': generate_test_command(package),
 
-         # Use distutils' sdist because it respects package_data.
-         # setuptools/distributes sdist requires duplication of information in
-         # MANIFEST.in
-         'sdist': DistutilsSdist,
+        # Use distutils' sdist because it respects package_data.
+        # setuptools/distributes sdist requires duplication of information in
+        # MANIFEST.in
+        'sdist': DistutilsSdist,
 
-         # The exact form of the build_ext command depends on whether or not
-         # we're building a release version
-         'build_ext': generate_build_ext_command(package, release),
+        # The exact form of the build_ext command depends on whether or not
+        # we're building a release version
+        'build_ext': generate_build_ext_command(package, release),
 
-         # We have a custom build_py to generate the default configuration file
-         'build_py': AstropyBuildPy,
+        # We have a custom build_py to generate the default configuration file
+        'build_py': AstropyBuildPy,
 
-         'register': AstropyRegister
+        # Since install can (in some circumstances) be run without
+        # first building, we also need to override install and
+        # install_lib.  See #2223
+        'install': AstropyInstall,
+        'install_lib': AstropyInstallLib,
+
+        'register': AstropyRegister
     }
 
     try:
@@ -381,7 +399,7 @@ def register_commands(package, version, release):
     if HAVE_SPHINX:
         _registered_commands['build_sphinx'] = AstropyBuildSphinx
     else:
-         _registered_commands['build_sphinx'] = FakeBuildSphinx
+        _registered_commands['build_sphinx'] = FakeBuildSphinx
 
     # Need to override the __name__ here so that the commandline options are
     # presented as being related to the "build" command, for example; normally
@@ -394,8 +412,6 @@ def register_commands(package, version, release):
     # Add a few custom options; more of these can be added by specific packages
     # later
     for option in [
-            ('enable-legacy',
-             "Install legacy shims", True),
             ('use-system-libraries',
              "Use system libraries whenever possible", True)]:
         add_command_option('build', *option)
@@ -536,6 +552,29 @@ def generate_build_ext_command(packagename, release):
     return type('build_ext', (basecls, object), attrs)
 
 
+def _get_platlib_dir(cmd):
+    plat_specifier = '.{0}-{1}'.format(cmd.plat_name, sys.version[0:3])
+    return os.path.join(cmd.build_base, 'lib' + plat_specifier)
+
+
+class AstropyInstall(SetuptoolsInstall):
+
+    def finalize_options(self):
+        build_cmd = self.get_finalized_command('build')
+        platlib_dir = _get_platlib_dir(build_cmd)
+        self.build_lib = platlib_dir
+        SetuptoolsInstall.finalize_options(self)
+
+
+class AstropyInstallLib(SetuptoolsInstallLib):
+
+    def finalize_options(self):
+        build_cmd = self.get_finalized_command('build')
+        platlib_dir = _get_platlib_dir(build_cmd)
+        self.build_dir = platlib_dir
+        SetuptoolsInstallLib.finalize_options(self)
+
+
 class AstropyBuildPy(SetuptoolsBuildPy):
 
     def finalize_options(self):
@@ -544,40 +583,63 @@ class AstropyBuildPy(SetuptoolsBuildPy):
         # for projects with only pure-Python source (this is desirable
         # specifically for support of multiple Python version).
         build_cmd = self.get_finalized_command('build')
-        plat_specifier = '.{0}-{1}'.format(build_cmd.plat_name,
-                                           sys.version[0:3])
-        # Do this unconditionally
-        build_purelib = os.path.join(build_cmd.build_base,
-                                     'lib' + plat_specifier)
-        build_cmd.build_purelib = build_purelib
-        build_cmd.build_lib = build_purelib
+        platlib_dir = _get_platlib_dir(build_cmd)
+
+        build_cmd.build_purelib = platlib_dir
+        build_cmd.build_lib = platlib_dir
+        self.build_lib = platlib_dir
 
-        # Ugly hack: We also need to 'fix' the build_lib option on the
-        # install command--it would be better just to override that command
-        # entirely, but we can get around that extra effort by doing it here
-        install_cmd = self.get_finalized_command('install')
-        install_cmd.build_lib = build_purelib
-        install_lib_cmd = self.get_finalized_command('install_lib')
-        install_lib_cmd.build_dir = build_purelib
-        self.build_lib = build_purelib
         SetuptoolsBuildPy.finalize_options(self)
 
+    def run_2to3(self, files, doctests=False):
+        # Filter the files to exclude things that shouldn't be 2to3'd
+        skip_2to3 = self.distribution.skip_2to3
+        filtered_files = []
+        for file in files:
+            for package in skip_2to3:
+                if file[len(self.build_lib) + 1:].startswith(package):
+                    break
+            else:
+                filtered_files.append(file)
+
+        SetuptoolsBuildPy.run_2to3(self, filtered_files, doctests)
+
     def run(self):
         # first run the normal build_py
         SetuptoolsBuildPy.run(self)
 
+        pkgnm = self.distribution.packages[0]
+
         if self.distribution.is_pure():
             # Generate the default astropy.cfg - we only do this here if it's
             # pure python.  Otherwise, it'll happen at the end of build_exp
             default_cfg = generate_default_config(
-                    os.path.abspath(self.build_lib),
-                    self.distribution.packages[0])
+                    os.path.abspath(self.build_lib), pkgnm)
             if default_cfg:
                 default_cfg = os.path.relpath(default_cfg)
                 self.copy_file(default_cfg,
                                os.path.join(self.build_lib, default_cfg),
                                preserve_mode=False)
 
+        # Also copy over *only* the pytest part of setup.cfg.  This is necessary
+        # because the astropy.test() function needs this information to know how
+        # it should be configured.
+        p = six.moves.configparser.SafeConfigParser()
+        p.add_section('pytest')
+
+        pkgnmsection = r'"' + pkgnm + r'[\/]'
+        for k, (fnsrc, v) in six.iteritems(self.distribution.command_options['pytest']):
+            # also need to adjust any part of the pytest section that contains
+            # reference to the package directory (e.g., "astropy" for the core
+            # package), because this file is actually written *into* that
+            # directory.
+            if pkgnmsection in v:
+                v = v.replace(pkgnmsection, '"')
+            p.set('pytest', k, v)
+
+        with open(os.path.join(self.build_lib, pkgnm, 'pytest.ini'), 'w') as f:
+            p.write(f)
+
 
 def generate_default_config(build_lib, package):
     config_path = os.path.relpath(package)
@@ -593,13 +655,21 @@ def generate_default_config(build_lib, package):
     else:
         builtins = '__builtin__'
 
+    # astropy may have been built with a numpy that setuptools
+    # downloaded and installed into the current directory for us.
+    # Therefore, we need to extend the sys.path of the subprocess
+    # that's generating the config file, with the sys.path of this
+    # process.
+
     subproccode = (
+        'import sys; sys.path.extend({paths!r});'
         'import {builtins};{builtins}._ASTROPY_SETUP_ = True;'
         'from astropy.config.configuration import generate_all_config_items;'
         'generate_all_config_items({pkgnm!r}, True, filename={filenm!r})')
     subproccode = subproccode.format(builtins=builtins,
                                      pkgnm=package,
-                                     filenm=os.path.abspath(filename))
+                                     filenm=os.path.abspath(filename),
+                                     paths=sys.path)
 
     # Note that cwd=build_lib--we're importing astropy from the build/ dir
     # but using the astropy/ source dir as the config directory
@@ -739,6 +809,12 @@ if HAVE_SPHINX:
 
         description = 'Build Sphinx documentation for Astropy environment'
         user_options = SphinxBuildDoc.user_options[:]
+        user_options.append(('warnings-returncode', 'w',
+                             'Parses the sphinx output and sets the return '
+                             'code to 1 if there are any warnings. Note that '
+                             'this will cause the sphinx log to only update '
+                             'when it completes, rather than continuously as '
+                             'is normally the case.'))
         user_options.append(('clean-docs', 'l',
                              'Completely clean previous builds, including '
                              'automodapi-generated files before building new '
@@ -752,6 +828,7 @@ if HAVE_SPHINX:
                              'successfully.'))
 
         boolean_options = SphinxBuildDoc.boolean_options[:]
+        boolean_options.append('warnings-returncode')
         boolean_options.append('clean-docs')
         boolean_options.append('no-intersphinx')
         boolean_options.append('open-docs-in-browser')
@@ -763,11 +840,12 @@ if HAVE_SPHINX:
             self.clean_docs = False
             self.no_intersphinx = False
             self.open_docs_in_browser = False
+            self.warnings_returncode = False
 
         def finalize_options(self):
             #Clear out previous sphinx builds, if requested
             if self.clean_docs:
-                dirstorm = ['docs/_generated']
+                dirstorm = ['docs/api']
                 if self.build_dir is None:
                     dirstorm.append('docs/_build')
                 else:
@@ -786,23 +864,23 @@ if HAVE_SPHINX:
         def run(self):
             import webbrowser
 
-            from os.path import split, join, abspath
-            from distutils.cmd import DistutilsOptionError
-            from subprocess import Popen, PIPE
-            from inspect import getsourcelines
             if PY3:
                 from urllib.request import pathname2url
             else:
                 from urllib import pathname2url
 
+            # This is used at the very end of `run` to decide if sys.exit should
+            # be called. If it's None, it won't be.
+            retcode = None
+
             # If possible, create the _static dir
             if self.build_dir is not None:
                 # the _static dir should be in the same place as the _build dir
                 # for Astropy
-                basedir, subdir = split(self.build_dir)
+                basedir, subdir = os.path.split(self.build_dir)
                 if subdir == '':  # the path has a trailing /...
-                    basedir, subdir = split(basedir)
-                staticdir = join(basedir, '_static')
+                    basedir, subdir = os.path.split(basedir)
+                staticdir = os.path.join(basedir, '_static')
                 if os.path.isfile(staticdir):
                     raise DistutilsOptionError(
                         'Attempted to build_sphinx in a location where' +
@@ -820,7 +898,7 @@ if HAVE_SPHINX:
             #command.  This is needed to get the correct imports for the built
             #version
 
-            runlines, runlineno = getsourcelines(SphinxBuildDoc.run)
+            runlines, runlineno = inspect.getsourcelines(SphinxBuildDoc.run)
             subproccode = textwrap.dedent("""
             from sphinx.setup_command import *
 
@@ -856,13 +934,48 @@ if HAVE_SPHINX:
             log.debug('Starting subprocess of {0} with python code:\n{1}\n'
                       '[CODE END])'.format(sys.executable, subproccode))
 
-            proc = Popen([sys.executable], stdin=PIPE)
-            proc.communicate(subproccode.encode('utf-8'))
+            # To return the number of warnings, we need to capture stdout. This
+            # prevents a continuous updating at the terminal, but there's no
+            # apparent way around this.
+            if self.warnings_returncode:
+                proc = subprocess.Popen([sys.executable],
+                                        stdin=subprocess.PIPE,
+                                        stdout=subprocess.PIPE,
+                                        stderr=subprocess.STDOUT)
+                stdo, stde = proc.communicate(subproccode)
+
+                print(stdo)
+
+                stdolines = stdo.split('\n')
+
+                if stdolines[-2] == 'build succeeded.':
+                    retcode = 0
+                else:
+                    retcode = 1
+
+                if retcode != 0:
+                    if os.environ.get('TRAVIS', None) == 'true':
+                        #this means we are in the travis build, so customize
+                        #the message appropriately.
+                        msg = ('The build_sphinx travis build FAILED '
+                               'because sphinx issued documentation '
+                               'warnings (scroll up to see the warnings).')
+                    else:  # standard failure message
+                        msg = ('build_sphinx returning a non-zero exit '
+                               'code because sphinx issued documentation '
+                               'warnings.')
+                    log.warn(msg)
+
+            else:
+                proc = subprocess.Popen([sys.executable], stdin=subprocess.PIPE)
+                proc.communicate(subproccode.encode('utf-8'))
+
             if proc.returncode == 0:
                 if self.open_docs_in_browser:
                     if self.builder == 'html':
-                        absdir = abspath(self.builder_target_dir)
-                        fileurl = 'file://' + pathname2url(join(absdir, 'index.html'))
+                        absdir = os.path.abspath(self.builder_target_dir)
+                        index_path = os.path.join(absdir, 'index.html')
+                        fileurl = 'file://' + pathname2url(index_path)
                         webbrowser.open(fileurl)
                     else:
                         log.warn('open-docs-in-browser option was given, but '
@@ -871,6 +984,13 @@ if HAVE_SPHINX:
                 log.warn('Sphinx Documentation subprocess failed with return '
                          'code ' + str(proc.returncode))
 
+            if retcode is not None:
+                # this is potentially dangerous in that there might be something
+                # after the call to `setup` in `setup.py`, and exiting here will
+                # prevent that from running.  But there's no other apparent way
+                # to signal what the return code should be.
+                sys.exit(retcode)
+
 
 def get_distutils_display_options():
     """ Returns a set of all the distutils display options in their long and
@@ -892,7 +1012,15 @@ def get_distutils_display_options():
     short_display_opts.add('-h')
     long_display_opts.add('--help')
 
-    return short_display_opts.union(long_display_opts)
+    # This isn't the greatest approach to hardcode these commands.
+    # However, there doesn't seem to be a good way to determine
+    # whether build *will be* run as part of the command at this
+    # phase.
+    display_commands = set([
+        'clean', 'register', 'setopt', 'saveopts', 'egg_info',
+        'alias'])
+
+    return short_display_opts.union(long_display_opts.union(display_commands))
 
 
 def is_distutils_display_option():
@@ -906,31 +1034,71 @@ def is_distutils_display_option():
 
 def update_package_files(srcdir, extensions, package_data, packagenames,
                          package_dirs):
-    """ Extends existing extensions, package_data, packagenames and
-    package_dirs collections by iterating through all packages in
-    ``srcdir`` and locating a ``setup_package.py`` module.  This
-    module can contain the following functions: ``get_extensions()``,
-    ``get_package_data()``, ``get_legacy_alias()``,
-    ``get_build_options()``, and ``get_external_libraries()``.
+    """
+    This function is deprecated and maintained for backward compatibility
+    with affiliated packages.  Affiliated packages should update their
+    setup.py to use `get_package_info` instead.
+    """
+    warnings.warn(
+        "astropy.setup_helpers.update_package_files is deprecated.  Update "
+        "your setup.py to use astropy.setup_helpers.get_package_info instead.",
+        AstropyDeprecationWarning)
 
-    Each of those functions take no arguments.  ``get_extensions``
-    returns a list of `distutils.extension.Extension` objects.
-    ``get_package_data()`` returns a dict formatted as required by the
-    ``package_data`` argument to ``setup()``.  ``get_legacy_alias()``
-    should call `add_legacy_alias` and return its result.
-    ``get_build_options()`` returns a list of tuples describing the
-    extra build options to add.  ``get_external_libraries()`` returns
-    a list of libraries that can optionally be built using external
-    dependencies.
+    info = get_package_info(srcdir)
+    extensions.extend(info['ext_modules'])
+    package_data.update(info['package_data'])
+    packagenames = list(set(packagenames + info['packages']))
+    package_dirs.update(info['package_dir'])
+
+
+def get_package_info(srcdir):
+    """
+    Collates all of the information for building all subpackages
+    subpackages and returns a dictionary of keyword arguments that can
+    be passed directly to `distutils.setup`.
 
     The purpose of this function is to allow subpackages to update the
     arguments to the package's ``setup()`` function in its setup.py
     script, rather than having to specify all extensions/package data
-    directly in the setup.py.  It updates existing lists in the
-    setup.py rather than returning new ones.  See Astropy's own
+    directly in the ``setup.py``.  See Astropy's own
     ``setup.py`` for example usage and the Astropy development docs
     for more details.
+
+    This function obtains that information by iterating through all
+    packages in ``srcdir`` and locating a ``setup_package.py`` module.
+    This module can contain the following functions:
+    ``get_extensions()``, ``get_package_data()``,
+    ``get_build_options()``, ``get_external_libraries()``,
+    and ``requires_2to3()``.
+
+    Each of those functions take no arguments.
+
+    - ``get_extensions`` returns a list of
+      `distutils.extension.Extension` objects.
+
+    - ``get_package_data()`` returns a dict formatted as required by
+      the ``package_data`` argument to ``setup()``.
+
+    - ``get_build_options()`` returns a list of tuples describing the
+      extra build options to add.
+
+    - ``get_external_libraries()`` returns
+      a list of libraries that can optionally be built using external
+      dependencies.
+
+    - ``requires_2to3()`` should return `True` when the source code
+      requires `2to3` processing to run on Python 3.x.  If
+      ``requires_2to3()`` is missing, it is assumed to return `True`.
+
     """
+    ext_modules = []
+    packages = []
+    package_data = {}
+    package_dir = {}
+    skip_2to3 = []
+
+    # Use the find_packages tool to locate all packages and modules
+    packages = filter_packages(find_packages())
 
     # For each of the setup_package.py modules, extract any
     # information that is needed to install them.  The build options
@@ -945,60 +1113,48 @@ def update_package_files(srcdir, extensions, package_data, packagenames,
             libraries = setuppkg.get_external_libraries()
             for library in libraries:
                 add_external_library(library)
-
-    # Check if all the legacy packages are needed
-    if get_distutils_build_or_install_option('enable_legacy'):
-        installed = []
-        for setuppkg in iter_setup_packages(srcdir):
-            if hasattr(setuppkg, 'get_legacy_alias'):
-                pkg, dir = setuppkg.get_legacy_alias()
-                if dir is None:
-                    installed.append(pkg)
-                else:
-                    packagenames.append(pkg)
-                    package_dirs[pkg] = dir
-        if len(installed) > 0:
-            lines = [
-                '-' * 60,
-                'The compatibility packages cannot be installed because the',
-                'following legacy packages are already installed:']
-            for pkg in installed:
-                lines.append("    * {0:s}".format(pkg))
-            lines.extend([
-                '',
-                'The compatibility packages can only be installed if none of',
-                'the corresponding legacy packages are present.',
-                '-' * 60
-                ])
-            log.warn('\n'.join(lines))
-            sys.exit(1)
+        if hasattr(setuppkg, 'requires_2to3'):
+            requires_2to3 = setuppkg.requires_2to3()
+        else:
+            requires_2to3 = True
+        if not requires_2to3:
+            skip_2to3.append(
+                os.path.dirname(setuppkg.__file__))
 
     for setuppkg in iter_setup_packages(srcdir):
         # get_extensions must include any Cython extensions by their .pyx
         # filename.
         if hasattr(setuppkg, 'get_extensions'):
-            extensions.extend(setuppkg.get_extensions())
+            ext_modules.extend(setuppkg.get_extensions())
         if hasattr(setuppkg, 'get_package_data'):
             package_data.update(setuppkg.get_package_data())
 
     # Locate any .pyx files not already specified, and add their extensions in.
     # The default include dirs include numpy to facilitate numerical work.
-    extensions.extend(get_cython_extensions(srcdir, extensions, ['numpy']))
+    ext_modules.extend(get_cython_extensions(srcdir, ext_modules, ['numpy']))
 
     # Now remove extensions that have the special name 'skip_cython', as they
     # exist Only to indicate that the cython extensions shouldn't be built
-    for i, ext in reversed(list(enumerate(extensions))):
+    for i, ext in reversed(list(enumerate(ext_modules))):
         if ext.name == 'skip_cython':
-            del extensions[i]
+            del ext_modules[i]
 
     # On Microsoft compilers, we need to pass the '/MANIFEST'
     # commandline argument.  This was the default on MSVC 9.0, but is
     # now required on MSVC 10.0, but it doesn't seeem to hurt to add
     # it unconditionally.
     if get_compiler_option() == 'msvc':
-        for ext in extensions:
+        for ext in ext_modules:
             ext.extra_link_args.append('/MANIFEST')
 
+    return {
+        'ext_modules': ext_modules,
+        'packages': packages,
+        'package_dir': package_dir,
+        'package_data': package_data,
+        'skip_2to3': skip_2to3
+        }
+
 
 def iter_setup_packages(srcdir):
     """ A generator that finds and imports all of the ``setup_package.py``
@@ -1083,7 +1239,7 @@ def get_cython_extensions(srcdir, prevextensions=tuple(), extincludedirs=None):
     ----------
     srcdir : str
         Path to the root of the source directory to search.
-    prevextensions: list of `~distutils.core.Extension` objects
+    prevextensions : list of `~distutils.core.Extension` objects
         The extensions that are already defined.  Any .pyx files already here
         will be ignored.
     extincludedirs : list of str or None
@@ -1141,35 +1297,28 @@ def write_if_different(filename, data):
             fd.write(data)
 
 
-def check_numpy():
-    """
-    Check that Numpy is installed and it is of the minimum version we
-    require.
-    """
-
-    requirement_met = False
-
-    try:
-        import numpy
-    except ImportError:
-        pass
-    else:
-        major, minor, rest = numpy.__version__.split(".", 2)
-        requirement_met = (int(major), int(minor)) >= (1, 4)
-
-    if not requirement_met:
-        msg = "numpy version 1.4 or later must be installed to build astropy"
-        raise ImportError(msg)
-
-    return numpy
-
-
 def get_numpy_include_path():
     """
     Gets the path to the numpy headers.
     """
+    # We need to go through this nonsense in case setuptools
+    # downloaded and installed Numpy for us as part of the build or
+    # install, since Numpy may still think it's in "setup mode", when
+    # in fact we're ready to use it to build astropy now.
 
-    numpy = check_numpy()
+    if sys.version_info[0] >= 3:
+        import builtins
+        if hasattr(builtins, '__NUMPY_SETUP__'):
+            del builtins.__NUMPY_SETUP__
+        import imp
+        import numpy
+        imp.reload(numpy)
+    else:
+        import __builtin__
+        if hasattr(__builtin__, '__NUMPY_SETUP__'):
+            del __builtin__.__NUMPY_SETUP__
+        import numpy
+        reload(numpy)
 
     try:
         numpy_include = numpy.get_include()
@@ -1196,138 +1345,6 @@ def import_file(filename):
         return imp.load_module(name, fd, filename, ('.py', 'U', 1))
 
 
-def get_legacy_alias_dir():
-    return os.path.join('build', 'legacy-aliases')
-
-
-legacy_shim_template = """
-# This is generated code.  DO NOT EDIT!
-
-from __future__ import absolute_import
-
-# This implements a PEP 302 finder/loader pair that translates
-# {old_package}.foo import {new_package}.foo.  This approach allows
-# relative imports in astropy that go above the level of the
-# {new_package} subpackage to work.
-class Finder(object):
-    def find_module(self, fullname, path=None):
-        if fullname.startswith("{old_package}."):
-            return self.Loader()
-
-    class Loader(object):
-        def load_module(self, fullname):
-            import importlib
-            fullname = fullname[len("{old_package}"):]
-            return importlib.import_module(fullname, package="{new_package}")
-
-import sys
-sys.meta_path.append(Finder())
-# Carefully clean up the namespace, since we can't use __all__ here
-del sys
-del Finder
-
-import warnings
-warnings.warn(
-    "{old_package} is deprecated.  Use {new_package} instead.",
-    DeprecationWarning)
-del warnings
-
-from {new_package} import *
-from astropy import __version__
-__version__ = {equiv_version!r} + '-' + __version__
-{extras}
-
-_is_astropy_legacy_alias = True
-"""
-
-
-def add_legacy_alias(old_package, new_package, equiv_version, extras={}):
-    """
-    Adds a legacy alias that makes *pkgfrom* also importable as
-    *pkgto*.
-
-    For example::
-
-       add_legacy_alias('astropy.io.votable', 'vo')
-
-    If the legacy package is importable and it is not merely the
-    compatibility shim, a warning is printed to the user, and the
-    shim is not installed.
-
-    Parameters
-    ----------
-    old_package : str
-        The old namespace.  Must be a single name (i.e. not have `.`).
-
-    new_package : str
-        The new namespace, specified using `.` as a delimiter
-
-    equiv_version : str
-        The equivalent version of the old package.  Code using the
-        legacy shim may do a version check, and this version should be
-        based on the version of the legacy package, not the version of
-        astropy.
-
-    extras : dict
-        A dictionary of extra values to include in the legacy shim template;
-        the keys should be the variable names, while the values will be written
-        to the template in their repr() form, so they should generally be
-        simple objects such as strings.
-
-    Returns
-    -------
-    old_package, shim_dir : (str, str)
-        The name of the alias package and its source directory in the
-        file system (useful for adding to distutils' `package_dir` kwarg.
-    """
-    import imp
-
-    # If legacy shims have not been enabled at the commandline, simply do
-    # nothing.
-    if not get_distutils_build_or_install_option('enable_legacy'):
-        return (old_package, None)
-
-    found_legacy_module = True
-    try:
-        location = imp.find_module(old_package)
-    except ImportError:
-        found_legacy_module = False
-    else:
-        # We want ImportError to raise here, because that means it was
-        # found, but something else went wrong.
-
-        # We could import the module here to determine if its "real"
-        # or just a legacy alias.  However, importing the legacy alias
-        # may cause importing of code within the astropy source tree,
-        # which may require 2to3 to have been run.  It's safer to just
-        # open the file and search for a string.
-        filename = os.path.join(location[1], '__init__.py')
-        if os.path.exists(filename):
-            with open(filename, 'U') as fd:
-                if '_is_astropy_legacy_alias' in fd.read():
-                    found_legacy_module = False
-
-    shim_dir = os.path.join(get_legacy_alias_dir(), old_package)
-
-    if found_legacy_module and not is_distutils_display_option():
-        if os.path.isdir(shim_dir):
-            shutil.rmtree(shim_dir)
-        return (old_package, None)
-
-    if extras:
-        extras = '\n'.join('{0} = {1!r}'.format(*v) for v in extras.items())
-    else:
-        extras = ''
-
-    if not os.path.isdir(shim_dir):
-        os.makedirs(shim_dir)
-    content = legacy_shim_template.format(**locals()).encode('utf-8')
-    write_if_different(
-        os.path.join(shim_dir, '__init__.py'), content)
-
-    return (old_package, shim_dir)
-
-
 class DistutilsExtensionArgs(collections.defaultdict):
     """
     A special dictionary whose default values are the empty list.
@@ -1439,7 +1456,7 @@ def add_external_library(library):
     """
 
     for command in ['build', 'build_ext', 'install']:
-        add_command_option(command, 'use-system-' + library,
+        add_command_option(command, str('use-system-' + library),
                            'Use the system {0} library'.format(library),
                            is_bool=True)
 
@@ -1644,5 +1661,3 @@ class FakeBuildSphinx(Command):
         except:
             log.error('error : Sphinx must be installed for build_sphinx')
             sys.exit(1)
-
-
