@@ -1,4 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+
+import os
+
 from ....tests.helper import pytest
 pytest.importorskip('sphinx')  # skips these tests if sphinx not present
 
@@ -16,8 +19,17 @@ class FakeApp(object):
     """
     Mocks up a `sphinx.application.Application` object for automodapi tests
     """
+
+    # Some default config values
+    _defaults = {
+        'automodapi_toctreedirnm': 'api',
+        'automodapi_writereprocessed': False
+    }
+
     def __init__(self, **configs):
-        self.config = FakeConfig(**configs)
+        config = self._defaults.copy()
+        config.update(configs)
+        self.config = FakeConfig(**config)
         self.info = []
         self.warnings = []
 
@@ -50,7 +62,7 @@ Functions
 
 .. automodsumm:: astropy.sphinx.ext.tests.test_automodapi
     :functions-only:
-    :toctree: _generated/
+    :toctree: api/
     {empty}
 
 Classes
@@ -58,7 +70,7 @@ Classes
 
 .. automodsumm:: astropy.sphinx.ext.tests.test_automodapi
     :classes-only:
-    :toctree: _generated/
+    :toctree: api/
     {empty}
 
 Class Inheritance Diagram
@@ -68,7 +80,8 @@ Class Inheritance Diagram
     :private-bases:
 
 This comes after
-""".format(empty='')  # necessary for editors that remove empty-line whitespace
+""".format(empty='').replace('/', os.sep)
+# the .format is necessary for editors that remove empty-line whitespace
 
 
 def test_am_replacer_basic():
@@ -78,7 +91,7 @@ def test_am_replacer_basic():
     """
     from ..automodapi import automodapi_replace
 
-    fakeapp = FakeApp(automodapi_toctreedirnm='_generated/')
+    fakeapp = FakeApp()
     result = automodapi_replace(am_replacer_str.format(options=''), fakeapp)
 
     assert result == am_replacer_basic_expected
@@ -96,7 +109,7 @@ Functions
 
 .. automodsumm:: astropy.sphinx.ext.tests.test_automodapi
     :functions-only:
-    :toctree: _generated/
+    :toctree: api/
     {empty}
 
 Classes
@@ -104,12 +117,12 @@ Classes
 
 .. automodsumm:: astropy.sphinx.ext.tests.test_automodapi
     :classes-only:
-    :toctree: _generated/
+    :toctree: api/
     {empty}
 
 
 This comes after
-""".format(empty='')  # necessary for editors that remove empty-line whitespace
+""".format(empty='').replace('/', os.sep)
 
 
 def test_am_replacer_noinh():
@@ -119,7 +132,7 @@ def test_am_replacer_noinh():
     """
     from ..automodapi import automodapi_replace
 
-    fakeapp = FakeApp(automodapi_toctreedirnm='_generated/')
+    fakeapp = FakeApp()
     ops = ['', ':no-inheritance-diagram:']
     ostr = '\n    '.join(ops)
     result = automodapi_replace(am_replacer_str.format(options=ostr), fakeapp)
@@ -139,7 +152,7 @@ Functions
 
 .. automodsumm:: astropy.sphinx.ext.tests.test_automodapi
     :functions-only:
-    :toctree: _generated/
+    :toctree: api/
     {empty}
 
 Classes
@@ -147,7 +160,7 @@ Classes
 
 .. automodsumm:: astropy.sphinx.ext.tests.test_automodapi
     :classes-only:
-    :toctree: _generated/
+    :toctree: api/
     {empty}
 
 Class Inheritance Diagram
@@ -158,7 +171,7 @@ Class Inheritance Diagram
 
 
 This comes after
-""".format(empty='')  # necessary for editors that remove empty-line whitespace
+""".format(empty='').replace('/', os.sep)
 
 
 def test_am_replacer_titleandhdrs():
@@ -168,7 +181,7 @@ def test_am_replacer_titleandhdrs():
     """
     from ..automodapi import automodapi_replace
 
-    fakeapp = FakeApp(automodapi_toctreedirnm='_generated/')
+    fakeapp = FakeApp()
     ops = ['', ':title: A new title', ':headings: &*']
     ostr = '\n    '.join(ops)
     result = automodapi_replace(am_replacer_str.format(options=ostr), fakeapp)
@@ -198,12 +211,12 @@ Functions
 
 .. automodsumm:: astropy.sphinx.ext.automodapi
     :functions-only:
-    :toctree: _generated/
+    :toctree: api/
     {empty}
 
 
 This comes after
-""".format(empty='')  # necessary for editors that remove empty-line whitespace
+""".format(empty='').replace('/', os.sep)
 
 
 def test_am_replacer_nomain():
@@ -212,7 +225,7 @@ def test_am_replacer_nomain():
     """
     from ..automodapi import automodapi_replace
 
-    fakeapp = FakeApp(automodapi_toctreedirnm='_generated/')
+    fakeapp = FakeApp()
     result = automodapi_replace(am_replacer_nomain_str, fakeapp)
 
     assert result == am_replacer_nomain_expected
@@ -241,12 +254,12 @@ Functions
 
 .. automodsumm:: astropy.sphinx.ext.automodapi
     :functions-only:
-    :toctree: _generated/
+    :toctree: api/
     :skip: something1,something2
 
 
 This comes after
-""".format(empty='')  # necessary for editors that remove empty-line whitespace
+""".format(empty='').replace('/', os.sep)
 
 
 def test_am_replacer_skip():
@@ -255,7 +268,7 @@ def test_am_replacer_skip():
     """
     from ..automodapi import automodapi_replace
 
-    fakeapp = FakeApp(automodapi_toctreedirnm='_generated/')
+    fakeapp = FakeApp()
     result = automodapi_replace(am_replacer_skip_str, fakeapp)
 
     assert result == am_replacer_skip_expected
@@ -277,7 +290,7 @@ def test_am_replacer_invalidop():
     """
     from ..automodapi import automodapi_replace
 
-    fakeapp = FakeApp(automodapi_toctreedirnm='_generated/')
+    fakeapp = FakeApp()
     automodapi_replace(am_replacer_invalidop_str, fakeapp)
 
     expected_warnings = [('Found additional options invalid-option in '
