@@ -212,10 +212,14 @@ def pytest_configure(config):
 
                     last_line = lines[-1]
                     match = re.match(
-                        r'\.\.\s+doctest-skip\s*::', last_line)
+                        r'\.\.\s+doctest-skip\s*::(\s+.*)?', last_line)
                     if match:
-                        skip_next = True
-                        continue
+                        marker = match.group(1)
+                        if (marker is None or
+                                (marker.strip() == 'win32' and
+                                 sys.platform == 'win32')):
+                            skip_next = True
+                            continue
 
                     match = re.match(
                         r'\.\.\s+doctest-requires\s*::\s+(.*)',
@@ -238,6 +242,10 @@ def pytest_configure(config):
                     config.getini('doctest_rst') or config.option.doctest_rst),
         'doctestplus')
 
+    # Remove the doctest_plugin, or we'll end up testing the .rst
+    # files twice.
+    config.pluginmanager.unregister(doctest_plugin)
+
 
 class DoctestPlus(object):
     def __init__(self, doctest_module_item_cls, doctest_textfile_item_cls,
@@ -254,6 +262,9 @@ class DoctestPlus(object):
         self._doctest_textfile_item_cls = doctest_textfile_item_cls
         self._run_rst_doctests = run_rst_doctests
 
+        # Directories to ignore when adding doctests
+        self._ignore_paths = []
+
         if run_rst_doctests and six.PY3:
             warnings.warn(
                 "Running doctests in .rst files is not yet supported on Python 3")
@@ -264,7 +275,13 @@ class DoctestPlus(object):
 
         for pattern in config.getini("doctest_norecursedirs"):
             if path.check(fnmatch=pattern):
-                return True
+                # Apparently pytest_ignore_collect causes files not to be
+                # collected by any test runner; for DoctestPlus we only want to
+                # avoid creating doctest nodes for them
+                self._ignore_paths.append(path)
+                break
+
+        return False
 
     def pytest_collect_file(self, path, parent):
         """Implements an enhanced version of the doctest module from py.test
@@ -297,6 +314,11 @@ class DoctestPlus(object):
             __doctest_requires__ = {('func1', 'func2'): ['scipy']}
 
         """
+
+        for ignore_path in self._ignore_paths:
+            if ignore_path.common(path) == ignore_path:
+                return None
+
         if path.ext == '.py':
             if path.basename == 'conf.py':
                 return None
