@@ -130,8 +130,12 @@ class Time(object):
             self = val.replicate(format=format, copy=copy)
         else:
             self = super(Time, cls).__new__(cls)
+
         return self
 
+    def __getnewargs__(self):
+        return (self._time,)
+
     def __init__(self, val, val2=None, format=None, scale=None,
                  precision=None, in_subfmt=None, out_subfmt=None,
                  lat=0.0, lon=0.0, copy=False):
@@ -635,8 +639,10 @@ class Time(object):
 
             >>> from astropy.utils.iers import IERS_A, IERS_A_URL
             >>> from astropy.utils.data import download_file
+            >>> t = Time(['1974-01-01', '2000-01-01'], scale='utc')
             >>> iers_a_file = download_file(IERS_A_URL,
             ...                             cache=True)        # doctest: +REMOTE_DATA
+            Downloading ... [Done]
             >>> iers_a = IERS_A.open(iers_a_file)              # doctest: +REMOTE_DATA
             >>> t.delta_ut1_utc = t.get_delta_ut1_utc(iers_a)  # doctest: +REMOTE_DATA
 
@@ -1092,7 +1098,12 @@ class TimeFormat(object):
 
 
 class TimeJD(TimeFormat):
-    """Julian Date time format"""
+    """
+    Julian Date time format.
+    This represents the number of days since the beginning of
+    the Julian Period.
+    For example, 2451544.5 in JD is midnight on January 1, 2000.
+    """
     name = 'jd'
 
     def set_jds(self, val1, val2):
@@ -1105,7 +1116,11 @@ class TimeJD(TimeFormat):
 
 
 class TimeMJD(TimeFormat):
-    """Modified Julian Date time format"""
+    """
+    Modified Julian Date time format.
+    This represents the number of days since midnight on November 17, 1858.
+    For example, 51544.0 in MJD is midnight on January 1, 2000.
+    """
     name = 'mjd'
 
     def set_jds(self, val1, val2):
@@ -1185,6 +1200,7 @@ class TimeFromEpoch(TimeFormat):
 class TimeUnix(TimeFromEpoch):
     """
     Unix time: seconds from 1970-01-01 00:00:00 UTC.
+    For example, 946684800.0 in Unix time is midnight on January 1, 2000.
 
     NOTE: this quantity is not exactly unix time and differs from the strict
     POSIX definition by up to 1 second on days with a leap second.  POSIX
@@ -1201,7 +1217,10 @@ class TimeUnix(TimeFromEpoch):
 
 
 class TimeCxcSec(TimeFromEpoch):
-    """Chandra X-ray Center seconds from 1998-01-01 00:00:00 TT"""
+    """
+    Chandra X-ray Center seconds from 1998-01-01 00:00:00 TT.
+    For example, 63072064.184 is midnight on January 1, 2000.
+    """
     name = 'cxcsec'
     unit = 1.0 / SECS_PER_DAY  # in days (1 day == 86400 seconds)
     epoch_val = '1998-01-01 00:00:00'
@@ -1212,6 +1231,7 @@ class TimeCxcSec(TimeFromEpoch):
 
 class TimeGPS(TimeFromEpoch):
     """GPS time: seconds from 1980-01-06 00:00:00 UTC
+    For example, 630720013.0 is midnight on January 1, 2000.
 
     GPS time includes leap seconds.  For details, see
     http://tycho.usno.navy.mil/gpstt.html
@@ -1237,6 +1257,8 @@ class TimePlotDate(TimeFromEpoch):
       >>> plt.plot_date(t.plot_date, jyear)
       >>> plt.gcf().autofmt_xdate()  # orient date labels at a slant
       >>> plt.draw()
+
+    For example, 730120.0003703703 is midnight on January 1, 2000.
     """
     # This corresponds to the zero reference time for matplotlib plot_date().
     # Note that TAI and UTC are equivalent at the reference time.
@@ -1475,7 +1497,8 @@ class TimeString(TimeUnique):
 class TimeISO(TimeString):
     """
     ISO 8601 compliant date-time format "YYYY-MM-DD HH:MM:SS.sss...".
-
+    For example, 2000-01-01 00:00:00.000 is midnight on January 1, 2000.
+    
     The allowed subformats are:
 
     - 'date_hms': date + hours, mins, secs (and optional fractional secs)
@@ -1501,6 +1524,7 @@ class TimeISOT(TimeString):
     ISO 8601 compliant date-time format "YYYY-MM-DDTHH:MM:SS.sss...".
     This is the same as TimeISO except for a "T" instead of space between
     the date and time.
+    For example, 2000-01-01T00:00:00.000 is midnight on January 1, 2000.
 
     The allowed subformats are:
 
@@ -1523,8 +1547,9 @@ class TimeISOT(TimeString):
 
 class TimeYearDayTime(TimeString):
     """
-    Year, day-of-year and time as "YYYY:DOY:HH:MM:SS.sss...".  The
-    day-of-year (DOY) goes from 001 to 365 (366 in leap years).
+    Year, day-of-year and time as "YYYY:DOY:HH:MM:SS.sss...".
+    The day-of-year (DOY) goes from 001 to 365 (366 in leap years).
+    For example, 2000:001:00:00:00.000 is midnight on January 1, 2000.
 
     The allowed subformats are:
 
