@@ -1,15 +1,24 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+
+import copy
 import functools
+import sys
+
+from datetime import datetime
 
 import numpy as np
 
 from ...tests.helper import pytest
-from .. import Time, ScaleValueError, sofa_time
+from .. import Time, ScaleValueError, erfa_time, TIME_SCALES
 
-allclose_jd = functools.partial(np.allclose, rtol=1e-15, atol=0)
-allclose_jd2 = functools.partial(np.allclose, rtol=1e-15, atol=1e-11)  # 1 microsec atol
-allclose_sec = functools.partial(np.allclose, rtol=1e-15, atol=1e-9)  # 1 nanosec atol
-allclose_year = functools.partial(np.allclose, rtol=1e-15, atol=0)  # 60 microsec at current epoch
+
+allclose_jd = functools.partial(np.allclose, rtol=2. ** -52, atol=0)
+allclose_jd2 = functools.partial(np.allclose, rtol=2. ** -52,
+                                 atol=2. ** -52)  # 20 ps atol
+allclose_sec = functools.partial(np.allclose, rtol=2. ** -52,
+                                 atol=2. ** -52 * 24 * 3600)  # 20 ps atol
+allclose_year = functools.partial(np.allclose, rtol=2. ** -52,
+                                  atol=0.)  # 14 microsec at current epoch
 
 
 class TestBasic():
@@ -19,14 +28,15 @@ class TestBasic():
         times = ['1999-01-01 00:00:00.123456789', '2010-01-01 00:00:00']
         t = Time(times, format='iso', scale='utc')
         assert (repr(t) == "<Time object: scale='utc' format='iso' "
-                "vals=['1999-01-01 00:00:00.123' '2010-01-01 00:00:00.000']>")
+                "value=['1999-01-01 00:00:00.123' '2010-01-01 00:00:00.000']>")
         assert allclose_jd(t.jd1, np.array([2451179.5, 2455197.5]))
-        assert allclose_jd2(t.jd2, np.array([1.42889802e-06, 0.00000000e+00]))
+        assert allclose_jd2(t.jd2, np.array([1.4288980208333335e-06,
+                                             0.00000000e+00]))
 
         # Set scale to TAI
         t = t.tai
         assert (repr(t) == "<Time object: scale='tai' format='iso' "
-                "vals=['1999-01-01 00:00:32.123' '2010-01-01 00:00:34.000']>")
+                "value=['1999-01-01 00:00:32.123' '2010-01-01 00:00:34.000']>")
         assert allclose_jd(t.jd1, np.array([2451179.5, 2455197.5]))
         assert allclose_jd2(t.jd2, np.array([0.00037179926839122024, 0.00039351851851851852]))
 
@@ -34,13 +44,12 @@ class TestBasic():
         # (internal JD1 and JD1 are now with respect to TT scale)"""
 
         assert (repr(t.tt) == "<Time object: scale='tt' format='iso' "
-                "vals=['1999-01-01 00:01:04.307' '2010-01-01 00:01:06.184']>")
+                "value=['1999-01-01 00:01:04.307' '2010-01-01 00:01:06.184']>")
 
         # Get the representation of the ``Time`` object in a particular format
         # (in this case seconds since 1998.0).  This returns either a scalar or
         # array, depending on whether the input was a scalar or array"""
 
-        print t.cxcsec
         assert allclose_sec(t.cxcsec, np.array([31536064.307456788, 378691266.18400002]))
 
     def test_copy_time(self):
@@ -63,9 +72,40 @@ class TestBasic():
 
         # Include initializers
         t2 = Time(t, format='iso', scale='tai', precision=1)
-        assert t2.val == '2010-01-01 00:00:34.0'
+        assert t2.value == '2010-01-01 00:00:34.0'
         t2 = Time(t, format='iso', scale='tai', out_subfmt='date')
-        assert t2.val == '2010-01-01'
+        assert t2.value == '2010-01-01'
+
+    def test_getitem(self):
+        """Test that Time objects holding arrays are properly subscriptable,
+        set isscalar as appropriate, and also subscript delta_ut1_utc, etc."""
+
+        mjd = np.arange(50000, 50010)
+        t = Time(mjd, format='mjd', scale='utc')
+        t1 = t[3]
+        assert t1.isscalar is True
+        assert np.all(t1._time.jd1 == np.array([t._time.jd1[3]]))
+        t1a = Time(mjd[3], format='mjd', scale='utc')
+        assert t1a.isscalar is True
+        assert np.all(t1._time.jd1 == t1a._time.jd1)
+        t1b = Time(t[3])
+        assert t1b.isscalar is True
+        assert np.all(t1._time.jd1 == t1b._time.jd1)
+        t2 = t[4:6]
+        assert t2.isscalar is False
+        assert np.all(t2._time.jd1 == t._time.jd1[4:6])
+        t2a = Time(t[4:6])
+        assert t2a.isscalar is False
+        assert np.all(t2a._time.jd1 == t._time.jd1[4:6])
+        t2b = Time([t[4], t[5]])
+        assert t2b.isscalar is False
+        assert np.all(t2b._time.jd1 == t._time.jd1[4:6])
+        t2c = Time((t[4], t[5]))
+        assert t2c.isscalar is False
+        assert np.all(t2c._time.jd1 == t._time.jd1[4:6])
+        t.delta_tdb_tt = np.arange(len(t))  # Explicitly set (not testing .tdb)
+        t3 = t[4:6]
+        assert np.all(t3._delta_tdb_tt == t._delta_tdb_tt[4:6])
 
     def test_properties(self):
         """Use properties to convert scales and formats.  Note that the UT1 to
@@ -84,6 +124,8 @@ class TestBasic():
         assert t.tcg.isot == '2010-01-01T00:01:06.910'
         assert allclose_sec(t.unix, 1262304000.0)
         assert allclose_sec(t.cxcsec, 378691266.184)
+        assert allclose_sec(t.gps, 946339215.0)
+        assert t.datetime == datetime(2010, 1, 1)
 
     def test_precision(self):
         """Set the output precision which is used for some formats.  This is
@@ -126,13 +168,27 @@ class TestBasic():
         assert t.tai.iso == '2006-01-15 21:25:10.500000'
         assert t.tt.iso == '2006-01-15 21:25:42.684000'
         assert t.tcg.iso == '2006-01-15 21:25:43.322690'
-        assert t.tdb.iso == '2006-01-15 21:25:42.683799'
-        assert t.tcb.iso == '2006-01-15 21:25:56.893378'
+        assert t.tdb.iso == '2006-01-15 21:25:42.684373'
+        assert t.tcb.iso == '2006-01-15 21:25:56.893952'
+
+    def test_all_transforms(self):
+        """Test that all transforms work.  Does not test correctness,
+        except reversibility [#2074]"""
+        lat = 19.48125
+        lon = -155.933222
+        for scale1 in TIME_SCALES:
+            t1 = Time('2006-01-15 21:24:37.5', format='iso', scale=scale1,
+                      lat=lat, lon=lon)
+            for scale2 in TIME_SCALES:
+                t2 = getattr(t1, scale2)
+                t21 = getattr(t2, scale1)
+                assert allclose_jd(t21.jd, t1.jd)
 
     def test_creating_all_formats(self):
         """Create a time object using each defined format"""
         Time(100.0, format='cxcsec')
         Time(100.0, format='unix')
+        Time(100.0, format='gps')
         Time(1950.0, format='byear', scale='tai')
         Time(2000.0, format='jyear', scale='tai')
         Time('B1950.0', format='byear_str', scale='tai')
@@ -142,6 +198,29 @@ class TestBasic():
         Time(2400000.5, 51544.0333981, format='jd', scale='tai')
         Time(0.0, 51544.0333981, format='mjd', scale='tai')
         Time('2000:001:12:23:34.0', format='yday', scale='tai')
+        dt = datetime(2000, 1, 2, 3, 4, 5, 123456)
+        Time(dt, format='datetime', scale='tai')
+        Time([dt, dt], format='datetime', scale='tai')
+
+    def test_datetime(self):
+        """
+        Test datetime format, including guessing the format from the input type
+        by not providing the format keyword to Time.
+        """
+        dt = datetime(2000, 1, 2, 3, 4, 5, 123456)
+        dt2 = datetime(2001, 1, 1)
+        t = Time(dt, scale='utc', precision=9)
+        assert t.iso == '2000-01-02 03:04:05.123456000'
+        assert t.datetime == dt
+        assert t.value == dt
+        t2 = Time(t.iso, scale='utc')
+        assert t2.datetime == dt
+
+        t = Time([dt, dt2], scale='utc')
+        assert np.all(t.value == [dt, dt2])
+
+        t = Time('2000-01-01 01:01:01.123456789', scale='tai')
+        assert t.datetime == datetime(2000, 1, 1, 1, 1, 1, 123457)
 
     def test_epoch_transform(self):
         """Besselian and julian epoch transforms"""
@@ -198,6 +277,37 @@ class TestBasic():
         t1 = Time('2012-07-01 00:00:00', scale='utc')
         assert allclose_sec((t1 - t0).sec, 2.0)
 
+    def test_init_from_time_objects(self):
+        """Initialize from one or more Time objects"""
+        t1 = Time('2007:001', scale='tai')
+        t2 = Time(['2007-01-02', '2007-01-03'], scale='utc')
+        # Init from a list of Time objects without an explicit scale
+        t3 = Time([t1, t2])
+        # Test that init appropriately combines a scalar (t1) and list (t2)
+        # and that scale and format are same as first element.
+        assert len(t3) == 3
+        assert t3.scale == t1.scale
+        assert t3.format == t1.format  # t1 format is yday
+        assert np.all(t3.value == np.concatenate([[t1.yday], t2.tai.yday]))
+
+        # Init from a single Time object without a scale
+        t3 = Time(t1)
+        assert t3.isscalar
+        assert t3.scale == t1.scale
+        assert t3.format == t1.format
+        assert np.all(t3.value == t1.value)
+
+        # Init from a single Time object with scale specified
+        t3 = Time(t1, scale='utc')
+        assert t3.scale == 'utc'
+        assert np.all(t3.value == t1.utc.value)
+
+        # Init from a list of Time object with scale specified
+        t3 = Time([t1, t2], scale='tt')
+        assert t3.scale == 'tt'
+        assert t3.format == t1.format  # yday
+        assert np.all(t3.value == np.concatenate([[t1.tt.yday], t2.tt.yday]))
+
 
 class TestVal2():
     """Tests related to val2"""
@@ -238,7 +348,7 @@ class TestSubFormat():
         times = ['2000-01-01 01:01',
                  '2000-01-01 01:01:01', '2000-01-01 01:01:01.123']
         t = Time(times, format='iso', scale='tai',
-                     in_subfmt='date_*')
+                 in_subfmt='date_*')
         assert np.all(t.iso == np.array(['2000-01-01 01:01:00.000',
                                          '2000-01-01 01:01:01.000',
                                          '2000-01-01 01:01:01.123']))
@@ -247,13 +357,13 @@ class TestSubFormat():
         """Failed format matching"""
         with pytest.raises(ValueError):
             Time('2000-01-01 01:01', format='iso', scale='tai',
-                     in_subfmt='date')
+                 in_subfmt='date')
 
     def test_bad_input_subformat(self):
         """Non-existent input subformat"""
         with pytest.raises(ValueError):
             Time('2000-01-01 01:01', format='iso', scale='tai',
-                     in_subfmt='doesnt exist')
+                 in_subfmt='doesnt exist')
 
     def test_output_subformat(self):
         """Input subformat selection"""
@@ -261,7 +371,7 @@ class TestSubFormat():
         times = ['2000-01-01', '2000-01-01 01:01',
                  '2000-01-01 01:01:01', '2000-01-01 01:01:01.123']
         t = Time(times, format='iso', scale='tai',
-                     out_subfmt='date_hm')
+                 out_subfmt='date_hm')
         assert np.all(t.iso == np.array(['2000-01-01 00:00',
                                          '2000-01-01 01:01',
                                          '2000-01-01 01:01',
@@ -287,6 +397,8 @@ class TestSubFormat():
         assert t.scale == 'utc'
         t = Time(100.0, format='unix', scale='tai')
         assert t.scale == 'tai'
+        t = Time(100.0, format='gps', scale='utc')
+        assert t.scale == 'utc'
 
         # Check that bad scale is caught when format is specified
         with pytest.raises(ScaleValueError):
@@ -307,7 +419,7 @@ class TestSubFormat():
 
         # Create new time object from this one and change scale, format
         t2 = Time(t, scale='tt', format='iso')
-        assert t2.val == '1998-01-01 00:00:00.000'
+        assert t2.value == '1998-01-01 00:00:00.000'
 
         # Value take from Chandra.Time.DateTime('2010:001:00:00:00').secs
         t = Time(378691266.184, format='cxcsec', scale='utc')
@@ -316,6 +428,12 @@ class TestSubFormat():
         assert allclose_sec(t.cxcsec, 378691266.184)
         assert allclose_sec(t.tt.cxcsec, 378691266.184)
 
+        # Value from:
+        #   d = datetime.datetime(2000, 1, 1)
+        #   matplotlib.pylab.dates.date2num(d)
+        t = Time('2000-01-01 00:00:00', scale='utc')
+        assert np.allclose(t.plot_date, 730120.0, atol=1e-5, rtol=0)
+
         # Round trip through epoch time
         for scale in ('utc', 'tt'):
             t = Time('2000:001', scale=scale)
@@ -333,20 +451,20 @@ class TestSubFormat():
 
 
 class TestSofaErrors():
-    """Test that sofa_time.pyx handles sofa status return values correctly"""
+    """Test that erfa_time.pyx handles erfa status return values correctly"""
 
     def test_bad_time(self):
         iy = np.array([2000], dtype=np.intc)
-        im = np.array([2000], dtype=np.intc) # bad month
-        id = np.array([2000], dtype=np.intc) # bad day
+        im = np.array([2000], dtype=np.intc)  # bad month
+        id = np.array([2000], dtype=np.intc)  # bad day
         djm0 = np.array([0], dtype=np.double)
         djm = np.array([0], dtype=np.double)
         with pytest.raises(ValueError):  # bad month, fatal error
-            sofa_time.cal2jd(iy, im, id, djm0, djm)
+            erfa_time.cal2jd(iy, im, id, djm0, djm)
 
         # Set month to a good value so now the bad day just gives a warning
         im[0] = 2
-        sofa_time.cal2jd(iy, im, id, djm0, djm)
+        erfa_time.cal2jd(iy, im, id, djm0, djm)
         assert allclose_jd(djm0, [2400000.5])
         assert allclose_jd(djm, [53574.])
 
@@ -357,21 +475,14 @@ class TestSofaErrors():
 class TestCopyReplicate():
     """Test issues related to copying and replicating data"""
 
-    def test_mutable_input(self):
-        """By default if JDs are provided with copy=False then internals are
-        mutable."""
+    def test_immutable_input(self):
+        """Internals are never mutable."""
         jds = np.array([2450000.5], dtype=np.double)
         t = Time(jds, format='jd', scale='tai')
         assert allclose_jd(t.jd, jds)
-        jds[0] = 2459009.5
-        assert allclose_jd(t.jd, jds)
-
-        t = Time(jds, format='jd', scale='tai', copy=True)
-        assert allclose_jd(t.jd, jds)
         jds[0] = 2458654
         assert not allclose_jd(t.jd, jds)
 
-        # MJD does not suffer from this mutability
         mjds = np.array([50000.0], dtype=np.double)
         t = Time(mjds, format='mjd', scale='tai')
         assert allclose_jd(t.jd, [2450000.5])
@@ -404,12 +515,55 @@ class TestCopyReplicate():
         assert t.yday != t2.yday
         assert t.yday == t_yday  # prove that it did not change
 
-def test_python_builtin_copy():
-    import copy
 
+def test_python_builtin_copy():
     t = Time('2000:001', format='yday', scale='tai')
     t2 = copy.copy(t)
     t3 = copy.deepcopy(t)
 
     assert t.jd == t2.jd
     assert t.jd == t3.jd
+
+
+def test_now():
+    """
+    Tests creating a Time object with the `now` class method.
+    """
+
+    now = datetime.utcnow()
+    t = Time.now()
+
+    assert t.format == 'datetime'
+    assert t.scale == 'utc'
+
+    dt = t.datetime - now  # a datetime.timedelta object
+
+    # this gives a .1 second margin between the `utcnow` call and the `Time`
+    # initializer, which is really way more generous than necessary - typical
+    # times are more like microseconds.  But it seems safer in case some
+    # platforms have slow clock calls or something.
+
+    version_info = sys.version_info
+    # py < 2.7 and py3 < 3.2 doesn't have `total_seconds`
+    if ((version_info[0] == 2 and version_info[1] < 7) or
+        (version_info[0] == 3 and version_info[1] < 2) or
+            version_info[0] < 2):
+        total_secs = lambda td: (td.microseconds + (
+            td.seconds + td.days * 24 * 3600) * 10 ** 6) / 10 ** 6.
+    else:
+        total_secs = lambda td: td.total_seconds()
+    assert total_secs(dt) < 0.1
+
+
+def test_dir():
+    t = Time('2000:001', format='yday', scale='tai')
+    assert 'utc' in dir(t)
+
+
+def test_TimeFormat_scale():
+    """guard against recurrence of #1122, where TimeFormat class looses uses
+    attributes (delta_ut1_utc here), preventing conversion to unix, cxc"""
+    t = Time('1900-01-01', scale='ut1')
+    t.delta_ut1_utc = 0.0
+    t.unix
+    assert t.unix == t.utc.unix
