@@ -6,12 +6,22 @@ Handles the "FITS" unit format.
 
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
+from ...extern.six.moves import zip
 
+import keyword
 import warnings
 
+from ...utils.exceptions import AstropyDeprecationWarning
+
 from . import generic
 from . import utils
+from ...utils.misc import did_you_mean
 
+class UnitScaleError(ValueError):
+    """
+    Used to catch the errors involving scaled units, 
+    which are not recognized by FITS format.
+    """
 
 class Fits(generic.Generic):
     """
@@ -23,14 +33,15 @@ class Fits(generic.Generic):
     name = 'fits'
 
     def __init__(self):
-        super(Fits, self).__init__()
+        # Build this on the class, so it only gets generated once.
+        if '_parser' not in Fits.__dict__:
+            Fits._parser, Fits._lexer = self._make_parser()
 
         if not '_units' in Fits.__dict__:
             Fits._units, Fits._deprecated_units = self._generate_unit_names()
 
     @staticmethod
     def _generate_unit_names():
-        import keyword
         from ... import units as u
         names = {}
         deprecated_names = set()
@@ -62,7 +73,7 @@ class Fits(generic.Generic):
             'photon', 'ph', 'pixel', 'pix', 'D', 'Sun', 'chan', 'bin',
             'voxel', 'adu', 'beam'
         ]
-        deprecated_units = ['erg', 'Angstrom']
+        deprecated_units = ['erg', 'Angstrom', 'angstrom']
 
         for unit in simple_units + deprecated_units:
             names[unit] = getattr(u, unit)
@@ -72,16 +83,21 @@ class Fits(generic.Generic):
         return names, deprecated_names
 
     @classmethod
-    def _parse_unit(cls, unit):
+    def _parse_unit(cls, unit, detailed_exception=True):
         if unit not in cls._units:
-            raise ValueError(
-                "Unit {0!r} not supported by the FITS standard.".format(unit))
+            if detailed_exception:
+                raise ValueError(
+                    "Unit {0!r} not supported by the FITS standard. {1}".format(
+                        unit, did_you_mean(
+                            unit, cls._units)))
+            else:
+                raise ValueError()
 
         if unit in cls._deprecated_units:
             warnings.warn(
                 "The unit {0!r} has been deprecated in the FITS "
                 "standard.".format(unit),
-                DeprecationWarning)
+                AstropyDeprecationWarning)
 
         return cls._units[unit]
 
@@ -96,7 +112,7 @@ class Fits(generic.Generic):
             warnings.warn(
                 "The unit {0!r} has been deprecated in the FITS "
                 "standard.".format(name),
-                DeprecationWarning)
+                AstropyDeprecationWarning)
 
         return name
 
@@ -108,11 +124,11 @@ class Fits(generic.Generic):
 
         if isinstance(unit, core.CompositeUnit):
             if unit.scale != 1:
-                raise ValueError(
+                raise UnitScaleError(
                     "The FITS unit format is not able to represent scale. "
                     "Multiply your data by {0:e}.".format(unit.scale))
 
-            pairs = zip(unit.bases, unit.powers)
+            pairs = list(zip(unit.bases, unit.powers))
             pairs.sort(key=lambda x: x[1], reverse=True)
 
             s = self._format_unit_list(pairs)
