@@ -4,11 +4,16 @@ Handles the "VOUnit" unit format.
 """
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
+from ...extern import six
+from ...extern.six.moves import zip
 
+import keyword
 import warnings
+from ...utils.exceptions import AstropyDeprecationWarning
 
 from . import generic
 from . import utils
+from ...utils.misc import did_you_mean
 
 
 class VOUnit(generic.Generic):
@@ -19,7 +24,8 @@ class VOUnit(generic.Generic):
     <http://www.ivoa.net/Documents/VOUnits/>`_.
     """
     def __init__(self):
-        super(VOUnit, self).__init__()
+        if '_parser' not in VOUnit.__dict__:
+            VOUnit._parser, VOUnit._lexer = self._make_parser()
 
         if not '_units' in VOUnit.__dict__:
             unit_names = VOUnit._generate_unit_names()
@@ -27,8 +33,8 @@ class VOUnit(generic.Generic):
 
     @staticmethod
     def _generate_unit_names():
-        import keyword
         from ... import units as u
+
         names = {}
         deprecated_names = set()
 
@@ -63,18 +69,32 @@ class VOUnit(generic.Generic):
 
         return names, deprecated_names
 
+    def parse(self, s, debug=False):
+        result = self._do_parse(s, debug=debug)
+        if s.count('/') > 1:
+            from ..core import UnitsError
+            raise UnitsError(
+                "'{0}' contains multiple slashes, which is "
+                "disallowed by the VOUnit standard".format(s))
+        return result
+
     @classmethod
-    def _parse_unit(cls, unit):
+    def _parse_unit(cls, unit, detailed_exception=True):
         if unit not in cls._units:
-            raise ValueError(
-                "Unit {0!r} not supported by the VOUnit "
-                "standard.".format(unit))
+            if detailed_exception:
+                raise ValueError(
+                    "Unit {0!r} not supported by the VOUnit "
+                    "standard. {1}".format(
+                        unit, did_you_mean(
+                            unit, cls._units)))
+            else:
+                raise ValueError()
 
         if unit in cls._deprecated_units:
             warnings.warn(
                 "The use of unit {0!r} is discouraged by the "
                 "VOUnit standard.".format(unit),
-                DeprecationWarning)
+                AstropyDeprecationWarning)
 
         return cls._units[unit]
 
@@ -89,7 +109,7 @@ class VOUnit(generic.Generic):
             warnings.warn(
                 "The use of unit {0!r} is discouraged by the "
                 "VOUnit standard.".format(name),
-                DeprecationWarning)
+                AstropyDeprecationWarning)
 
         return name
 
@@ -100,6 +120,11 @@ class VOUnit(generic.Generic):
         unit = utils.decompose_to_known_units(unit, self._get_unit_name)
 
         if isinstance(unit, core.CompositeUnit):
+            if unit.physical_type == 'dimensionless' and unit.scale != 1:
+                raise ValueError("The VOUnit format is not able to "
+                                 "represent scale for dimensionless units. "
+                                 "Multiply your data by {0:e}."
+                                 .format(unit.scale))
             s = ''
             if unit.scale != 1:
                 m, ex = utils.split_mantissa_exponent(unit.scale)
@@ -111,7 +136,7 @@ class VOUnit(generic.Generic):
                         s += '+'
                     s += ex
 
-            pairs = zip(unit.bases, unit.powers)
+            pairs = list(zip(unit.bases, unit.powers))
             pairs.sort(key=lambda x: x[1], reverse=True)
 
             s += self._format_unit_list(pairs)
