@@ -16,6 +16,7 @@ from numpy.testing import (assert_allclose, assert_array_equal,
 from ...tests.helper import raises, pytest
 from ...utils import isiterable
 from ... import units as u
+from ...units.quantity import _UNIT_NOT_INITIALISED
 from ...extern.six.moves import xrange
 from ...extern.six.moves import cPickle as pickle
 from ...extern import six
@@ -573,6 +574,20 @@ class TestQuantityDisplay(object):
         assert format(self.scalarfloatq, '.1f') == "1.3 m"
         assert format(self.scalarfloatq, '.0f') == "1 m"
 
+    def test_uninitialized_unit_format(self):
+        bad_quantity = np.arange(10.).view(u.Quantity)
+        assert str(bad_quantity).endswith(_UNIT_NOT_INITIALISED)
+        assert repr(bad_quantity).endswith(_UNIT_NOT_INITIALISED + '>')
+
+    def test_repr_latex(self):
+        q2 = u.Quantity(1.5e14, 'm/s')
+        assert self.scalarintq._repr_latex_() == '$1 \\; \\mathrm{m}$'
+        assert self.scalarfloatq._repr_latex_() == '$1.3 \\; \\mathrm{m}$'
+        assert (q2._repr_latex_() ==
+                '$1.5\\times 10^{+14} \\; \\mathrm{\\frac{m}{s}}$')
+        with pytest.raises(NotImplementedError):
+            self.arrq._repr_latex_()
+
 
 def test_decompose():
     q1 = 5 * u.N
