@@ -1,4 +1,6 @@
+# -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+
 """
 Regression tests for the units package
 """
@@ -6,32 +8,61 @@ Regression tests for the units package
 from __future__ import (absolute_import, unicode_literals, division,
                         print_function)
 
-import warnings
 
 import numpy as np
+from numpy.testing.utils import assert_allclose
 
-from ...tests.helper import pytest, raises
-from ...tests.compat import assert_allclose
+from ...extern import six
+from ...extern.six.moves import cPickle as pickle
+from ...tests.helper import pytest, raises, catch_warnings
 from ...utils.compat.fractions import Fraction
 
 from ... import units as u
+from ... import constants as c
 
 
 def test_getting_started():
     """
     Corresponds to "Getting Started" section in the docs.
     """
-    speed_unit = u.cm / u.s
-    x = speed_unit.to(u.mile / u.hour, 1)
-    assert_allclose(x, 0.02236936292054402)
-    speed_converter = speed_unit.get_converter("mile hour^-1")
-    x = speed_converter([1., 1000., 5000.])
-    assert_allclose(x, [2.23693629e-02, 2.23693629e+01, 1.11846815e+02])
+    from .. import imperial
+    with imperial.enable():
+        speed_unit = u.cm / u.s
+        x = speed_unit.to(imperial.mile / u.hour, 1)
+        assert_allclose(x, 0.02236936292054402)
+        speed_converter = speed_unit.get_converter("mile hour^-1")
+        x = speed_converter([1., 1000., 5000.])
+        assert_allclose(x, [2.23693629e-02, 2.23693629e+01, 1.11846815e+02])
+
+
+def test_initialisation():
+    assert u.Unit(u.m) is u.m
+
+    ten_meter = u.Unit(10.*u.m)
+    assert ten_meter == u.CompositeUnit(10., [u.m], [1])
+    assert u.Unit(ten_meter) is ten_meter
+
+    assert u.Unit(10.*ten_meter) == u.CompositeUnit(100., [u.m], [1])
+
+    foo = u.Unit('foo', (10. * ten_meter)**2, namespace=locals())
+    assert foo == u.CompositeUnit(10000., [u.m], [2])
+
+    assert u.Unit('m') == u.m
+    assert u.Unit('') == u.dimensionless_unscaled
+    assert u.Unit('10 m') == ten_meter
+    assert u.Unit(10.) == u.CompositeUnit(10., [], [])
 
 
-@raises(ValueError)
 def test_invalid_power():
-    u.m ** 0.3
+    x = u.m ** Fraction(1, 3)
+    assert isinstance(x.powers[0], Fraction)
+
+    x = u.m ** Fraction(1, 2)
+    assert isinstance(x.powers[0], float)
+
+    # Test the automatic conversion to a fraction
+    x = u.m ** (1. / 3.)
+    assert isinstance(x.powers[0], Fraction)
 
 
 def test_invalid_compare():
@@ -43,19 +74,12 @@ def test_convert():
 
 
 def test_convert_fail():
-    with pytest.raises(u.UnitsException):
+    with pytest.raises(u.UnitsError):
         u.cm.to(u.s, 1)
-    with pytest.raises(u.UnitsException):
+    with pytest.raises(u.UnitsError):
         (u.cm / u.s).to(u.m, 1)
 
 
-def test_is_equivalent():
-    assert u.m.is_equivalent(u.inch)
-    assert not (u.Hz.is_equivalent(u.J))
-    assert u.Hz.is_equivalent(u.J, u.spectral())
-    assert u.J.is_equivalent(u.Hz, u.spectral())
-
-
 def test_composite():
     assert (u.cm / u.s * u.h).get_converter(u.m)(1) == 36
     assert u.cm * u.cm == u.cm ** 2
@@ -73,92 +97,12 @@ def test_repr():
     assert repr(u.cm) == 'Unit("cm")'
 
 
-def test_spectral():
-    a = u.AA.to(u.Hz, 1, u.spectral())
-    assert_allclose(a, 2.9979245799999995e+18)
-    b = u.Hz.to(u.AA, a, u.spectral())
-    assert_allclose(b, 1)
-
-    a = u.AA.to(u.MHz, 1, u.spectral())
-    assert_allclose(a, 2.9979245799999995e+12)
-    b = u.MHz.to(u.AA, a, u.spectral())
-    assert_allclose(b, 1)
-
-    a = u.m.to(u.Hz, 1, u.spectral())
-    assert_allclose(a, 2.9979245799999995e+8)
-    b = u.Hz.to(u.m, a, u.spectral())
-    assert_allclose(b, 1)
-
-
-def test_spectral2():
-    a = u.nm.to(u.J, 500, u.spectral())
-    assert_allclose(a, 3.972891366538605e-19)
-    b = u.J.to(u.nm, a, u.spectral())
-    assert_allclose(b, 500)
-
-    a = u.AA.to(u.Hz, 1, u.spectral())
-    b = u.Hz.to(u.J, a, u.spectral())
-    c = u.AA.to(u.J, 1, u.spectral())
-    assert_allclose(b, c)
-
-
-def test_spectral3():
-    a = u.nm.to(u.Hz, [1000, 2000], u.spectral())
-    assert_allclose(a, [2.99792458e+14, 1.49896229e+14])
-
-
-def test_spectraldensity():
-
-    a = u.AA.to(u.Jy, 1, u.spectral_density(u.eV, 2.2))
-    assert_allclose(a, 1059416252057.8357, rtol=1e-4)
-
-    b = u.Jy.to(u.AA, a, u.spectral_density(u.eV, 2.2))
-    assert_allclose(b, 1)
-
-
-def test_spectraldensity2():
-    flambda = u.erg / u.angstrom / u.cm ** 2 / u.s
-    fnu = u.erg / u.Hz / u.cm ** 2 / u.s
-
-    a = flambda.to(fnu, 1, u.spectral_density(u.AA, 3500))
-    assert_allclose(a, 4.086160166177361e-12)
-
-
-def test_spectraldensity3():
-
-    # Define F_nu in Jy
-    f_nu = u.Jy
-
-    # Convert to ergs / cm^2 / s / Hz
-    assert_allclose(f_nu.to(u.erg / u.cm ** 2 / u.s / u.Hz, 1.), 1.e-23, 10)
-
-    # Convert to ergs / cm^2 / s at 10 Ghz
-    assert_allclose(f_nu.to(u.erg / u.cm ** 2 / u.s, 1.,
-                    equivalencies=u.spectral_density(u.GHz, 10)), 1.e-13, 10)
-
-    # Convert to ergs / cm^2 / s / micron at 1 Ghz
-    assert_allclose(f_nu.to(u.erg / u.cm ** 2 / u.s / u.micron, 1.,
-                    equivalencies=u.spectral_density(u.Hz, 1.e9)),
-                    3.335640951981521e-20, 10)
-
-    # Define F_lambda in ergs / cm^2 / s / micron
-    f_lambda = u.erg / u.cm ** 2 / u.s / u.micron
-
-    # Convert to Jy at 1 Ghz
-    assert_allclose(f_lambda.to(u.Jy, 1.,
-                    equivalencies=u.spectral_density(u.Hz, 1.e9)),
-                    1. / 3.335640951981521e-20, 10)
-
-    # Convert to ergs / cm^2 / s at 10 microns
-    assert_allclose(f_lambda.to(u.erg / u.cm ** 2 / u.s, 1.,
-                    equivalencies=u.spectral_density(u.micron, 10.)), 10., 10)
-
-
 def test_units_conversion():
     assert_allclose(u.kpc.to(u.Mpc), 0.001)
     assert_allclose(u.Mpc.to(u.kpc), 1000)
     assert_allclose(u.yr.to(u.Myr), 1.e-6)
     assert_allclose(u.AU.to(u.pc), 4.84813681e-6)
+    assert_allclose(u.cycle.to(u.rad), 6.283185307179586)
 
 
 def test_units_manipulation():
@@ -171,11 +115,6 @@ def test_decompose():
     assert u.Ry == u.Ry.decompose()
 
 
-def test_equivalent_units():
-    assert u.pound in u.g.find_equivalent_units()
-    assert u.J in u.Hz.find_equivalent_units(u.spectral())
-
-
 def test_dimensionless_to_si():
     """
     Issue #1150: Test for conversion of dimensionless quantities
@@ -187,6 +126,7 @@ def test_dimensionless_to_si():
     assert testunit.unit.physical_type == 'dimensionless'
     assert_allclose(testunit.si, 0.001)
 
+
 def test_dimensionless_to_cgs():
     """
     Issue #1150: Test for conversion of dimensionless quantities
@@ -198,24 +138,25 @@ def test_dimensionless_to_cgs():
     assert testunit.unit.physical_type == 'dimensionless'
     assert_allclose(testunit.cgs, 0.001)
 
+
 def test_unknown_unit():
-    with warnings.catch_warnings(record=True) as warning_lines:
-        warnings.resetwarnings()
-        warnings.simplefilter("always", u.UnitsWarning, append=True)
+    with catch_warnings(u.UnitsWarning) as warning_lines:
         u.Unit("FOO", parse_strict='warn')
 
-    assert warning_lines[0].category == u.UnitsWarning
     assert 'FOO' in str(warning_lines[0].message)
 
 
-def test_unknown_unit2():
-    with warnings.catch_warnings(record=True) as warning_lines:
-        warnings.resetwarnings()
-        warnings.simplefilter("always", u.UnitsWarning, append=True)
-        assert u.Unit("m/s/kg", parse_strict='warn').to_string() == 'm/s/kg'
+def test_multiple_solidus():
+    assert u.Unit("m/s/kg").to_string() == u.m / u.s / u.kg
+
+    with catch_warnings(u.UnitsWarning) as warning_lines:
+        assert u.Unit("m/s/kg").to_string() == u.m / (u.s * u.kg)
 
-    assert warning_lines[0].category == u.UnitsWarning
     assert 'm/s/kg' in str(warning_lines[0].message)
+    assert 'discouraged' in str(warning_lines[0].message)
+
+    with pytest.raises(ValueError):
+        u.Unit("m/s/kg", format="vounit")
 
 
 def test_unknown_unit3():
@@ -244,24 +185,27 @@ def test_unknown_unit3():
         unit5 = u.Unit(None)
 
 
+@raises(TypeError)
+def test_invalid_scale():
+    x = ['a', 'b', 'c'] * u.m
+
+
 def test_cds_power():
     unit = u.Unit("10+22/cm2", format="cds", parse_strict='silent')
     assert unit.scale == 1e22
 
 
 def test_register():
-    try:
-        u.def_unit("foo", u.m ** 3, register=True)
-        assert hasattr(u, 'foo')
-    finally:
-        if hasattr(u, 'foo'):
-            del u.UnitBase._registry['foo']
-            del u.foo
+    foo = u.def_unit("foo", u.m ** 3, namespace=locals())
+    assert 'foo' in locals()
+    with u.add_enabled_units(foo):
+        assert 'foo' in u.get_current_unit_registry().registry
+    assert 'foo' not in u.get_current_unit_registry().registry
 
 
 def test_in_units():
     speed_unit = u.cm / u.s
-    x = speed_unit.in_units(u.mile / u.hour, 1)
+    x = speed_unit.in_units(u.pc / u.hour, 1)
 
 
 def test_null_unit():
@@ -270,7 +214,7 @@ def test_null_unit():
 
 def test_unrecognized_equivalency():
     assert u.m.is_equivalent('foo') is False
-    assert u.m.is_equivalent('foot') is True
+    assert u.m.is_equivalent('pc') is True
 
 
 @raises(TypeError)
@@ -281,14 +225,14 @@ def test_unit_noarg():
 def test_convertible_exception():
     try:
         u.AA.to(u.h * u.s ** 2)
-    except u.UnitsException as e:
+    except u.UnitsError as e:
         assert "length" in str(e)
 
 
 def test_convertible_exception2():
     try:
         u.m.to(u.s)
-    except u.UnitsException as e:
+    except u.UnitsError as e:
         assert "length" in str(e)
 
 
@@ -323,7 +267,7 @@ def test_decompose_bases():
 
     d = e.esu.unit.decompose(bases=cgs.bases)
     assert d._bases == [u.cm, u.g, u.s]
-    assert d._powers == [Fraction(3, 2), Fraction(1, 2), -1]
+    assert d._powers == [Fraction(3, 2), 0.5, -1]
     assert d._scale == 1.0
 
 
@@ -340,7 +284,7 @@ def test_equiv_compose():
 
 
 def test_empty_compose():
-    with pytest.raises(u.UnitsException):
+    with pytest.raises(u.UnitsError):
         composed = u.m.compose(units=[])
 
 
@@ -349,11 +293,11 @@ def test_compose_roundtrip():
         composed_list = unit.decompose().compose()
         found = False
         for composed in composed_list:
-            if len(composed._bases):
-                if composed._bases[0] is unit:
+            if len(composed.bases):
+                if composed.bases[0] is unit:
                     found = True
                     break
-            elif len(unit._bases) == 0:
+            elif len(unit.bases) == 0:
                 found = True
                 break
         assert found
@@ -368,7 +312,9 @@ def test_compose_roundtrip():
 
 def test_compose_cgs_to_si():
     def _test_compose_cgs_to_si(unit):
-        unit.to_system(u.si)
+        si = unit.to_system(u.si)
+        assert [x.is_equivalent(unit) for x in si]
+        assert si[0] == unit.si
 
     for val in u.cgs.__dict__.values():
         if (isinstance(val, u.UnitBase) and
@@ -380,12 +326,15 @@ def test_compose_si_to_cgs():
     def _test_compose_si_to_cgs(unit):
         # Can't convert things with Ampere to CGS without more context
         try:
-            unit.to_system(u.cgs)
-        except u.UnitsException:
+            cgs = unit.to_system(u.cgs)
+        except u.UnitsError:
             if u.A in unit.decompose().bases:
                 pass
             else:
                 raise
+        else:
+            assert [x.is_equivalent(unit) for x in cgs]
+            assert cgs[0] == unit.cgs
 
     for val in u.si.__dict__.values():
         if (isinstance(val, u.UnitBase) and
@@ -419,7 +368,7 @@ def test_self_compose():
     assert len(unit.compose(units=[u.g, u.s])) == 1
 
 
-@raises(u.UnitsException)
+@raises(u.UnitsError)
 def test_compose_failed():
     unit = u.kg
 
@@ -482,10 +431,7 @@ def test_endian_independence():
     for endian in ['<', '>']:
         for ntype in ['i', 'f']:
             for byte in ['4', '8']:
-                # Note, we have to use encode() because we've imported
-                # unicode_literals from __future__, and Numpy 1.4.1 crashes if
-                # a unicode dtype is passed.
-                x = np.array([1,2,3], dtype=(endian + ntype + byte).encode('ascii'))
+                x = np.array([1,2,3], dtype=(endian + ntype + byte))
                 u.m.to(u.cm, x)
 
 
@@ -504,27 +450,36 @@ def test_no_as():
 
 
 def test_pickling():
-    import cPickle
-
-    p = cPickle.dumps(u.m)
-    other = cPickle.loads(p)
+    p = pickle.dumps(u.m)
+    other = pickle.loads(p)
 
     assert other is u.m
 
-    try:
-        new_unit = u.IrreducibleUnit(['foo'], format={'baz': 'bar'})
-        p = cPickle.dumps(new_unit)
-    finally:
-        del u.UnitBase._registry['foo']
-
-    new_unit_copy = cPickle.loads(p)
+    new_unit = u.IrreducibleUnit(['foo'], format={'baz': 'bar'})
+    u.add_enabled_units([new_unit])
+    p = pickle.dumps(new_unit)
+    new_unit_copy = pickle.loads(p)
     assert new_unit_copy.names == ['foo']
     assert new_unit_copy.get_format_name('baz') == 'bar'
 
 
+def test_pickle_unrecognized_unit():
+    """
+    Issue #2047
+    """
+    a = u.Unit('asdf', parse_strict='silent')
+    pickle.loads(pickle.dumps(a))
+
+
 @raises(ValueError)
 def test_duplicate_define():
-    u.def_unit('m')
+    u.def_unit('m', namespace=u.__dict__)
+
+
+def test_all_units():
+    from ...units.core import get_current_unit_registry
+    registry = get_current_unit_registry()
+    assert len(registry.all_units) > len(registry.non_prefix_units)
 
 
 def test_repr_latex():
@@ -543,5 +498,110 @@ def test_comparison():
     assert u.cm < u.m
     assert u.cm <= u.m
 
-    with pytest.raises(u.UnitsException):
+    with pytest.raises(u.UnitsError):
         u.m > u.kg
+
+
+def test_compose_into_arbitrary_units():
+    # Issue #1438
+    from ...constants import G
+    G.decompose([u.kg, u.km, u.Unit("15 s")])
+
+
+def test_unit_multiplication_with_string():
+    """Check that multiplication with strings produces the correct unit."""
+    u1 = u.cm
+    us = 'kg'
+    assert us * u1 == u.Unit(us) * u1
+    assert u1 * us == u1 * u.Unit(us)
+
+
+def test_unit_division_by_string():
+    """Check that multiplication with strings produces the correct unit."""
+    u1 = u.cm
+    us = 'kg'
+    assert us / u1 == u.Unit(us) / u1
+    assert u1 / us == u1 / u.Unit(us)
+
+
+def test_sorted_bases():
+    """See #1616."""
+    assert (u.m * u.Jy).bases == (u.Jy * u.m).bases
+
+
+def test_megabit():
+    """See #1543"""
+    assert u.Mbit is u.Mb
+    assert u.megabit is u.Mb
+
+    assert u.Mbyte is u.MB
+    assert u.megabyte is u.MB
+
+
+def test_composite_unit_get_format_name():
+    """See #1576"""
+    unit1 = u.Unit('nrad/s')
+    unit2 = u.Unit('Hz(1/2)')
+    assert (str(u.CompositeUnit(1, [unit1, unit2], [1, -1])) ==
+            'nrad / (Hz(1/2) s)')
+
+def test_unicode_policy():
+    from ...tests.helper import assert_follows_unicode_guidelines
+
+    assert_follows_unicode_guidelines(
+        u.degree, roundtrip=u.__dict__)
+
+
+def test_suggestions():
+    for search, matches in [
+            ('microns', 'micron'),
+            ('s/microns', 'micron'),
+            ('M', 'm'),
+            ('metre', 'meter'),
+            ('angstroms', 'Angstrom or angstrom'),
+            ('milimeter', 'millimeter'),
+            ('ångström', 'Angstrom or angstrom'),
+            ('kev', 'EV, eV, kV or keV')]:
+        try:
+            u.Unit(search)
+        except ValueError as e:
+            assert 'Did you mean {0}?'.format(matches) in six.text_type(e)
+        else:
+            assert False, 'Expected ValueError'
+
+
+def test_fits_hst_unit():
+    """See #1911."""
+    x = u.Unit("erg /s /cm**2 /angstrom")
+    assert x == u.erg * u.s ** -1 * u.cm ** -2 * u.angstrom ** -1
+
+
+def test_fractional_powers():
+    """See #2069"""
+    m = 1e9 * u.Msun
+    tH = 1. / (70. * u.km / u.s / u.Mpc)
+    vc = 200 * u.km/u.s
+
+    x = (c.G ** 2 * m ** 2 * tH.cgs) ** Fraction(1, 3) / vc
+    v1 = x.to('pc')
+
+    x = (c.G ** 2 * m ** 2 * tH) ** Fraction(1, 3) / vc
+    v2 = x.to('pc')
+
+    x = (c.G ** 2 * m ** 2 * tH.cgs) ** (1.0 / 3.0) / vc
+    v3 = x.to('pc')
+
+    x = (c.G ** 2 * m ** 2 * tH) ** (1.0 / 3.0) / vc
+    v4 = x.to('pc')
+
+    assert_allclose(v1, v2)
+    assert_allclose(v2, v3)
+    assert_allclose(v3, v4)
+
+    x = u.m ** (1.0 / 11.0)
+    assert isinstance(x.powers[0], float)
+
+    x = u.m ** (3.0 / 7.0)
+    assert isinstance(x.powers[0], Fraction)
+    assert x.powers[0].numerator == 3
+    assert x.powers[0].denominator == 7
