@@ -14,11 +14,39 @@ Includes the following fixes:
 
 """
 
-from __future__ import absolute_import
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
+from ...extern import six
 
-from sys import version_info
+import os
+import sys
 
-__all__ = ['inspect_getmodule', 'invalidate_caches']
+from functools import wraps
+
+
+__all__ = ['inspect_getmodule', 'invalidate_caches', 'override__dir__',
+           'possible_filename']
+
+
+def possible_filename(filename):
+    """
+    Determine if the ``filename`` argument is an allowable type for a filename.
+
+    In Python 3.3 use of non-unicode filenames on system calls such as
+    `os.stat` and others that accept a filename argument was deprecated (and
+    may be removed outright in the future).
+
+    Therefore this returns `True` in all cases except for `bytes` strings in
+    Windows on Python >= 3.3.
+    """
+
+    if isinstance(filename, six.text_type):
+        return True
+    elif isinstance(filename, six.binary_type):
+        return not (sys.platform == 'win32' and
+                    sys.version_info[:2] >= (3, 3))
+
+    return False
 
 
 def _patched_getmodule(object, _filename=None):
@@ -28,8 +56,6 @@ def _patched_getmodule(object, _filename=None):
     function but includes a fix for a bug present in Python 3.1 and 3.2.
     """
     #these imports mock up what would otherwise have been in inspect
-    import sys
-    import os
     from inspect import modulesbyfile, _filesbymodname, getabsfile, ismodule
 
     if ismodule(object):
@@ -85,7 +111,7 @@ functionality with a bugfix for Python 3.1 and 3.2.
 
 #This assigns the stdlib inspect.getmodule to the variable name
 #`inspect_getmodule` if it's not buggy, and uses the matched version if it is.
-if version_info[0] < 3 or version_info[1] > 2:
+if sys.version_info[0] < 3 or sys.version_info[1] > 2:
     #in 2.x everythig is fine, as well as >=3.3
     from inspect import getmodule as inspect_getmodule
 else:
@@ -96,7 +122,45 @@ else:
 # general case. But sometimes it's necessary to manually invalidate those
 # caches so that the import system can pick up new generated files.  See
 # https://github.com/astropy/astropy/issues/820
-if version_info[:2] >= (3, 3):
+if sys.version_info[:2] >= (3, 3):
     from importlib import invalidate_caches
 else:
     invalidate_caches = lambda: None
+
+
+def override__dir__(f):
+    """
+    When overriding a __dir__ method on an object, you often want to
+    include the "standard" members on the object as well.  This
+    decorator takes care of that automatically, and all the wrapped
+    function needs to do is return a list of the "special" members
+    that wouldn't be found by the normal Python means.
+
+    Example
+    -------
+
+    @override__dir__
+    def __dir__(self):
+        return ['special_method1', 'special_method2']
+    """
+    if sys.version_info[:2] < (3, 3):
+        # There was no straightforward way to do this until Python 3.3, so
+        # we have this complex monstrosity
+        @wraps(f)
+        def override__dir__wrapper(self):
+            members = set()
+            for cls in self.__class__.mro():
+                members.update(dir(cls))
+            members.update(six.iterkeys(self.__dict__))
+            members.update(f(self))
+            return sorted(members)
+    else:
+        # http://bugs.python.org/issue12166
+
+        @wraps(f)
+        def override__dir__wrapper(self):
+            members = set(object.__dir__(self))
+            members.update(f(self))
+            return sorted(members)
+
+    return override__dir__wrapper
