@@ -1,10 +1,14 @@
+# Licensed under a 3-clause BSD style license - see LICENSE.rst
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
+
 import io
-import os
 
 from ...tests.helper import pytest
 from ..compat import gzip
 
-pytestmark = pytest.mark.skipif("sys.version_info < (3,0)")
+
+pytestmark = pytest.mark.skipif(str("sys.version_info < (3,0)"))
 
 
 def test_gzip(tmpdir):
@@ -15,4 +19,3 @@ def test_gzip(tmpdir):
 def test_gzip2(tmpdir):
     with gzip.GzipFile(str(tmpdir.join("test.gz")), 'wb') as fd:
         pass
-
