@@ -1,11 +1,18 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from .. import misc
-from .. import data
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
 
+import json
+import os
 
 #namedtuple is needed for find_mod_objs so it can have a non-local module
 from collections import namedtuple
-import warnings
+
+import numpy as np
+
+from .. import data, misc
+from ..exceptions import AstropyDeprecationWarning
+from ...tests.helper import remote_data, catch_warnings
 
 
 def test_pkg_finder():
@@ -65,13 +72,11 @@ def test_find_current_mod():
 
 
 def test_isiterable():
-    from numpy import array
-
     assert misc.isiterable(2) is False
     assert misc.isiterable([2]) is True
     assert misc.isiterable([1, 2, 3]) is True
-    assert misc.isiterable(array(2)) is False
-    assert misc.isiterable(array([1, 2, 3])) is True
+    assert misc.isiterable(np.array(2)) is False
+    assert misc.isiterable(np.array([1, 2, 3])) is True
 
 
 def test_deprecated_attribute():
@@ -86,26 +91,28 @@ def test_deprecated_attribute():
 
     dummy = DummyClass()
 
-    with warnings.catch_warnings(record=True) as w:
-        warnings.resetwarnings()
-        warnings.simplefilter('always')
+    with catch_warnings(AstropyDeprecationWarning) as w:
         x = dummy.foo
 
     assert len(w) == 1
     assert str(w[0].message) == ("The foo attribute is deprecated and may be "
                                  "removed in a future version.")
 
-    with warnings.catch_warnings(record=True) as w:
-        warnings.resetwarnings()
-        warnings.simplefilter('always')
+    with catch_warnings() as w:
         dummy.set_private()
 
     assert len(w) == 0
 
+@remote_data
+def test_api_lookup():
+    strurl = misc.find_api_page('astropy.utils.misc', 'dev', False, timeout=3)
+    objurl = misc.find_api_page(misc, 'dev', False, timeout=3)
+
+    assert strurl == objurl
+    assert strurl == 'http://devdocs.astropy.org/utils/index.html#module-astropy.utils.misc'
+
 
 def test_skip_hidden():
-    import os
-
     path = data._find_pkg_data_path('data')
     for root, dirs, files in os.walk(path):
         assert '.hidden_file.txt' in files
@@ -118,3 +125,13 @@ def test_skip_hidden():
         assert '.hidden_file.txt' not in files
         assert 'local.dat' in files
         break
+
+
+def test_JsonCustomEncoder():
+    assert json.dumps(np.arange(3), cls=misc.JsonCustomEncoder) == '[0, 1, 2]'
+    assert json.dumps(1+2j, cls=misc.JsonCustomEncoder) == '[1.0, 2.0]'
+    assert json.dumps(set([1, 2, 1]), cls=misc.JsonCustomEncoder) == '[1, 2]'
+    assert json.dumps(b'hello world \xc3\x85',
+                      cls=misc.JsonCustomEncoder) == '"hello world \\u00c5"'
+    assert json.dumps({1: 2},
+                      cls=misc.JsonCustomEncoder) == '{"1": 2}'  # default
