@@ -1,14 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import division  # confidence high
-# We don't want the "division" symbol in the namespace, since it
-# should have only docstrings
-try:
-    del division
-except NameError:
-    # When building the configuration defaults in 3.x, the ``del division`` line
-    # throws a NameError because for some reason it seems to think it's already
-    # deleted.  This works around that.
-    pass
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 # It gets to be really tedious to type long docstrings in ANSI C
 # syntax (since multi-line string literals are not valid).
@@ -189,10 +180,10 @@ matrix.
 
 For historical compatibility, three alternate specifications of the
 linear transforations are available in wcslib.  The canonical
-``PCi_ja`` with ``CDELTia``, and the deprecated ``CDi_ja`` and
-``CROTAia`` keywords.  Although the deprecated versions may not
-formally co-exist with ``PCi_ja``, the approach here is simply to
-ignore them if given in conjunction with ``PCi_ja``.
+``PCi_ja`` with ``CDELTia``, ``CDi_ja``, and the deprecated
+``CROTAia`` keywords.  Although the latter may not formally co-exist
+with ``PCi_ja``, the approach here is simply to ignore them if given
+in conjunction with ``PCi_ja``.
 
 `~astropy.wcs.Wcsprm.has_pc`, `~astropy.wcs.Wcsprm.has_cd` and
 `~astropy.wcs.Wcsprm.has_crota` can be used to determine which of
@@ -322,10 +313,10 @@ axis.
 
 For historical compatibility, three alternate specifications of the
 linear transforations are available in wcslib.  The canonical
-``PCi_ja`` with ``CDELTia``, and the deprecated ``CDi_ja`` and
-``CROTAia`` keywords.  Although the deprecated versions may not
-formally co-exist with ``PCi_ja``, the approach here is simply to
-ignore them if given in conjunction with ``PCi_ja``.
+``PCi_ja`` with ``CDELTia``, ``CDi_ja``, and the deprecated
+``CROTAia`` keywords.  Although the latter may not formally co-exist
+with ``PCi_ja``, the approach here is simply to ignore them if given
+in conjunction with ``PCi_ja``.
 
 `~astropy.wcs.Wcsprm.has_pc`, `~astropy.wcs.Wcsprm.has_cd` and
 `~astropy.wcs.Wcsprm.has_crota` can be used to determine which of
@@ -642,8 +633,9 @@ Applies all of the corrections handled separately by
 Parameters
 ----------
 
-translate_units : str
-    Do potentially unsafe translations of non-standard unit strings.
+translate_units : str, optional
+    Specify which potentially unsafe translations of non-standard unit
+    strings to perform.  By default, performs all.
 
     Although ``"S"`` is commonly used to represent seconds, its
     translation to ``"s"`` is potentially unsafe since the standard
@@ -663,7 +655,7 @@ translate_units : str
     Thus ``''`` doesn't do any unsafe translations, whereas ``'shd'``
     does all of them.
 
-naxis : int array[naxis]
+naxis : int array[naxis], optional
     Image axis lengths.  If this array is set to zero or ``None``,
     then `~astropy.wcs.Wcsprm.cylfix` will not be invoked.
 
@@ -706,7 +698,7 @@ Coordinate increments (``CDELTia``) for each coord axis.
 
 Returns the ``CDELT`` offsets in read-only form.  Unlike the
 `~astropy.wcs.Wcsprm.cdelt` property, this works even when the header
-specifies the linear transformation matrix in one of the deprecated
+specifies the linear transformation matrix in one of the alternative
 ``CDi_ja`` or ``CROTAia`` forms.  This is useful when you want access
 to the linear transformation matrix, but don't care how it was
 specified in the header.
@@ -717,7 +709,7 @@ get_pc() -> double array[naxis][naxis]
 
 Returns the ``PC`` matrix in read-only form.  Unlike the
 `~astropy.wcs.Wcsprm.pc` property, this works even when the header
-specifies the linear transformation matrix in one of the deprecated
+specifies the linear transformation matrix in one of the alternative
 ``CDi_ja`` or ``CROTAia`` forms.  This is useful when you want access
 to the linear transformation matrix, but don't care how it was
 specified in the header.
@@ -1307,10 +1299,10 @@ The order is::
 
 For historical compatibility, three alternate specifications of the
 linear transforations are available in wcslib.  The canonical
-``PCi_ja`` with ``CDELTia``, and the deprecated ``CDi_ja`` and
-``CROTAia`` keywords.  Although the deprecated versions may not
-formally co-exist with ``PCi_ja``, the approach here is simply to
-ignore them if given in conjunction with ``PCi_ja``.
+``PCi_ja`` with ``CDELTia``, ``CDi_ja``, and the deprecated
+``CROTAia`` keywords.  Although the latter may not formally co-exist
+with ``PCi_ja``, the approach here is simply to ignore them if given
+in conjunction with ``PCi_ja``.
 
 `~astropy.wcs.Wcsprm.has_pc`, `~astropy.wcs.Wcsprm.has_cd` and
 `~astropy.wcs.Wcsprm.has_crota` can be used to determine which of
@@ -1735,7 +1727,7 @@ vice versa.
 
 Parameters
 ----------
-ctype : string
+ctype : str
     Required spectral ``CTYPEia``, maximum of 8 characters.  The first
     four characters are required to be given and are never modified.
     The remaining four, the algorithm code, are completely determined
@@ -2019,17 +2011,17 @@ like ``"log (m ** 2)"`` which is formally disallowed.
 Parameters
 ----------
 
-have : string
+have : str
     FITS unit string to convert from, with or without surrounding
     square brackets (for inline specifications); text following the
     closing bracket is ignored.
 
-want : string
+want : str
     FITS unit string to convert to, with or without surrounding square
     brackets (for inline specifications); text following the closing
     bracket is ignored.
 
-ctrl : string, optional
+ctrl : str, optional
     Do potentially unsafe translations of non-standard unit strings.
 
     Although ``\"S\"`` is commonly used to represent seconds, its
@@ -2099,7 +2091,7 @@ whitespace.
 
 Parameters
 ----------
-translate_units : string, optional
+translate_units : str, optional
     Do potentially unsafe translations of non-standard unit strings.
 
     Although ``\"S\"`` is commonly used to represent seconds, its
@@ -2200,7 +2192,7 @@ Parameters
 header : An `astropy.io.fits.Header`, string, or `None`.
   If ``None``, the object will be initialized to default values.
 
-key : string, optional
+key : str, optional
     The key referring to a particular WCS transform in the header.
     This may be either ``' '`` or ``'A'``-``'Z'`` and corresponds to
     the ``\"a\"`` part of ``\"CTYPEia\"``.  (*key* may only be
@@ -2265,3 +2257,62 @@ zsource = """
 
 An undefined value is represented by NaN.
 """
+
+WcsError = """
+Base class of all invalid WCS errors.
+"""
+
+SingularMatrix = """
+SingularMatrixError()
+
+The linear transformation matrix is singular.
+"""
+
+InconsistentAxisTypes = """
+InconsistentAxisTypesError()
+
+The WCS header inconsistent or unrecognized coordinate axis type(s).
+"""
+
+InvalidTransform = """
+InvalidTransformError()
+
+The WCS transformation is invalid, or the transformation parameters
+are invalid.
+"""
+
+InvalidCoordinate = """
+InvalidCoordinateError()
+
+One or more of the world coordinates is invalid.
+"""
+
+NoSolution = """
+NoSolutionError()
+
+No solution can be found in the given interval.
+"""
+
+InvalidSubimageSpecification = """
+InvalidSubimageSpecificationError()
+
+The subimage specification is invalid.
+"""
+
+NonseparableSubimageCoordinateSystem = """
+NonseparableSubimageCoordinateSystemError()
+
+Non-separable subimage coordinate system.
+"""
+
+NoWcsKeywordsFound = """
+NoWcsKeywordsFoundError()
+
+No WCS keywords were found in the given header.
+"""
+
+InvalidTabularParameters = """
+InvalidTabularParametersError()
+
+The given tabular parameters are invalid.
+"""
