@@ -1,15 +1,18 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import division  # confidence high
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 CONTACT = "Michael Droettboom"
 EMAIL = "mdroe@stsci.edu"
 
 from distutils.core import Extension
+import io
 from os.path import join
 import os.path
+import shutil
 import sys
 
 from astropy import setup_helpers
+from astropy.extern import six
 
 WCSROOT = os.path.relpath(os.path.dirname(__file__))
 WCSVERSION = "4.10"
@@ -18,18 +21,13 @@ WCSVERSION = "4.10"
 def b(s):
     return s.encode('ascii')
 
-if sys.version_info[0] >= 3:
-
+if six.PY3:
     def string_escape(s):
         s = s.decode('ascii').encode('ascii', 'backslashreplace')
-        s = s.replace(b('\n'), b('\\n'))
-        s = s.replace(b('\0'), b('\\0'))
+        s = s.replace(b'\n', b'\\n')
+        s = s.replace(b'\0', b'\\0')
         return s.decode('ascii')
-
-    from io import StringIO
-    string_types = (str, bytes)
 else:
-
     def string_escape(s):
         # string_escape has subtle differences with the escaping done in Python
         # 3 so correct for those too
@@ -37,9 +35,6 @@ else:
         s = s.replace(r'\x00', r'\0')
         return s.replace(r"\'", "'")
 
-    from cStringIO import StringIO
-    string_types = (str, unicode)
-
 
 def determine_64_bit_int():
     """
@@ -74,7 +69,7 @@ def write_wcsconfig_h():
     """
     Writes out the wcsconfig.h header with local configuration.
     """
-    h_file = StringIO()
+    h_file = io.StringIO()
     h_file.write("""
     /* WCSLIB library version number. */
     #define WCSLIB_VERSION {0}
@@ -110,6 +105,9 @@ def write_wcsconfig_h():
 
     #endif
     """.format(WCSVERSION, determine_64_bit_int()))
+    setup_helpers.write_if_different(
+        join(WCSROOT, 'include', 'astropy_wcs', 'wcsconfig.h'),
+        h_file.getvalue().encode('ascii'))
     setup_helpers.write_if_different(
         join(WCSROOT, 'include', 'wcsconfig.h'),
         h_file.getvalue().encode('ascii'))
@@ -122,14 +120,14 @@ def generate_c_docstrings():
     from astropy.wcs import docstrings
     docstrings = docstrings.__dict__
     keys = [
-        key for key in docstrings.keys()
-        if not key.startswith('__') and type(key) in string_types]
+        key for key, val in docstrings.items()
+        if not key.startswith('__') and isinstance(val, six.string_types)]
     keys.sort()
     docs = {}
     for key in keys:
         docs[key] = docstrings[key].encode('utf8').lstrip() + b'\0'
 
-    h_file = StringIO()
+    h_file = io.StringIO()
     h_file.write("""/*
 DO NOT EDIT!
 
@@ -140,10 +138,6 @@ its contents, edit astropy/wcs/docstrings.py
 #ifndef __DOCSTRINGS_H__
 #define __DOCSTRINGS_H__
 
-#if defined(_MSC_VER)
-void fill_docstrings(void);
-#endif
-
 """)
     for key in keys:
         val = docs[key]
@@ -151,10 +145,10 @@ void fill_docstrings(void);
     h_file.write("\n#endif\n\n")
 
     setup_helpers.write_if_different(
-        join(WCSROOT, 'include', 'docstrings.h'),
+        join(WCSROOT, 'include', 'astropy_wcs', 'docstrings.h'),
         h_file.getvalue().encode('utf-8'))
 
-    c_file = StringIO()
+    c_file = io.StringIO()
     c_file.write("""/*
 DO NOT EDIT!
 
@@ -166,34 +160,21 @@ MSVC, do not support string literals greater than 256 characters.
 */
 
 #include <string.h>
-#include "docstrings.h"
+#include "astropy_wcs/docstrings.h"
 
-#if defined(_MSC_VER)
 """)
     for key in keys:
         val = docs[key]
-        c_file.write('char doc_{0}[{1}];\n'.format(key, len(val)))
+        c_file.write('char doc_{0}[{1}] = {{\n'.format(key, len(val)))
+        for i in range(0, len(val), 12):
+            section = val[i:i+12]
+            if six.PY2:
+                section = [ord(x) for x in section]
+            c_file.write('    ');
+            c_file.write(''.join('0x{0:02x}, '.format(x) for x in section))
+            c_file.write('\n')
 
-    c_file.write("\nvoid fill_docstrings(void)\n{\n")
-    for key in keys:
-        val = docs[key]
-        # For portability across various compilers, we need to fill the
-        # docstrings in 256-character chunks
-        for i in range(0, len(val), 256):
-            chunk = string_escape(val[i:i + 256]).replace('"', '\\"')
-            c_file.write('   strncpy(doc_{0} + {1}, "{2}", {3});\n'.format(
-                key, i, chunk, min(len(val) - i, 256)))
-        c_file.write("\n")
-    c_file.write("\n}\n\n")
-
-    c_file.write("#else /* UNIX */\n")
-
-    for key in keys:
-        val = docs[key]
-        c_file.write('char doc_{0}[{1}] = "{2}";\n\n'.format(
-            key, len(val), string_escape(val).replace('"', '\\"')))
-
-    c_file.write("#endif\n")
+        c_file.write("    };\n\n")
 
     setup_helpers.write_if_different(
         join(WCSROOT, 'src', 'docstrings.c'),
@@ -293,30 +274,57 @@ def get_extensions():
     if sys.platform.startswith('linux'):
         cfg['define_macros'].append(('HAVE_SINCOS', None))
 
-    return [Extension('astropy.wcs._wcs', **cfg)]
+    cfg['sources'] = [str(x) for x in cfg['sources']]
+
+    cfg = dict((str(key), val) for key, val in six.iteritems(cfg))
+
+    return [Extension(str('astropy.wcs._wcs'), **cfg)]
 
 
 def get_package_data():
     # Installs the testing data files
     api_files = [
+        'astropy_wcs.h',
         'astropy_wcs_api.h',
-        'wcsconfig.h',
-        'pyutil.h',
-        'util.h',
         'distortion.h',
+        'isnan.h',
         'pipeline.h',
-        'sip.h'
+        'pyutil.h',
+        'sip.h',
+        'util.h',
+        'wcsconfig.h',
         ]
-    api_files = [join('include', x) for x in api_files]
+    api_files = [join('include', 'astropy_wcs', x) for x in api_files]
+    api_files.append(join('include', 'astropy_wcs_api.h'))
+
+    wcslib_headers = [
+        'cel.h',
+        'lin.h',
+        'prj.h',
+        'spc.h',
+        'spx.h',
+        'tab.h',
+        'wcs.h',
+        'wcserr.h',
+        'wcsmath.h',
+        'wcsprintf.h',
+        ]
+    for header in wcslib_headers:
+        shutil.copy(join('cextern', 'wcslib', 'C', header),
+                    join('astropy', 'wcs', 'include', 'wcslib', header))
+        api_files.append(join('include', 'wcslib', header))
+
     return {
-        'astropy.wcs.tests': ['data/*.hdr', 'data/*.fits',
-                              'maps/*.hdr', 'spectra/*.hdr'],
-        'astropy.wcs': api_files}
-
-
-def get_legacy_alias():
-    return setup_helpers.add_legacy_alias('pywcs', 'astropy.wcs', '1.11')
+        str('astropy.wcs.tests'): ['data/*.hdr', 'data/*.fits',
+                                   'data/*.txt',
+                                   'maps/*.hdr', 'spectra/*.hdr'],
+        str('astropy.wcs'): api_files
+    }
 
 
 def get_external_libraries():
     return ['wcslib']
+
+
+def requires_2to3():
+    return False
