@@ -375,9 +375,10 @@ PyWcsprm_init(
       return -1;
     }
 
+    wcsvfree(&nwcs, &wcs);
+
     if (convert_rejections_to_warnings(wcsprintf_buf())) {
       free(colsel_ints);
-      wcsvfree(&nwcs, &wcs);
       return -1;
     }
 
@@ -413,6 +414,7 @@ PyWcsprm_init(
     }
 
     if (nwcs == 0) {
+      wcsvfree(&nwcs, &wcs);
       PyErr_SetString(
           WcsExc_NoWcsKeywordsFound,
           "No WCS keywords found in the given header");
@@ -581,8 +583,9 @@ PyWcsprm_find_all_wcs(
     return NULL;
   }
 
+  wcsvfree(&nwcs, &wcs);
+
   if (convert_rejections_to_warnings(wcsprintf_buf())) {
-    wcsvfree(&nwcs, &wcs);
     return NULL;
   }
 
@@ -1645,7 +1648,7 @@ PyWcsprm_sub(
     }
     nsub = (int)tmp;
 
-    axes = malloc(nsub * sizeof(int));
+    axes = malloc(nsub * sizeof(int) * 2);
     if (axes == NULL) {
       PyErr_SetString(PyExc_MemoryError, "Out of memory");
       goto exit;
@@ -1741,13 +1744,13 @@ PyWcsprm_sub(
 
   py_dest_wcs = (PyWcsprm*)PyWcsprm_cnew();
   py_dest_wcs->x.flag = -1;
-  status = wcsini(1, alloc_size, &py_dest_wcs->x);
+  status = wcsini(0, alloc_size, &py_dest_wcs->x);
   if (status != 0) {
     goto exit;
   }
 
   wcsprm_python2c(&self->x);
-  status = wcssub(0, &self->x, &nsub, axes, &py_dest_wcs->x);
+  status = wcssub(1, &self->x, &nsub, axes, &py_dest_wcs->x);
   wcsprm_c2python(&self->x);
   if (PyWcsprm_cset(py_dest_wcs, 0)) {
     goto exit;
